import axios from "axios"
import moment from "moment";
import { BASE_URL, ELEMENT_TYPE, USER_CONNECTED } from "../../../core/application/constant/common"
import { ADD_EVENTS, ADD_IMAGE_EVENTS, CITY_AUTOCOMPLETE, DELETE_EVENTS, GET_EVENTS, GET_EVENT_INFOS, GLOBAL_SEARCH, PASSWORD_RECOVERY, SET_LINK_CONNECT, SET_LINK_DISCONNECT, SHARE_EVENTS } from "../api/agenda-api";
import ObjectId from 'bson-objectid';

/**
 * 
 * @param {*} startDate ex: 2023-10-31T09:00:00+0400
 * @param {*} name  ex: planning
 * @param {*} type  ex: contest
 * @param {*} locality ex:
    {
        "id": "0",
        "_id": {
            "$id": "5b30cbcf40bb4e6b652cc601"
        },
        "name": "Fianarantsoa",
        "alternateName": "FIANARANTSOA",
        "country": "MG",
        "geo": {
            "@type": "GeoCoordinates",
            "latitude": "-21.45337",
            "longitude": "47.085447"
        },
        "insee": "8001662*MG",
        "postalCodes": [],
        "level1": "59edc3a66ff99227048b462b",
        "level1Name": "Madagascar",
        "type": "city"
    }
 * @param {*} step 
 * @returns 
 */
const dayOfWeek = ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'];
export const getEvents = (startDate, name, type, locality, step = 30) => {
    const params = new FormData()
    const momentObj = moment(startDate);
    params.append("searchType[]", ELEMENT_TYPE.events);
    params.append("indexMin", 0);
    params.append("startDate", momentObj.valueOf() / 1000);
    params.append("indexStep", step);
    params.append("startDateUTC", new Date(startDate).toUTCString());
    params.append("fediverse", false);
    if (name) params.append("name", name);
    if (type) params.append("type", type);
    if (locality) {
        const formattedLocality = {};
        Object.keys(data).forEach(key => {
            const newKey = `${data.id}city[${key}]`;
            const value = key === "country" ? data[key] : true;
            locality[newKey] = value;
        });
        params.append("locality", formattedLocality)
    };
    if (name || type || locality) {
        params.append("count", true);
        params.append("countType[]", ELEMENT_TYPE.events);
    }
    return axios.post(BASE_URL + GET_EVENTS, params).then(({ data }) => {
        let events = [];
        let count = data.count && data.count[ELEMENT_TYPE.events] ? data.count[ELEMENT_TYPE.events] : 0;
        let results = data.results ? data.results : [];
        if (results) {
            Object.keys(results).forEach(id => {
                const item = results[id];
                events.push({
                    id,
                    ...item
                })
            });
        }
        return {
            count,
            //nextStartDate: moment(events[0].startDateSortFormat).valueOf() / 1000,
            //nextStartDateUTC : events[0].startDateSortFormat,
            data: events
        }
    })
}
export const getLocality = (name, limit = 30) => {
    const params = new FormData()
    params.append("name", name);
    params.append("searchType[]", ELEMENT_TYPE.cities);
    params.append("indexMax", limit);
    params.append("searchBy", 'ALL');
    return axios.post(BASE_URL + GLOBAL_SEARCH, params).then(({ data }) => {
        let locality = [];
        if (data.results) {
            Object.keys(data.results).forEach(id => {
                const item = data.results[id];
                locality.push({
                    id,
                    ...item
                })
            });
        }
        return locality;
    })
}

export const getOrganizer = (name, type) => {
    const params = new FormData()
    params.append("name", name);
    type.forEach(types => {
        params.append("searchType[]", ELEMENT_TYPE[types]);
    });
    return axios.post(BASE_URL + GLOBAL_SEARCH, params).then(({ data }) => {
        let organizers = [];
        if (data.results) {
            Object.keys(data.results).forEach(id => {
                const item = data.results[id];
                organizers.push({
                    id,
                    ...item
                })
            });
        }
        return organizers;
    })
}

export const createEvent = (name, organizeValue, partThisValue, type, visible, image, recurrency, email, tags, shortDescription, url) => {
    const newId = new ObjectId();
    const params = new FormData()
    params.append("name", name);

    if (organizeValue.length > 0) {
        for (let i = 0; i < organizeValue.length; i++) {
            params.append(`organizer[${organizeValue[i].id}][type]`, organizeValue[i].collection);
            params.append(`organizer[${organizeValue[i].id}][name]`, organizeValue[i].name);
        }
    } else {
        params.append(`organizer`, "");
    }

    if (partThisValue.length > 0) {
        for (let i = 0; i < partThisValue.length; i++) {
            params.append(`parent[${partThisValue[i].id}][type]`, partThisValue[i].collection);
            params.append(`parent[${partThisValue[i].id}][name]`, partThisValue[i].name);
        }
    } else {
        params.append(`parent`, "");
    }

    params.append("type", type);
    params.append("public", visible);

    if (recurrency.recurrency == false) {
        params.append("recurrency", recurrency.recurrency);
        params.append("startDate", recurrency.data.startDate);
        params.append("endDate", recurrency.data.endDate);
    } else if (recurrency.recurrency == true) {
        params.append("recurrency", recurrency.recurrency);
        let count = 0;
        for (const day of dayOfWeek) {
            const matchingItem = recurrency.data.find(item => day.substring(0, 2) === item.dayOfWeek);
            if (matchingItem) {
                params.append(`openingHours[${count}][dayOfWeek]`, matchingItem.dayOfWeek);
                params.append(`openingHours[${count}][hours][0][opens]`, matchingItem.opens);
                params.append(`openingHours[${count}][hours][0][closes]`, matchingItem.closes);
            } else {
                params.append('openingHours[]', '');
            }
            count++;
        }
    }

    if (tags.length > 0) {
        for (let i = 0; i < tags.length; i++) {
            params.append('tags[]', tags[i]);
        }
    }
    
    params.append("email", email);
    params.append("shortDescription", shortDescription);
    params.append("url", url);
    params.append("preferences[isOpenData]", true);
    params.append("preferences[isOpenEdition]", true);
    params.append("key", "event");
    params.append("collection", "events");
    params.append("id", newId.toString());
    params.append("timeZone", Intl.DateTimeFormat().resolvedOptions().timeZone);
    return axios.post(BASE_URL + ADD_EVENTS, params);
}

export const addImageEvents = (idAgenda, fileName, sizeFile, binaryData) => {

    const newId = new ObjectId();
    const params = new FormData()
    params.append("qquuid", newId.toString());
    params.append("qqfilename", fileName);
    params.append("qqtotalfilesize", sizeFile);
    params.append("qqfile", binaryData)

    return axios.post(BASE_URL + ADD_IMAGE_EVENTS + idAgenda + '/input/qqfile/docType/image/contentKey/profil', params)
}


export const updateEvent = () => {
    // To do update
}

export const getEventInfos = (eventId) => {
    const params = new FormData()
    return axios.post(BASE_URL + GET_EVENT_INFOS + eventId, params);
}

export const joinEvent = (eventId, connectType) => {
    const params = new FormData()
    params.append("childId", USER_CONNECTED.id);
    params.append("childType", ELEMENT_TYPE.citoyens);
    params.append("parentType", ELEMENT_TYPE.events);
    params.append("parentId", eventId);
    params.append("connectType", connectType); //admin
    return axios.post(BASE_URL + SET_LINK_CONNECT, params);
}

export const leaveEvent = (eventId) => {
    const params = new FormData()
    params.append("childId", USER_CONNECTED.id);
    params.append("childType", ELEMENT_TYPE.citoyens);
    params.append("parentType", ELEMENT_TYPE.events);
    params.append("parentId", eventId);
    params.append("connectType", 'attendees');
    return axios.post(BASE_URL + SET_LINK_DISCONNECT, params);
}

export const deleteEvent = (eventId, reason) => {
    const params = new FormData()
    params.append("reason", reason);
    return axios.post(BASE_URL + DELETE_EVENTS + eventId + '/type/events', params);
}

export const share = (eventId, comment, parentType) => {
    const params = new FormData()
    params.append("parentId", eventId);
    params.append("childId", USER_CONNECTED.id);
    params.append("childType", ELEMENT_TYPE.citoyens);
    params.append("connectType", "share");
    params.append("comment", comment);
    params.append("parentType", parentType);
    return axios.post(BASE_URL + SHARE_EVENTS, params);

}

export const getCityAutoComplete = (scopeValue, countryCode) => {
    const params = new FormData()
    params.append("type", "locality");
    params.append("scopeValue", scopeValue);
    params.append("geoShape", true)
    params.append("formInMap", true);
    params.append("countryCode", countryCode);
    return axios.post(BASE_URL + CITY_AUTOCOMPLETE, params).then(({ data }) => {
        let city = [];
        if (data.cities) {
            Object.keys(data.cities).forEach(id => {
                const item = data.cities[id];
                city.push({
                    id,
                    ...item
                })
            });
        }
        return city;
    })
}

// THIS IS FOR THE PASSWORD RECOVERY
export const passwordRecovery = (email, type) => {
    const params = new FormData();
    params.append("email", email);
    params.append("type", type);
    return axios.post(BASE_URL + PASSWORD_RECOVERY, params);
}