import { useState } from "react";
import defaultImage from "../../../core/assets/images/event.png";
import {  convertToFrenchDay1 } from "../../../core/application/helpers/dateTime-converter";
import { BASE_URL, USER_CONNECTED } from "../../../core/application/constant/common";
import { ChipWithAvatar } from "../../../core/presentation/component/ChipWithAvatar";
import CircleAvatarStack from "../../../core/presentation/component/CircleAvatarStack";
import CircleCardIconWithBadge from "../../../core/presentation/component/CircleCardIconWithBadge";
import PropTypes from 'prop-types';
import { EVENT_TYPES } from "../../infrastructure/constant/list-constant-agenda";

function CardEvent({ event, joinEvent, leaveEvent, deleteEvent, shareEvent, dataEvent, mode, editEvent, margin, openEventDetails, onSelectedEvent}) {
  const [isLeaveEventBtn, setLeaveEventBtn] = useState(false);
  const [isEditDelete, setEditDelete] = useState(false);

  const organizersArray = event.organizer ? Object.values(event.organizer) : [];
  const firstOrganizer = organizersArray.length >= 1 ? organizersArray[0] : null;

  const eventLabel = EVENT_TYPES.find((eventTypes) => eventTypes.value === event.type)?.label;

  const toggleDropdown = (e) => {
    e.stopPropagation();
    setLeaveEventBtn(!isLeaveEventBtn);
  };

  console.log(event);

  const joinEventFunction = (e, type) => joinEvent(e, type);

  const leaveEventFunction = (e) => leaveEvent(e);

  const deleteEventFunction = (e) => deleteEvent(e);

  const editEventFunction = () => editEvent(event);

  const shareEventFunction = (e) => {
    dataEvent(event);
    shareEvent(e);
  };

  const onClickedEventFunction = (e) => {
    e.stopPropagation(); 
    onSelectedEvent();
    openEventDetails();
  };

  const actionBottomRight = () => {
    const invited = [];
    const participated = [];

    if (event.links && event.links.attendees) {
      for (const key in event.links.attendees) {
        const attendee = event.links.attendees[key];

        if (
          attendee &&
          attendee.hasOwnProperty("isInviting") &&
          attendee.isInviting === true
        ) {
          invited.push(attendee);
        } else {
          participated.push(attendee);
        }
      }
    }

    return (
      <>
        <div className="md:absolute justify-end mr-2 md:mb-0 mb-2 md:bottom-2 bottom-2 right-2 flex space-x-2 cursor-pointer">
          <CircleAvatarStack participated={participated} className={"hidden sm:block"} />

          <CircleCardIconWithBadge
            count={invited.length}
            icon={"fa-solid fa-envelope"}
            dataTooltipContent={"invité-e(s)"}
            tooltipId={"invite-tooltip"}
          />

          {/*  action more */}
          {event.creator == USER_CONNECTED.id && mode != "getOnly" ? (
            <>
              <div 
                onClick={(e) => {
                  e.stopPropagation();
                  setEditDelete(!isEditDelete);
               }}
                className="relative inline-block text-left cursor-pointer">
                <div
                  class="relative inline-flex items-center justify-center w-8 h-8 mr-0 dark:text-gray-300 text-gray-500 transition-colors duration-150 bg-gray-300 dark:bg-gray-700 rounded-full focus:shadow-outlin"
                >
                  <i className="fa-solid fa-ellipsis cursor-pointer text-xl"></i>
                </div>
              </div>
            </>
          ) : null}
        </div>
      </>
    );
  };

  const isAlreadyAdminForEvent = () => {
    const userId = USER_CONNECTED.id;
    const attendees = event.links.attendees;
    return (
      attendees &&
      Object.keys(attendees)
        .map((key) => {
          const attendee = attendees[key];
          return key === userId && attendee.isAdmin === true;
        })
        .includes(true)
    );
  };

  const profilMediumImageUrl = (
    <>
      <img
        className="md:h-52 w-full rounded-tl-lg rounded-bl-lg object-cover sm:h-24"
        src={BASE_URL + event.profilMediumImageUrl}
        alt={event.name}
        onError={(e) => (e.target.src = defaultImage)}
      />
    </>
  );

  const organizer = firstOrganizer && (
    <div className="flex items-start flex-wrap md:flex-wrap">
      <span className="text-blue-500 text-sm md:mr-1 mb-1"> Organisée par :</span>
      <ChipWithAvatar name={firstOrganizer.name} image={BASE_URL + firstOrganizer.profilThumbImageUrl} defaultImage={defaultImage} />
    </div>
  );

  const otherOrganizers = organizersArray.length > 1 && (
    <p className="dark:text-gray-300 text-xs dark:hover:underline dark:hover:text-white hover:underline hover:text-gray-900">
      et {organizersArray.length - 1} autre
      {organizersArray.length - 1 > 1 ? "s" : ""} organisateur
      {organizersArray.length - 1 > 1 ? "s" : ""}
    </p>
  );

  const isFollowedOrNot = event.isFollowed ? (
    <div className="relative inline-block text-left">
      <button
        disabled={mode == "getOnly" ? true : false}
        className="bg-lime-600 p-1 rounded-lg flex items-center focus:outline-none"
        onClick={toggleDropdown}
      >
        <i
          style={{ fontSize: 11 }}
          className={`fa ${
            isAlreadyAdminForEvent() ? "fa-user-secret" : "fa-user-circle"
          } text-sm text-gray-50 dark:text-gray-50`}
        ></i>
        <p style={{ fontSize: 11 }} className="ml-2 text-gray-50 dark:text-gray-50 text-sm">
          {isAlreadyAdminForEvent() ? "Déjà  admin" : "Déjà  contributeur-rice"}
        </p>
      </button>

      {isLeaveEventBtn && (
        <div
          onMouseLeave={toggleDropdown}
          className="absolute right-1 mt-2 w-auto bg-white border border-gray-700 rounded-lg shadow-md dark:bg-gray-800"
        >
          <ul>
            {isAlreadyAdminForEvent() ? null : event.creator ===
              USER_CONNECTED.id ? (
              <li
                onClick={(e) => {
                  e.stopPropagation();
                  joinEventFunction(event._id.$id, "admin")
                }}
                className="text-sm px-4 py-2 hover:bg-yellow-100 dark:hover:bg-lime-600 dark:hover:text-gray-100 cursor-pointer"
              >
                Devenir administrateur
              </li>
            ) : null}
            <li
              onClick={(e) => {
                e.stopPropagation();
                leaveEventFunction(event._id.$id);
              }}
              className="text-sm px-4 py-2 hover:bg-gray-100 dark:hover:bg-lime-600 dark:hover:text-gray-100 cursor-pointer"
            >
              Quitter
            </li>
          </ul>
        </div>
      )}
    </div>
  ) : (
    <button
      disabled={mode == "getOnly" ? true : false}
      className="bg-lime-600 p-1 rounded-lg flex items-center cursor-pointer"
      onClick={(e) => {
        e.stopPropagation();
        joinEventFunction(event._id.$id, "connect");
      }}
    >
      <i
        style={{ fontSize: 11 }}
        className="fa-solid fa-link text-sm text-gray-50 dark:text-gray-50"
      ></i>
      <p style={{ fontSize: 11 }} className="ml-2 text-gray-50 dark:text-gray-50 text-sm">
        Participer
      </p>
    </button>
  );

  const eventReccurencyOrNot = event.openingHours ? (
    <>
       <div className="absolute bottom-0 w-full h-14 bg-slate-700 bg-opacity-75 flex items-center justify-center">
        <div className="flex space-x-1 justify-center m-2">
        <p className="text-gray-200 text-xs font-semibold">Chaque: </p>
        <p className="text-gray-200 text-xs font-semibold">
          {Object.keys(event.openingHours).map((key) => (
            <>
              <span>
                {" "}
                {convertToFrenchDay1(event.openingHours[key].dayOfWeek)}{" "}
              </span>
            </>
          ))}
        </p>
      </div>
           
        </div>
    </>
  ) : (
    <>
      {/* <div className="flex justify-center space-x-2">
        Du : <DateRenderer date={startDate} isAllDate={false}/>
        Au : <DateRenderer date={endDate} isAllDate={false}/>
      </div> */}
    </>
  );

  return (
    <div
      className={`sm:flex bg-gray-100 border dark:border-none dark:bg-gray-800 rounded-lg mb-5 transform hover:scale-105 transition duration-500 cursor-pointer ${
        margin == undefined ? "md:m-8 m-1 " : margin
      } overflow-hidden`}
    onClick={onClickedEventFunction}
    >
      <div className="relative md:w-1/2 sm:w-1/2">
        {profilMediumImageUrl}
        <div className="absolute top-0 left-0">
          <div className="bg-lime-600 rounded-tl-lg p-2 flex items-center">
            <i className="fa-solid fa-caret-right text-sm text-gray-50 dark:text-gray-50"></i>
            <p className="ml-2 text-gray-50 dark:text-gray-50 text-sm">{eventLabel}</p>
          </div>
        </div>

        {eventReccurencyOrNot}
      </div>

      <div className="md:w-1/2 sm:w-1/2 flex-col mx-4 mt-4 justify-between items-center space-y-3">
        <p className="dark:text-gray-50 mb-2 md:mt-5 font-semibold sm:mt-0">
          {event.name}
        </p>

       <div>
        {organizer}
        {otherOrganizers}
       </div>
       
      </div>


    
      <div className="md:absolute md:left-1/2 md:bottom-2 md:mb-1 ml-3 mb-2">
      {event.address && (
          <>
            <div className="flex-wrap items-center space-x-2">
              <div className="flex space-x-1">
              <div className="bg-gray-400 dark:bg-gray-600 w-5 h-5 rounded-lg p-1 flex items-center justify-center">
                <i className="fa-solid text-xs fa-location-dot text-gray-50"></i>
              </div>

                <p style={{ fontSize: 12 }} className="text-sm">
                  {event.address.streetAddress === ""
                    ? event.address.postalCode +
                      " " +
                      event.address.addressLocality
                    : event.address.streetAddress}
                </p>
              </div>
            </div>
          </>
        )}
      </div>


      <div className="absolute flex right-1 top-2 space-x-2 -mt-1">
        {isFollowedOrNot}
        {mode == "getOnly" ? null : (
          <>
            <button
              className="bg-lime-600 p-1 rounded-lg flex items-center"
              onClick={(e) => {
                e.stopPropagation();
                shareEventFunction(event._id.$id);
              }}
            >
              <i
                style={{ fontSize: 11 }}
                className="fa-solid fa-share text-sm text-gray-50 dark:text-gray-50"
              ></i>
              <p
                style={{ fontSize: 11 }}
                className="ml-2 text-gray-50 dark:text-gray-50 text-sm"
              >
                Partager
              </p>
            </button>
          </>
        )}
      </div>

      {/* action */}
      {actionBottomRight()}

      {isEditDelete && (
        <div
          onMouseLeave={() => setEditDelete(!isEditDelete)}
          className="absolute right-1 bottom-12  bg-white border border-gray-700 rounded-lg shadow-md dark:bg-gray-800"
        >
          <ul>
            <li
              onClick={(e) => {
                e.stopPropagation();
                deleteEventFunction(event._id.$id);
              }}
              className="text-sm px-4 py-2 hover:bg-yellow-100 dark:hover:bg-lime-600 dark:hover:text-gray-100 cursor-pointer"
            >
              Supprimer
            </li>
            <li
              onClick={(e) => {
                e.stopPropagation();
                editEventFunction(event._id.$id);
              }}
              className="text-sm px-4 py-2 hover:bg-gray-100 dark:hover:bg-lime-600 dark:hover:text-gray-100 cursor-pointer"
            >
              Modifier
            </li>
          </ul>
        </div>
      )}
    </div>
  );
}

CardEvent.propTypes = {
  event: PropTypes.object.isRequired,
  mode: PropTypes.string,
  joinEvent: PropTypes.func,
  leaveEvent: PropTypes.func,
  deleteEvent: PropTypes.func,
  shareEvent: PropTypes.func,
  dataEvent: PropTypes.func,
  editEvent: PropTypes.func,
  openEventDetails: PropTypes.func,
  onSelectedEvent: PropTypes.func,
  isSelected: PropTypes.bool
}

export default CardEvent;
