import { Carousel, IconButton } from "@material-tailwind/react";
import CategorieCard from "./categorieCard";
import { EVENT_TYPES } from "../../../infrastructure/constant/list-constant-agenda";
import PropTypes from 'prop-types';
import { useMemo } from "preact/hooks";

function CategorieCarousel({ onSelectedSearch, onResetSelectedSearch, selectedEventType, setSelectedEventType }) {


	const handleSearchCategory = (eventType) => {
		setSelectedEventType(eventType);
		onSelectedSearch(eventType);
	};

	const handleResetSelectedSearch = () => {
		setSelectedEventType({});
		onResetSelectedSearch();
	}


	const EventTypeList = useMemo(
		() => ({ eventTypeGroup }) => (
		  <div className="flex flex-row space-x-2">
			{eventTypeGroup.map((eventType) => (
			  <CategorieCard key={eventType.value} eventType={eventType} onClick={() => {
				if (eventType.value === selectedEventType.value) {
				  handleResetSelectedSearch();
				} else {
				  handleSearchCategory(eventType);
				}
			  }} isSelected={eventType.value == selectedEventType.value} />
			))}
		  </div>
		),
		[selectedEventType, handleResetSelectedSearch, handleSearchCategory]
	  );

	const firstList = EVENT_TYPES.slice(0, 5);
	const secondList = EVENT_TYPES.slice(5, 10);
	const thirdList = EVENT_TYPES.slice(10, 15);
	const fourthList = EVENT_TYPES.slice(15, 20);

	return (
		<Carousel
			className="md:h-64 md:w-auto mb-5"
			prevArrow={({ handlePrev }) => (
				<IconButton
					variant="text"
					color="white"
					size="lg"
					onClick={handlePrev}
					className="!absolute top-2/4 -left-3 -translate-y-2/4 bg-transparent text-gray-500 dark:text-gray-100 hover:dark:bg-transparent"
				>
					<i style={{ fontSize: 22 }} class="fa-solid fa-chevron-left"></i>
				</IconButton>
			)}
			nextArrow={({ handleNext }) => (
				<IconButton
					variant="text"
					color="white"
					size="lg"
					onClick={handleNext}
					className="!absolute top-2/4 -right-2 -translate-y-2/4 text-gray-500 dark:text-gray-100 hover:dark:bg-transparent"
				>
					<i style={{ fontSize: 22 }} class="fa-solid fa-chevron-right"></i>
				</IconButton>
			)}
			navigation={({ setActiveIndex, activeIndex, length }) => (
				<div className="absolute -bottom-0 left-2/4 z-50 flex -translate-x-2/4 gap-2">
					{new Array(length).fill("").map((_, i) => (
						<span
							key={i}
							className={`block h-1 cursor-pointer rounded-2xl transition-all content-[''] ${activeIndex === i ? "w-8 bg-gray-700 dark:bg-white" : "w-4 dark:bg-white/50 bg-gray-700/50"
								}`}
							onClick={() => setActiveIndex(i)}
						/>
					))}
				</div>
			)}
		>
			<div className="relative md:h-full md:w-full sm:w-1/2">
				<div className="absolute inset-0 grid h-full w-full place-items-center">
					<EventTypeList eventTypeGroup={firstList} />
					<EventTypeList eventTypeGroup={secondList} />
				</div>
			</div>

			<div className="relative md:h-full md:w-full sm:w-1/2">
				<div className="absolute inset-0 grid h-full w-full place-items-center">
					<EventTypeList eventTypeGroup={thirdList} />
					<EventTypeList eventTypeGroup={fourthList} />
				</div>
			</div>
		</Carousel>
	);
}

CategorieCarousel.propTypes = {
	onSelectedSearch: PropTypes.func,  
	onResetSelectedSearch: PropTypes.func,
	selectedEventType: PropTypes.object,  
	setSelectedEventType: PropTypes.func 
};

export default CategorieCarousel;