import { useMemo } from "preact/hooks";
import Carousel from "react-grid-carousel";
import CategorieCard from "./categorieCard";
import { EVENT_TYPES } from "../../../infrastructure/constant/list-constant-agenda";

function CategorieCarouselGrid({
  onSelectedSearch,
  onResetSelectedSearch,
  selectedEventType,
  setSelectedEventType,
  carouselWidth
}) {
  const handleSearchCategory = (eventType) => {
    setSelectedEventType(eventType);
    onSelectedSearch(eventType);
  };

  const handleResetSelectedSearch = () => {
    setSelectedEventType({});
    onResetSelectedSearch();
  };

  return (
      <>
      <Carousel
        cols={5}
        rows={2}
        gap={10}
        containerClassName={"hidden md:block mb-2"}
        containerStyle={{ width: `${carouselWidth >= 768 ? carouselWidth : 0}px`}}
      >
        {EVENT_TYPES.map((eventType) => (
          <Carousel.Item>
            <CategorieCard
              key={eventType.value}
              eventType={eventType}
              onClick={() => {
                if (eventType.value === selectedEventType.value) {
                  handleResetSelectedSearch();
                } else {
                  handleSearchCategory(eventType);
                }
              }}
              isSelected={eventType.value == selectedEventType.value}
            />
          </Carousel.Item>
        ))}
      </Carousel>
      </>
   
  );
}

export default CategorieCarouselGrid;
