import { useState } from "preact/hooks";
import React from "react";
import PropTypes from 'prop-types';
import { EVENT_TYPES } from "../../../infrastructure/constant/list-constant-agenda";
import CustomDrawer from "../../../../core/presentation/component/CustomDrawer";

function CategoryDropdown({onSelectedSearch, onResetSelectedSearch, containerClassName }) {
	const [isDropdownVisible, setDropdownVisible] = useState(false);
	const [selected, setSelected] = useState({});

	const toggleDropdown = () => {
		setDropdownVisible(!isDropdownVisible);
	};

	const handleSearchCategory = (eventType) => {
		setSelected(eventType);
		onSelectedSearch(eventType);
		setDropdownVisible(false);
	};

	const handleResetSelectedSearch = () => {
		setSelected({});
		onResetSelectedSearch();
	}


	const categoryEvent = EVENT_TYPES.map((eventType) => (
		<li key={eventType.value} className="flex space-x-2">
            
			<img src={eventType.image} className="w-8 h-8 object-cover rounded-lg" alt={eventType.label} />

			<button
				onClick={() => handleSearchCategory(eventType)}
				type="button"
				className="items-center w-full px-4 text-sm text-gray-700 dark:text-gray-400 dark:hover:text-gray-200"
			>
				<div className="flex justify-between">
					<span style={{ fontSize: 12 }}>
						{eventType.label}
					</span>
					{
						selected.value == eventType.value && (
							<i className="fa fa-check"></i>
						)
					}
				</div>
			</button>
		</li>
	));


	return (
		<>
			<div className={containerClassName}>

				<div className="flex" onMouseLeave={()=> handleResetSelectedSearch()}>
					<button
						className="flex-shrink-0 z-10 inline-flex items-center py-2.5 px-4 text-sm font-medium text-center bg-white rounded-lg border-l-2 border border-gray-300 dark:bg-gray-900 dark:border-l-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 focus:outline-none dark:rounded-l-lg"
						type="button"
						onClick={toggleDropdown}
					>

						{
							selected && Object.keys(selected).length !== 0 ? (
								<i onClick={() => handleResetSelectedSearch()} className="fa-solid fa-circle-xmark mt-1 mr-3 cursor-pointer"></i>
							) : null
						}

						<span className="mr-2">
							{
								selected && Object.keys(selected).length !== 0
									? selected.label
									: "Catégorie"
							}
						</span>

						<i className="fa-solid fa-caret-down mt-1"></i>
					</button>

					
				</div>

				{isDropdownVisible && (
					<CustomDrawer 
					  isOpenDrawer={isDropdownVisible} 
					  openAndCloseDrawer={toggleDropdown}
					  placement={"bottom"} 
					>
			           	<ul className="flex-col mt-2 space-y-2 text-sm text-gray-700 dark:text-gray-200" aria-labelledby="states-button">
					 		{categoryEvent}
					 	</ul>

					</CustomDrawer>
					// <div
					// 	className="absolute md:h-1/2 sm:h-1/2 z-40 overflow-auto top-14 bg-white divide-y divide-gray-100 rounded-lg shadow w-44 dark:bg-gray-700"
					// 	onMouseLeave={toggleDropdown}
					// >
					// 	<ul className="py-2 text-sm text-gray-700 dark:text-gray-200" aria-labelledby="states-button">
					// 		{categoryEvent}
					// 	</ul>
					// </div>
				)}

			</div>

		</>
	);
}

CategoryDropdown.propTypes = {
	onSearch:  PropTypes.func,
	onSelectedSearch: PropTypes.func, 
	onResetSelectedSearch: PropTypes.func
};

export default CategoryDropdown;