import { useMemo } from 'preact/hooks';
import NoEvents from "./NoEvents";
import PropTypes from 'prop-types';

function EventTimeline({ events, eventChild }) {
  
  const eventsWithoutRecurrence = useMemo(() => {
    return events.filter((event) => !event.recurrency);
  }, [events]);

  const uniqueMonths = useMemo(() => {
    return [
      ...new Set(
        eventsWithoutRecurrence.map((event) => formatDate(event.endDate))
      ),
    ].sort((a, b) => new Date(b) - new Date(a));
  }, [eventsWithoutRecurrence]);

  function formatDate(date) {
    return new Date(date).toLocaleString("default", {
      month: "long",
      year: "numeric",
    });
  }

  function capitalizeFirstLetter(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
  }

  return eventsWithoutRecurrence.length > 0 ? (
    <div className="md:px-7">
      <ol className="relative border-l border-gray-400 dark:border-gray-700 border-dotted p-2">
        {uniqueMonths.map((monthYear, index) => (
          <li key={index} className="mb-10 ml-4">
            <div className="absolute w-3 h-3 bg-gray-400 rounded-full mt-1.5 -left-1.5 dark:border-gray-50 dark:bg-gray-400"></div>
            <time className="font-normal leading-none text-gray-500 dark:text-gray-500 text-xl">
              {capitalizeFirstLetter(monthYear)}
            </time>
            <ul>
              {eventsWithoutRecurrence
                .filter((event) => formatDate(event.endDate) === monthYear)
                .map((eventElement, eventIndex) => eventChild(eventElement, eventIndex))}
            </ul>
          </li>
        ))}
      </ol>
    </div>
  ) : (
    <NoEvents />
  );
}

EventTimeline.propTypes = {
  events: PropTypes.array.isRequired,
  eventChild: PropTypes.elementType.isRequired
}

export default EventTimeline;
