import React from 'react'
import Select from '../../../../core/presentation/component/input/Select'
import { CountryList } from '../../../../core/list/CountryList'
import { useEffect, useState } from 'preact/hooks'
import InputSimple from '../../../../core/presentation/component/input/InputSimple'
import { getCityAutoComplete } from '../../../infrastructure/constant/api-endpoints'
import MapDetaille from '../../../../searchAll/presentation/component/MapDetaille'

function AdressDetaille({ addressCountry, addressLocallity, streetAddress }) {

    const [stepAdress, setstepAdress] = useState(0)
    const [pays, setpays] = useState("")
    const [ville, setville] = useState("")
    const [streetAdresse, setstreetAdresse] = useState("")
    const [suggestions, setSuggestions] = useState([]);

    useEffect(() => {
        addressCountry(pays)
        addressLocallity(ville)
        streetAddress(streetAdresse)
        test()
    }, [pays, ville, streetAdresse])

    const test = async () => {
        if (ville.length >= 2) {
            try {
                const response = await getCityAutoComplete(ville, pays)
                const tagsArray = response.map(item => item.name)
                setSuggestions(tagsArray)
            } catch (error) {
                console.log(error);
            }
        }
    }

    const handleClick = (e) => {
        setville(e)
        setSuggestions([])
    }
    return (
        <>
            <div className='mt-5 object-center flex'>
                <button
                    disabled={stepAdress != 0 ? true : false}
                    onClick={() => setstepAdress(1)}
                    type="button"
                    className="w-full text-gray-200 bg-green-700 hover:bg-green-600 focus:outline-none focus:ring-green-300 dark:focus:ring-green-800 font-medium rounded text-sm items-center px-5 py-2.5">
                    <i className='fa-solid fa-plus'></i> Ajouter une nouvelle adresse
                </button>
            </div>
            {stepAdress != 0 ?
                <>
                    <div className='border-l-2 rounded-t-sm rounded-b-xl border-r-2 border-b-2 border-gray-500 p-2'>
                        <Select label={"Pays ou DOM/TOM"} list={CountryList} ctrl={false} value={(e) => setpays(e)} />
                        {pays != "" ?
                            <div className='relative'>
                                <InputSimple label={"Ville"} type={"text"} ctrl={false} value={(e) => setville(e)} defaultValue={ville} />
                                {suggestions.length > 0 && ville.length >= 2 && (
                                    <div className="absolute w-full z-50 -mt-5 p-2 bg-white border border-gray-200 rounded-lg shadow dark:bg-gray-800 dark:border-gray-700">
                                        {suggestions
                                            .map((suggestion, index) => (
                                                <div
                                                    key={index}
                                                    onClick={() => handleClick(suggestion)}
                                                    className="text-gray-900 dark:text-gray-300 cursor-pointer"
                                                >
                                                    {suggestion}
                                                </div>
                                            ))}
                                    </div>
                                )}
                            </div>
                            : null
                        }
                        <div className='ml-4'>
                            <MapDetaille latitude={"22"} longitude={"22"} />
                        </div>
                        {ville != "" ?
                            <InputSimple label={"(N° rue) + Adresse"} type={"text"} ctrl={false} value={(e) => setstreetAdresse(e)} />
                            : null
                        }
                    </div>
                </> : null
            }
        </>
    )
}

export default AdressDetaille