import { useEffect, useState } from 'preact/hooks'
import React from 'react'
import Modal from '../../../../core/presentation/component/Modal'
import logo from "../../../../core/assets/images/logo-min.png";
import { USER_CONNECTED, BASE_URL } from '../../../../core/application/constant/common';

function IsPart({ results, callBackGetList, valueCallBack, editData, setSearchValueIspart }) {
    const [show, setShow] = useState(false)
    const [selectedItem, setSelectedItem] = useState(null);
    const [resultsEdit, setResultsEdit] = useState([]);
    const [userShow, setUserShow] = useState(true);
    const [idNoShow, setidNoShow] = useState(null);
    const [value, setValue] = useState([]);

    useEffect(() => {
        if (editData !== undefined || editData == "") {
            if (Object.entries(editData)[0][0] == USER_CONNECTED.id) {
                const { id, collection, name, profilThumbImageUrl } = USER_CONNECTED;
                setSelectedItem({ id, collection, name, photo: profilThumbImageUrl });
                setResultsEdit(results)
                setUserShow(false)
                setValue([{ "id": id, "collection": collection, "name": name }])
            } else {
                setUserShow(true)
                // setSelectedItem();
                // console.log(results.find(objet => objet.id == "655c52e6e32155972ca955e8"));
                setSelectedItem({ "id": Object.keys(editData)[0], "collection": Object.entries(editData)[0][1].type, "name": Object.entries(editData)[0][1].name })
                setResultsEdit(results.filter(objet => objet.id !== Object.keys(editData)[0]))
            }
        } else if (selectedItem == null) {
            setResultsEdit(results)
        } else {
            setResultsEdit((results) => results.filter(result => result.id !== idNoShow));
        }
    }, [results])

    const showAndGetList = () => {
        setShow(true);
        callBackGetList();
    }

    const handleItemClick = (id, collection, name, photo) => {
        setidNoShow(id)
        if (id == USER_CONNECTED.id) {
            setUserShow(false)
        } else if (id != USER_CONNECTED.id) {
            setUserShow(true)
        }
        setSelectedItem({ id, collection, name, photo });
        setResultsEdit(results)
        setResultsEdit((prevResults) => prevResults.filter(result => result.id !== id));
        setValue([{ "id": id, "collection": collection, "name": name }])
    }

    const removeItems = () => {
        setUserShow(true)
        setSelectedItem(null)
        setValue([])
    }

    const closeModal = () => {
        setShow(false)
        setSearchValueIspart('')
    }

    valueCallBack(value)

    return (
        <>
            <label className="mt-4 block text-sm font-medium text-gray-900 dark:text-gray-300">Fait partie d'un événement</label>
            <button
                onClick={showAndGetList}
                type="button" className="w-full mt-2 text-gray-200 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-gray-300 dark:focus:ring-gray-800 font-medium rounded text-sm items-center px-5 py-2.5 mr-2">
                Changer l’élément ci-dessous
            </button>
            {selectedItem && (
                <div key={selectedItem.id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => removeItems(selectedItem.id)}>
                    <input
                        type="checkbox"
                        checked={true}
                        className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                    />
                    <img
                        src={(selectedItem.photo !== undefined ? BASE_URL + selectedItem.photo : logo)}
                        className="h-10 w-10 rounded-full object-cover"
                    />
                    <div className="flex flex-col w-80">
                        <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                            {selectedItem.name}
                        </h2>
                        <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{selectedItem.collection}</p>
                    </div>
                </div>
            )}
            <Modal show={show} onSubmit={closeModal} close={closeModal} title={"Selectionner dans la liste"} style={"h-[calc(100vh-290px)] overflow-y-auto overflow-x-hidden"}>
                <input
                    type="search"
                    onChange={(e) => setSearchValueIspart(e.target.value)}
                    className="mb-2 block w-full p-3 pl-10 text-sm text-gray-900 border border-gray-300 rounded bg-gray-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none" placeholder="Rechercher un element..."
                />
                {selectedItem && (
                    <div key={selectedItem.id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => removeItems(selectedItem.id)}>
                        <input
                            type="checkbox"
                            checked={true}
                            className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                        />
                        <img
                            src={(selectedItem.photo !== undefined ? BASE_URL + selectedItem.photo : logo)}
                            className="h-10 w-10 rounded-full object-cover"
                        />
                        <div className="flex flex-col w-80">
                            <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                                {selectedItem.name}
                            </h2>
                            <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{selectedItem.collection}</p>
                        </div>
                    </div>
                )}
                <hr class="h-px my-2 bg-gray-200 border-0 dark:bg-gray-600" />
                {userShow && USER_CONNECTED.name.toLowerCase() && (
                    <div key={USER_CONNECTED.id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => handleItemClick(USER_CONNECTED.id, USER_CONNECTED.collection, USER_CONNECTED.name, USER_CONNECTED.profilThumbImageUrl)}>
                        <input
                            type="checkbox"
                            className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                        />
                        <img
                            src={(USER_CONNECTED.profilThumbImageUrl !== undefined ? BASE_URL + USER_CONNECTED.profilThumbImageUrl : logo)}
                            className="h-10 w-10 rounded-full object-cover"
                        />
                        <div className="flex flex-col w-80">
                            <h2 className="font-bold text-lg text-gray-900 dark:text-gray-300 truncate">
                                {USER_CONNECTED.name}
                            </h2>
                            <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{USER_CONNECTED.collection}</p>
                        </div>
                    </div>
                )}

                {resultsEdit
                    .map(({ profilThumbImageUrl, name, collection, id }) => (
                        <div key={id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => handleItemClick(id, collection, name, profilThumbImageUrl)}>
                            <input
                                type="checkbox"
                                className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                            />
                            <img
                                src={(profilThumbImageUrl !== undefined ? BASE_URL + profilThumbImageUrl : logo)}
                                className="h-10 w-10 rounded-full object-cover"
                            />
                            <div className="flex flex-col w-80">
                                <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                                    {name}
                                </h2>
                                <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{collection}</p>
                            </div>
                        </div>
                    ))
                }
            </Modal>
        </>
    )
}

export default IsPart