import React from 'react'
import Modal from '../../../../core/presentation/component/Modal'
import { useEffect, useState } from 'preact/hooks'
import { BASE_URL } from '../../../../core/application/constant/common';
import logo from "../../../../core/assets/images/logo-min.png";

function OrganizesThis({ results, callBackGetList, valueCallBack, editData, setSearchValue }) {
    const [show, setShow] = useState(false);
    
    const [selectedItems, setSelectedItems] = useState([]);
    const [uniqueId, setUniqueId] = useState(0);
    const [remainingResults, setRemainingResults] = useState([]);
    const [value, setValue] = useState([]);
    // console.log(results);
    
    useEffect(() => {
        if (editData !== undefined || editData == "") {
            const filteredArray2 = results.filter(item2 => !Object.entries(editData).map(([id, data]) => ({ id, ...data })).some(item1 => item1.id === item2.id))
            const resultsWithOriginalOrder = filteredArray2.map((result, index) => ({
                ...result,
                originalOrder: index
            }));
            setSelectedItems(Object.entries(editData).map(([id, data]) => ({ id, ...data })))
            setRemainingResults(resultsWithOriginalOrder);

        } else if (selectedItems.length > 0) {
            const resultsWithOriginalOrder = remainingResults.map((result, index) => ({
                ...result,
                originalOrder: index
            }));
            setRemainingResults(resultsWithOriginalOrder);

        } else {
            const resultsWithOriginalOrder = results.map((result, index) => ({
                ...result,
                originalOrder: index
            }));
            setRemainingResults(resultsWithOriginalOrder);
            
        }
    }, [results]);

    const showAndGetList = () => {
        setShow(true);
        callBackGetList();
    }

    const handleItemClick = (id, collection, name, profilThumbImageUrl, originalOrder) => {
        const item = { id, collection, name, profilThumbImageUrl, uniqueId, originalOrder };
        setSelectedItems([...selectedItems, item]);
        setValue([...value, { "id": id, "collection": collection, "name": name }]);
        setUniqueId(uniqueId + 1);

        const updatedRemainingResults = remainingResults.filter(result => result.id !== id);
        setRemainingResults(updatedRemainingResults);
    }

    const handleItemRemove = (uniqueId, collection, id) => {
        if (collection === undefined) {
            const dataToAdd = results.filter(result => result.id == id);
            setRemainingResults(prevRemainingResults => [...prevRemainingResults, ...dataToAdd]);
            const updatedSelectedItems = selectedItems.filter(item => item.id !== id);
            setSelectedItems(updatedSelectedItems);
        } else {
            const updatedSelectedItems = selectedItems.filter(item => item.uniqueId !== uniqueId);
            setSelectedItems(updatedSelectedItems);

            const removedItem = selectedItems.find(item => item.uniqueId === uniqueId);
            setValue(prevValue => prevValue.filter(item => item.id !== removedItem.id));

            const updatedRemainingResults = [...remainingResults];
            updatedRemainingResults.splice(removedItem.originalOrder, 0, removedItem);
            setRemainingResults(updatedRemainingResults);
        }
    };

    const closeModal = () => {
        setShow(false)
        setSearchValue('')
    }

    valueCallBack(value)
    return (
        <>
            <label className="mt-4 block text-sm font-medium text-gray-900 dark:text-gray-300">Qui organise cet événement</label>
            <button
                onClick={showAndGetList}
                type="button" className="w-full mt-2 text-gray-200 bg-gray-700 hover:bg-gray-600 focus:outline-none focus:ring-gray-300 dark:focus:ring-gray-800 font-medium rounded text-sm items-center px-5 py-2.5 mr-2">
                Ajouter à la liste
            </button>
            {selectedItems.length > 0 && (
                <ul>
                    {selectedItems.map((item) => (
                        <div key={item.id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => handleItemRemove(item.uniqueId, item.collection, item.id)}>
                            <inputsetSearchValue
                                type="checkbox"
                                className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                                checked={true}
                            />
                            <img
                                src={(item.profilThumbImageUrl !== undefined ? BASE_URL + item.profilThumbImageUrl : logo)}
                                className="h-10 w-10 rounded-full object-cover"
                            />
                            <div className="flex flex-col w-80">
                                <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                                    {item.name}
                                </h2>
                                <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{item.collection ? item.collection : item.type}</p>
                            </div>
                        </div>
                    ))}
                </ul>
            )}
            <Modal show={show} onSubmit={closeModal} close={closeModal} title={"Selectionner dans la liste"} style={"h-[calc(100vh-290px)] overflow-y-auto overflow-x-hidden"}>
                <input
                    type="search"
                    onChange={(e) => setSearchValue(e.target.value)}
                    className="mb-2 block w-full p-3 pl-10 text-sm text-gray-900 border border-gray-300 rounded bg-gray-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none" placeholder="Rechercher un element..."
                />
                {selectedItems.length > 0 && (
                    <ul>
                        {selectedItems.map((item) => (
                            <div key={item.id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => handleItemRemove(item.uniqueId, item.collection, item.id)}>
                                <input
                                    type="checkbox"
                                    className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                                    checked={true}
                                />
                                <img
                                    src={(item.profilThumbImageUrl !== undefined ? BASE_URL + item.profilThumbImageUrl : logo)}
                                    className="h-10 w-10 rounded-full object-cover"
                                />
                                <div className="flex flex-col w-80">
                                    <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                                        {item.name}
                                    </h2>
                                    <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{item.collection ? item.collection : item.type}</p>
                                </div>
                            </div>
                        ))}
                    </ul>
                )}
                <hr class="h-px my-2 bg-gray-200 border-0 dark:bg-gray-600" />
                {remainingResults
                    .map(({ profilThumbImageUrl, name, collection, id, originalOrder }) => (
                        <div key={id} className="flex items-center space-x-4 p-3 cursor-pointer hover:dark:bg-gray-800" onClick={() => handleItemClick(id, collection, name, profilThumbImageUrl, originalOrder)}>
                            <input
                                type="checkbox"
                                className="w-5 h-5 text-blue-600 bg-gray-100 border-gray-300 rounded focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600"
                            />
                            <img
                                src={(profilThumbImageUrl !== undefined ? BASE_URL + profilThumbImageUrl : logo)}
                                className="h-10 w-10 rounded-full object-cover"
                            />
                            <div className="flex flex-col w-80">
                                <h2 className="font-bold text-lgtext-gray-900 dark:text-gray-300 truncate">
                                    {name}
                                </h2>
                                <p className="text-sm text-gray-900 dark:text-gray-300 truncate">{collection}</p>
                            </div>
                        </div>
                    ))
                }
            </Modal>
        </>
    )
}

export default OrganizesThis