import moment from "../../../../core/application/helpers/moment";
import { useEffect, useState } from 'preact/hooks';
import React from 'react'

function RecurringEvents({ valueCallBack, ctrlIfNo, recurrencyEditValue, msgErreur }) {
    const [startDate, setStartDate] = useState(recurrencyEditValue !== undefined && recurrencyEditValue.recurrency == false ? moment(recurrencyEditValue.data.startDate).format("yyyy-MM-DDThh:mm") : "");
    const [endDate, setEndDate] = useState(recurrencyEditValue !== undefined && recurrencyEditValue.recurrency == false ? moment(recurrencyEditValue.data.endDate).format("yyyy-MM-DDThh:mm") : "");
    const [recurrency, setRecurrency] = useState(recurrencyEditValue !== undefined && recurrencyEditValue.recurrency == true ? true : false);
    const daysOfWeek = ['Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday'];
    const [dayData, setDayData] = useState([]);

    useEffect(() => {
        if (recurrencyEditValue == undefined) {
            if (!recurrency) {
                valueCallBack({
                    "recurrency": false,
                    "data": {
                        "startDate": startDate,
                        "endDate": endDate
                    }
                });

            } else {
                const formattedData = dayData.map((data) => {
                    return {
                        dayOfWeek: data.day.substring(0, 2),
                        opens: data.startTime != "" ? data.startTime : '08:00',
                        closes: data.endTime != "" ? data.endTime : '19:00'
                    };
                });
                valueCallBack({ "recurrency": true, "data": formattedData, validateMultiData: isValid });
            }
        }
    }, [recurrency, startDate, endDate, dayData]);

    const hasDataForDay = (day) => {
        return dayData.some((data) => data.day === day);
    };

    dayData.sort((a, b) => {
        const dayA = daysOfWeek.indexOf(a.day);
        const dayB = daysOfWeek.indexOf(b.day);
        return dayA - dayB;
    });

    const handleDayClick = (day) => {
        const existingData = dayData.find((data) => data.day === day);

        if (existingData) {
            setDayData((prevData) => prevData.filter((data) => data.day !== day));
        } else {
            const newData = { day, startTime: '', endTime: '' };
            setDayData([...dayData, newData]);
        }
    };

    const recurrencySet = (e) => {
        setRecurrency(e)
    }

    const validatedayData = (dayData) => {
        const isValidData = dayData.map((range) => {
            let startTimeValue = range.startTime;
            let endTimeValue = range.endTime;

            if (range.startTime === "") {
                startTimeValue = "08:00";
            }
            if (range.endTime === "") {
                endTimeValue = "19:00";
            }

            const startTimeMoment = moment(startTimeValue, 'HH:mm');
            const endTimeMoment = moment(endTimeValue, 'HH:mm');

            const isValidStartTime = startTimeValue === "" || startTimeMoment.isValid();
            const isValidEndTime = endTimeValue === "" || endTimeMoment.isValid();
            const isEndTimeAfterStartTime =
                startTimeValue !== "" &&
                endTimeValue !== "" &&
                endTimeMoment.isSameOrAfter(startTimeMoment);

            return isValidStartTime && isValidEndTime && isEndTimeAfterStartTime;
        });

        return isValidData;
    };
    const isValid = validatedayData(dayData);
    return (
        <>
            <label className="relative inline-flex items-center cursor-pointer mt-4">
                <input type="checkbox" onClick={() => recurrencySet(!recurrency)} checked={recurrency == false ? false : true} className="sr-only peer" />
                <div className="w-11 h-6 bg-gray-200 rounded-full peer peer-focus:ring-4 peer-focus:ring-blue-300 dark:peer-focus:ring-blue-800 dark:bg-gray-700 peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[''] after:absolute after:top-0.5 after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-blue-600"></div>
                <span className="ml-3 text-sm font-medium text-gray-900 dark:text-gray-300">Evènement récurrent? *</span>
            </label>
            {recurrency == false ?
                <>
                    <div className="flex items-center mt-2">
                        <div className="relative w-1/2">
                            <input
                                onChange={(e) => setStartDate(e.target.value)}
                                type="datetime-local"
                                value={startDate}
                                className={`${ctrlIfNo === false
                                    ? 'block w-full p-3 pl-2 mt-2 text-sm text-gray-900 dark:text-gray-300 border border-gray-300 dark:bg-gray-800 dark:border-gray-600 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 rounded-lg dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none'
                                    : 'w-full p-3 pl-2 mt-2 bg-red-50 border border-red-500 text-red-900 placeholder-red-700 text-sm rounded-lg focus:ring-red-500 dark:bg-gray-700 focus:border-red-500 block w-full p-2.5 dark:text-red-500 dark:placeholder-red-500 dark:border-red-500 outline-none'
                                    }`}
                                placeholder="Date de début *"
                            />
                        </div>
                        <span className={`mx-2 ${ctrlIfNo == false ? `text-gray-500` : `text-red-900`}`}>A</span>
                        <div className="relative w-1/2">
                            <input
                                onChange={(e) => setEndDate(e.target.value)}
                                type="datetime-local"
                                value={endDate}
                                className={`${ctrlIfNo === false
                                    ? 'block w-full p-3 pl-2 mt-2 text-sm text-gray-900 dark:text-gray-300 border border-gray-300 dark:bg-gray-800 dark:border-gray-600 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 rounded-lg dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none'
                                    : 'w-full p-3 pl-2 mt-2 bg-red-50 border border-red-500 text-red-900 placeholder-red-700 text-sm rounded-lg focus:ring-red-500 dark:bg-gray-700 focus:border-red-500 block w-full p-2.5 dark:text-red-500 dark:placeholder-red-500 dark:border-red-500 outline-none'
                                    }`}
                                placeholder="Date de fin *" />
                        </div>
                    </div>
                    {ctrlIfNo &&
                        <p class="mt-2 text-sm text-red-600 dark:text-red-500"> {msgErreur == undefined ? "Ce champ est obligatoire" : msgErreur}</p>
                    }
                </> :
                <>
                    <div>
                        <div className="grid grid-cols-7 gap-1 text-gray-200 mt-5">
                            {daysOfWeek.map((day) => (
                                <div
                                    key={day}
                                    className={`block max-w-sm p-2 text-center cursor-pointer border border-gray-700 rounded-lg shadow hover:bg-gray-100 ${hasDataForDay(day) ? 'dark:bg-blue-600' : 'dark:bg-gray-800'
                                        }`}
                                    onClick={() => handleDayClick(day)}
                                >
                                    {day.substring(0, 3)}
                                </div>
                            ))}
                        </div>
                        {dayData.map((data, index) => (
                            <div key={data.day} className={isValid[index] === true ? "border rounded-lg dark:border-gray-700 mt-4 p-2" : "border rounded-lg dark:border-red-700 mt-4 p-2"}>
                                <h1 className="text-gray-200 mb-2 font-bold">{data.day}</h1>
                                <div className="grid grid-cols-2 gap-1 text-gray-200">
                                    <div>
                                        <label htmlFor={`input-group-1-${data.day}`} className={isValid[index] === true ? "block mb-2 text-sm text-gray-900 dark:text-gray-200" : "block mb-2 text-sm text-red-500 dark:text-red-500"}>
                                            <i className="fa-solid fa-hourglass-start"></i> Heure de début
                                        </label>
                                        <div className="relative">
                                            <input
                                                type="time"
                                                id={`input-group-1-${data.day}`}
                                                className={`${isValid[index] === true
                                                    ? 'block w-full p-3 pl-2 mt-2 text-sm text-gray-900 dark:text-gray-300 border border-gray-300 dark:bg-gray-800 dark:border-gray-600 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 rounded-lg dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none'
                                                    : 'w-full p-3 pl-2 mt-2 bg-red-50 border border-red-500 text-red-900 placeholder-red-700 text-sm rounded-lg focus:ring-red-500 dark:bg-gray-700 focus:border-red-500 block w-full p-2.5 dark:text-red-500 dark:placeholder-red-500 dark:border-red-500 outline-none'
                                                    }`}
                                                value={data.startTime || '08:00'}
                                                onChange={(e) => {
                                                    const updatedData = { ...data, startTime: e.target.value };
                                                    setDayData((prevData) =>
                                                        prevData.map((item) => (item.day === data.day ? updatedData : item))
                                                    );
                                                }}
                                            />
                                        </div>
                                    </div>
                                    <div>
                                        <label htmlFor={`input-group-1-${data.day}`} className={isValid[index] === true ? "block mb-2 text-sm text-gray-900 dark:text-gray-200" : "block mb-2 text-sm text-red-500 dark:text-red-500"}>
                                            <i className="fa-solid fa-hourglass-end"></i> Heure de fin
                                        </label>
                                        <div className="relative">
                                            <input
                                                type="time"
                                                id={`input-group-2-${data.day}`}
                                                className={`${isValid[index] === true
                                                    ? 'block w-full p-3 pl-2 mt-2 text-sm text-gray-900 dark:text-gray-300 border border-gray-300 dark:bg-gray-800 dark:border-gray-600 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 rounded-lg dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none'
                                                    : 'w-full p-3 pl-2 mt-2 bg-red-50 border border-red-500 text-red-900 placeholder-red-700 text-sm rounded-lg focus:ring-red-500 dark:bg-gray-700 focus:border-red-500 block w-full p-2.5 dark:text-red-500 dark:placeholder-red-500 dark:border-red-500 outline-none'
                                                    }`}
                                                value={data.endTime || '19:00'}
                                                onChange={(e) => {
                                                    const updatedData = { ...data, endTime: e.target.value };
                                                    setDayData((prevData) =>
                                                        prevData.map((item) => (item.day === data.day ? updatedData : item))
                                                    );
                                                }}
                                            />
                                        </div>
                                    </div>
                                    {isValid[index] === false &&
                                        <p class="mt-2 text-sm text-red-600 dark:text-red-500"> {msgErreur == undefined ? "Verifier les champs" : msgErreur}</p>
                                    }
                                </div>
                            </div>
                        ))}
                    </div>
                </>
            }
        </>
    )
}

export default RecurringEvents