import { useEffect, useState } from "preact/hooks";
import Modal from "../../../core/presentation/component/Modal";
import Tags from "../../../news/presentation/component/form/Tags";
import { addImageEvents, createEvent, getOrganizer } from "../../infrastructure/constant/api-endpoints";
import OrganizesThis from "../component/form/OrganizesThis";
import IsPart from "../component/form/IsPart";
import RecurringEvents from "../component/form/RecurringEvents";
import TypeEvents from "../component/form/TypeEvents";
import YesOrNo from "../component/form/YesOrNo";
import InputSimple from "../../../core/presentation/component/input/InputSimple";
import Textarea from "../../../core/presentation/component/input/Textarea";
import UploadImage from "../../../core/presentation/component/input/UploadImage";
import moment from "moment";

export default function FormEditEvent({ showEditForm, close, title, data }) {
    const [tags, setTags] = useState([]);
    const [name, setName] = useState("");
    const [nameCtrl, setNameCtrl] = useState(false);
    const [email, setEmail] = useState("");
    const [shortDescription, setShortDescription] = useState("");
    const [organizeValue, setorganizeValue] = useState([]);
    const [partThisValue, setpartThisValue] = useState([]);
    const [visible, setvisible] = useState(true);
    const [image, setimage] = useState("");
    const [type, settype] = useState("");
    const [typeCtrl, settypeCtrl] = useState(false);
    const [recurrency, setRecurrency] = useState(true);
    const [recurrencyCtrlIfNo, setRecurrencyCtrlIfNo] = useState(false);
    const [resultGlobalAutocompleteOne, setResultGlobalAutocompleteOne] = useState([]);
    const [resultGlobalAutocompleteTwo, setResultGlobalAutocompleteTwo] = useState([]);
    const [url, setUrl] = useState("");

    const recurrencyEditValue =
        data.recurrency == false ? {
            "recurrency": false,
            "data": {
                "startDate": data.startDateTime,
                "endDate": data.endDateTime
            }
        } : {
            "recurrency": true,
        }
    
    useEffect(() => {
        setName(data.name)
        settype(data.type)
    }, [data]);

    const create = async () => {
        let result = '';
        if (name == '') {
            setNameCtrl(true)
        } else {
            setNameCtrl(false)
            result += '1';
        }
        if (type == '') {
            settypeCtrl(true)
        } else {
            settypeCtrl(false)
            result += '2';
        }
        if (recurrency.recurrency == false) {
            if (recurrency.data.startDate == "" || recurrency.data.endDate == "" || moment(recurrency.data.startDate).isAfter(moment(recurrency.data.endDate))) {
                setRecurrencyCtrlIfNo(true)
            } else {
                setRecurrencyCtrlIfNo(false)
                result += 'f3';
            }
        } else if (recurrency.recurrency == true) {
            if (recurrency.data.length >= 1 && !recurrency.validateMultiData.includes(false)) {
                result += 'y3';
            }
        }
        if (result == "12f3" || result == "12y3") {
            try {
                const response = await createEvent(name, organizeValue, partThisValue, type, visible, image, recurrency, email, tags, shortDescription, url);
                if (typeof image === 'object' && response.data.result === true) {
                    await addImageEvents(response.data.id, image.name, image.size, image.binary);
                }
                close()
            } catch (error) {
                console.log(error);
            }
        }

    }


    const getOrganizerConst = async () => {
        const result = await getOrganizer("", ["projects", "organizations"])
        setResultGlobalAutocompleteOne(result)
    }

    const getIsPartConst = async () => {
        const result = await getOrganizer("", ["events"])
        setResultGlobalAutocompleteTwo(result)
    }
    return (
        <>
            <Modal show={showEditForm} close={close} title={title} onSubmit={create} style={"h-[calc(100vh-200px)] overflow-y-auto overflow-x-hidden"}>
                <div className="-mt-5">
                    <InputSimple label={"Nom de votre événement"} type={"text"} ctrl={nameCtrl} value={(e) => setName(e)} defaultValue={name} />
                </div>
                <OrganizesThis results={resultGlobalAutocompleteOne} callBackGetList={getOrganizerConst} valueCallBack={(e) => setorganizeValue(e)} editData={data.organizer} />
                <IsPart results={resultGlobalAutocompleteTwo} callBackGetList={getIsPartConst} valueCallBack={(e) => setpartThisValue(e)} editData={data.parent} />
                <TypeEvents valueCallBack={(e) => settype(e)} ctrl={typeCtrl} defaultValue={type} />
                <YesOrNo label={"Rendre l'événement visible publiquement ?"} valueCallBack={(e) => setvisible(e)} />
                <UploadImage valueCallBack={(e) => setimage(e)} editData={data.profilThumbImageUrl} />
                <RecurringEvents valueCallBack={(e) => setRecurrency(e)} ctrlIfNo={recurrencyCtrlIfNo} recurrencyEditValue={recurrencyEditValue} />
                <InputSimple label={"E-mail principal"} type={"email"} ctrl={false} value={(e) => setEmail(e)} />
                <Tags tagsValueCallBack={(e) => setTags(e)} tagsModif={data.tags}/>
                <Textarea label={"Description courte"} rows={2} ctrl={false} value={(e) => setShortDescription(e)} defaultValue={data.shortDescription}/>
                <InputSimple label={"URL principale"} type={"url"} ctrl={false} value={(e) => setUrl(e)} defaultValue={data.url}/>
            </Modal>
        </>
    )
}