import { useEffect, useState } from "preact/hooks";
import Modal from "../../../core/presentation/component/Modal";
import Tags from "../../../news/presentation/component/form/Tags";
import { addImageEvents, createEvent, getOrganizer } from "../../infrastructure/constant/api-endpoints";
import OrganizesThis from "../component/form/OrganizesThis";
import IsPart from "../component/form/IsPart";
import RecurringEvents from "../component/form/RecurringEvents";
import TypeEvents from "../component/form/TypeEvents";
import YesOrNo from "../component/form/YesOrNo";
import InputSimple from "../../../core/presentation/component/input/InputSimple";
import Textarea from "../../../core/presentation/component/input/Textarea";
import UploadImage from "../../../core/presentation/component/input/UploadImage";
import moment from "moment";
import AdressDetaille from "../component/form/AdressDetaille";

export default function FormNewsEvent({ showNewsForm, close, title }) {
    const [tags, setTags] = useState([]);
    const [name, setName] = useState("");
    const [nameCtrl, setNameCtrl] = useState(false);
    const [email, setEmail] = useState("");
    const [emailCtrl, setEmailCtrl] = useState(false);
    const [shortDescription, setShortDescription] = useState("");
    const [organizeValue, setorganizeValue] = useState([]);
    const [partThisValue, setpartThisValue] = useState([]);
    const [visible, setvisible] = useState(true);
    const [image, setimage] = useState("");
    const [type, settype] = useState("");
    const [typeCtrl, settypeCtrl] = useState(false);
    const [recurrency, setRecurrency] = useState(true);
    const [recurrencyCtrlIfNo, setRecurrencyCtrlIfNo] = useState(false);
    const [resultGlobalAutocompleteOne, setResultGlobalAutocompleteOne] = useState([]);
    const [resultGlobalAutocompleteTwo, setResultGlobalAutocompleteTwo] = useState([]);
    const [url, setUrl] = useState("");
    const [urlCtrl, seturlCtrl] = useState(false);
    const [searchValue, setSearchValue] = useState('');
    const [searchValueIspart, setSearchValueIspart] = useState('');

    const create = async () => {
        let result = '';
        if (name == '') {
            setNameCtrl(true)
        } else {
            setNameCtrl(false)
            result += '1';
        }
        if (type == '') {
            settypeCtrl(true)
        } else {
            settypeCtrl(false)
            result += '2';
        }
        if (url != "" && isValidURL(url) == false) {
            seturlCtrl(true)
        } else {
            seturlCtrl(false)
            result += 'u';
        }
        if (email != "" && isValidEmail(email) == false) {
            setEmailCtrl(true)
        } else {
            setEmailCtrl(false)
            result += 'e';
        }
        if (recurrency.recurrency == false) {
            if (recurrency.data.startDate == "" || recurrency.data.endDate == "" || moment(recurrency.data.startDate).isAfter(moment(recurrency.data.endDate))) {
                setRecurrencyCtrlIfNo(true)
            } else {
                setRecurrencyCtrlIfNo(false)
                result += 'f3';
            }
        } else if (recurrency.recurrency == true) {
            if (recurrency.data.length >= 1 && !recurrency.validateMultiData.includes(false)) {
                result += 'y3';
            }
        }
        if (result == "12uef3" || result == "12uey3") {
            try {
                const response = await createEvent(name, organizeValue, partThisValue, type, visible, image, recurrency, email, tags, shortDescription, url);
                if (typeof image === 'object' && response.data.result === true) {
                    await addImageEvents(response.data.id, image.name, image.size, image.binary);
                }
                close()
            } catch (error) {
                // console.log(error);
            }
        }

    }

    const getOrganizerConst = async () => {
        const result = await getOrganizer(searchValue, ["projects", "organizations"])
        setResultGlobalAutocompleteOne(result)
    }

    useEffect(() => {
        let timer;

        if (searchValueIspart != "") {
            timer = setTimeout(() => {
                getIsPartConst();
            }, 1000);
        } else if (searchValue != "") {
            timer = setTimeout(() => {
                getOrganizerConst();
            }, 1000);
        }

        return () => {
            clearTimeout(timer);
        };
    }, [searchValue, searchValueIspart]);

    const getIsPartConst = async () => {
        const result = await getOrganizer(searchValueIspart, ["events"])
        setResultGlobalAutocompleteTwo(result)
    }

    const isValidURL = (url) => {
        const pattern = /^(ftp|http|https):\/\/[^ "]+$/;
        return pattern.test(url);
    }

    const isValidEmail = (email) => {
        const pattern = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        return pattern.test(email);
    }

    return (
        <>
            <Modal show={showNewsForm} close={close} title={title} onSubmit={create} style={"h-[calc(100vh-200px)] overflow-y-auto overflow-x-hidden"}>
                <div className="-mt-5">
                    <InputSimple label={"Nom de votre événement"} type={"text"} ctrl={nameCtrl} value={(e) => setName(e)} msgErreur={"Ce champ est obligatoire."} />
                </div>
                <OrganizesThis results={resultGlobalAutocompleteOne} callBackGetList={getOrganizerConst} valueCallBack={(e) => setorganizeValue(e)} setSearchValue={setSearchValue} />
                <IsPart results={resultGlobalAutocompleteTwo} callBackGetList={getIsPartConst} valueCallBack={(e) => setpartThisValue(e)} setSearchValueIspart={setSearchValueIspart} />
                <TypeEvents valueCallBack={(e) => settype(e)} ctrl={typeCtrl} msgErreur={"Ce champ est obligatoire."}/>
                <YesOrNo label={"Rendre l'événement visible publiquement ?"} valueCallBack={(e) => setvisible(e)} />
                <UploadImage valueCallBack={(e) => setimage(e)} />
                <RecurringEvents valueCallBack={(e) => setRecurrency(e)} ctrlIfNo={recurrencyCtrlIfNo} msgErreur={"Verifier les champs."}/>
                <AdressDetaille addressCountry={(e) => console.log(e)} addressLocallity={(e) => console.log(e)} streetAddress={(e) => console.log(e)} />
                <InputSimple label={"E-mail principal"} type={"email"} ctrl={emailCtrl} value={(e) => setEmail(e)} msgErreur={"exemple@gmail.com"}/>
                <Tags tagsValueCallBack={(e) => setTags(e)} />
                <Textarea label={"Description courte"} rows={2} ctrl={false} value={(e) => setShortDescription(e)} />
                <InputSimple label={"URL principale"} type={"url"} ctrl={urlCtrl} value={(e) => setUrl(e)} msgErreur={"https://exemple.com"}/>
            </Modal>
        </>
    )
}