import React from "react";
import { useContext, useEffect, useMemo, useState } from "preact/hooks";
import StateContext from "../../../core/context/state-context";
import {
  deleteEvent,
  getEvents,
  joinEvent,
  leaveEvent,
  share,
} from "../../infrastructure/constant/api-endpoints";
import CardEvent from "../component/CardEvent";
import EventTimeline from "../component/EventTimeline";
import DeleteEventsConfime from "../component/DeleteEventsConfime";
import ShareEventsConfime from "../component/ShareEventsConfime";
import FormEditEvent from "./FormEditEvent";
import EventListRecurency from "../component/EventListRecurency";
import FilterEvent from "../component/filterEvent";
import SearchForm from "../component/SearchForm";
import { Input, Switch, Typography } from "@material-tailwind/react";
import EventDetails from "../component/EventDetails";
import CustomDrawer from "../../../core/presentation/component/CustomDrawer";
import EventSearchList from "../component/EventSearchList";
import CategorieCarouselGrid from "../component/Categorie/categorieCarouselGrid";
import CategoryDropdown from "../component/Categorie/categoryDropdown";
import CustomDialog from "../../../core/presentation/component/CustomDialog";
import ResetPasswordPage from "../../../core/presentation/component/ResetPasswordPage";


function ListAgenda() {

  const { events, event } = useContext(StateContext);
  const [showEditForm, setShowEditForm] = useState(false);
  const [showDeleteConfirme, setShowDeleteConfirme] = useState(false);
  const [loading, setloading] = useState(false);
  const [showShareConfirme, setshowShareConfirme] = useState(false);
  const [commentValueShare, setcommentValueShare] = useState("");
  const [reason, setreason] = useState("");
  const [isRecurency, setIsRecurency] = useState(false);
  const [idEvents, setidEvents] = useState(null);
  const [dataEvent, setdataEvent] = useState({});
  const [selectedEventType, setSelectedEventType] = useState({});
  const [upcomingEventCount, setUpcomingEventCount] = useState(0);
  const [isOpenDrawer, openAndCloseDrawer] = useState(false);
  const [textSearch, setTextSearch] = useState(null);
  const currentDate = new Date().toISOString().split("T")[0];
  const eventsList = useMemo(() => events.signal.value, [events.signal.value]);
  const selectedEvent = useMemo(() => event.signal.value, [event.signal.value]);

   // we need to move this code
   const [isOpenDialog, setIsOpenDialog] = useState(false);
   const handleOpenDialog = () => setIsOpenDialog((value) => !value);


  const fetchData = async () => {
    try {
      const eventsList = await getEvents(currentDate);
      events.signal.value = eventsList.data;
    } catch (error) {
      console.error("Error fetching events: ", error);
    }
  };

  const handleUpcomingEvent = async () => {
    const oneWeekFromNow = new Date();
    oneWeekFromNow.setDate(oneWeekFromNow.getDate() + 7);
    const futureDate = oneWeekFromNow.toISOString().split("T")[0];
    //
    const eventsSearchList = await getEvents(futureDate);

    const upcomingEvents = eventsSearchList.data.filter(event => {
      const eventStartDate = new Date(event.startDate);
      return eventStartDate > new Date(); // Check if startDate is in the future
    });

    setUpcomingEventCount(upcomingEvents.length);

    return upcomingEvents;
  }

  useEffect(() => {
    fetchData();
    handleUpcomingEvent();
  }, [currentDate, events.signal]);


  const handleOnFilter = async (ts) => { 
    try { 
       if (ts.value === "upcoming") {
          events.signal.value = await handleUpcomingEvent();
       }
       if(ts.value === "current"){
         fetchData(); 
       }
       
    } catch (error) {
      console.error("Error fetching events: ", error);
    }
  }

  const debounce = (func, delay) => {
    let timeoutId;
  
    return function (...args) {
      return new Promise((resolve) => {
        clearTimeout(timeoutId);
        timeoutId = setTimeout(() => {
          resolve(func.apply(this, args));
        }, delay);
      });
    };
  };
  
  const handleOnSearch = debounce(async (e) => {
    var name = e.target.value;
    setTextSearch(name);
    var type = selectedEventType && selectedEventType.value !== undefined ? selectedEventType.value : null;

    // Calculate the date one week from now
    const oneWeekFromNow = new Date();
    oneWeekFromNow.setDate(oneWeekFromNow.getDate() + 7);
    const futureDate = oneWeekFromNow.toISOString().split("T")[0];
    const eventsSearchList = await getEvents(futureDate, name, type);
    events.signal.value = eventsSearchList.data;
  }, 300);


  const handleOnSelectedSearch = async (eventType) => {
    const type = eventType.value;
    const eventsSelectedList = await getEvents(currentDate, null, type);
    events.signal.value = eventsSelectedList.data;
  };

  const handleSwitchValue = (e) => setIsRecurency(e.target.checked);


  const updateEventState = (eventId) => {
    var eventUpdate = events.signal.value.filter((ev) => ev._id.$id === eventId)[0];
    event.signal.value = eventUpdate;
  }

  const joinEventFunction = async (e, type) => {
    await joinEvent(e, type).then(async (res)=> {
      if (res.data.result) {
        await fetchData();
        updateEventState(e);
      }
    });
  };

  const leaveEventFunction = async (e) => {
    await leaveEvent(e).then(async (res) => {
      if(res.data.result){
        await fetchData();
        updateEventState(e);
      };
    });
  };

  const deleteEventFunction = async (e) => {
    setShowDeleteConfirme(true);
    setidEvents(e);
  };

  const deleteConfirmeOui = async () => {
    setloading(true);
    await deleteEvent(idEvents, reason);
    events.signal.value = events.signal.value.filter(
      (event) => event._id.$id != idEvents
    );
    setShowDeleteConfirme(false);
    setloading(false);
  };

  const shareEventFunction = () => setshowShareConfirme(true);

  const openEventDetailsFunction = () => openAndCloseDrawer(!isOpenDrawer);
  
  const shareBtn = async (e) => {
    setloading(true);
    await share(e, commentValueShare, events);
    setshowShareConfirme(false);
    setloading(false);
  };

  const editEventFunction = (e) => {
    setdataEvent(e);
    setShowEditForm(true);
  };

  const eventChild = (eventElement, eventIndex) => {
    return (
      <CardEvent
        key={eventIndex}
        event={eventElement}
        joinEvent={joinEventFunction}
        leaveEvent={leaveEventFunction}
        deleteEvent={deleteEventFunction}
        shareEvent={shareEventFunction}
        dataEvent={(e) => setdataEvent(e)}
        editEvent={editEventFunction}
        openEventDetails={openEventDetailsFunction}
        onSelectedEvent={()=> event.signal.value = eventElement}
      />
    );
  };

  // list events for recurency  
  const eventsRecurency = (
     <div className="px-4">
        <EventListRecurency events={eventsList} eventChild={eventChild} />
     </div>
  );

  // list events for timeline or not recurency
  const eventsTimeline = (
    <EventTimeline
      events={eventsList}
      eventChild={eventChild}
    />
  );

  const eventsGlobal = (
    <EventSearchList
     events={eventsList}
     eventChild={eventChild}
    />
  );


 


  return (
    <>
      <div className="w-full h-full overflow-auto bg-white p-3 rounded drop-shadow-md dark:bg-gray-900 dark:text-gray-400">


        <div className="flex w-auto h-auto cursor-pointer justify-center md:mb-9 mb-3">
          <SearchForm  onSearch={handleOnSearch}/>
        </div>


        <div className="flex items-center justify-between md:px-6 sm:px-0 md:mb-2 mb-5">
          <p className={`${'hidden md:flex sm:hidden ' }text-gray-700 dark:text-gray-300 font-medium md:text-2xl sm:text-xs`}>
            Catégorie
          </p>

            <CategoryDropdown
              onSearch={handleOnSearch}
              onSelectedSearch={handleOnSelectedSearch}
              onResetSelectedSearch={fetchData}
              containerClassName={"md:hidden sm:flex"}
             />

           <Switch
              checked={isRecurency}
              onChange={handleSwitchValue}
              ripple={false}
              className="md:h-full md:w-full sm:h-8 sm:w-8 dark:checked:bg-lime-600 checked:bg-lime-600 bg-gray-300 dark:bg-gray-700"
              containerProps={{
                className: "md:w-11 md:h-6 sm:w-6 sm:h-3",
              }}
              circleProps={{
                className: "before:hidden left-0.5 border-none",
              }}
              label={
                <Typography className={`${
                  'md:font-medium text-gray-700 dark:text-gray-300 md:text-xl text-sm'
                }`}>
                  Événement récurrent
                </Typography>
              }
            />
      </div>


       <CategorieCarouselGrid
          onSelectedSearch={handleOnSelectedSearch} 
          onResetSelectedSearch={fetchData}
          selectedEventType={selectedEventType}
          setSelectedEventType={setSelectedEventType}
          carouselWidth={790} 
        />

        <div className="flex justify-between md:mb-0 mb-3 md:px-6 py-2">
          <div>
            <p  onClick={handleOpenDialog}  className="text-gray-600 dark:text-gray-300 font-medium md:text-2xl sm:text-xl">
              Événements {selectedEventType.label}
            </p>
            <p className="text-gray-500  md:text-xl sm:text-xs">Célébrons l'extraordinaire : Explorez, Participez, Vivez !</p>
          </div>

          <FilterEvent onFilter={handleOnFilter} upcomingEventCount={upcomingEventCount}/>
        </div>

         
         {
         textSearch !== null && textSearch.trim() !== '' 
           ? eventsGlobal
           : isRecurency ? eventsRecurency : eventsTimeline
         }
         
        {/* {isRecurency ? eventsRecurency : eventsTimeline} */}
        {/* {eventsGlobal} */}

      
      </div>

      <DeleteEventsConfime
        title={"Effacer"}
        show={showDeleteConfirme}
        close={() => setShowDeleteConfirme(false)}
        valueTextAreaCallBack={(e) => setreason(e)}
        onSubmit={deleteConfirmeOui}
        isLoading={loading}
      />
      <ShareEventsConfime
        title={"Partager cette contenu avec votre reseau"}
        show={showShareConfirme}
        margin={0}
        close={() => setshowShareConfirme(false)}
        isLoading={loading}
        dataEvent={dataEvent}
        shareBtn={shareBtn}
        commentValue={(e) => setcommentValueShare(e)}
      />
      <FormEditEvent
        title={"Modifier l'evenement"}
        showEditForm={showEditForm}
        close={() => setShowEditForm(false)}
        data={dataEvent}
      />
     
     {/* Event Details */}
     <CustomDrawer 
       isOpenDrawer={isOpenDrawer} 
       openAndCloseDrawer={openEventDetailsFunction}
       openPageTitle={"Ouvrir la page de l'événement"}
       placement={"right"} 
     >
      
       <EventDetails event={selectedEvent} joinEvent={joinEventFunction} leaveEvent={leaveEventFunction} />

       </CustomDrawer>

       {/* test reset password */}
       <CustomDialog size={"md"} isOpenDialog={isOpenDialog} setOpenAndCloseDialog={handleOpenDialog}>
        <i className="fa fa-close cursor-pointer text-4xl text-gray-300" onClick={handleOpenDialog}></i>

        <ResetPasswordPage/>

       </CustomDialog> 

    </>
  );
}

export default ListAgenda;
