import { useEffect, useState } from "preact/hooks";
import { BASE_URL, USER_CONNECTED } from "../../application/constant/common";
import defaultImage from "../../../core/assets/images/defaultPerson.png";

const AppMenu = ({ hideAppMenu }) => {
    const menus = [
        {
            label: "Actualités",
            icon: "fa-regular fa-newspaper",
            link: "/news"
        },
        {
            label: "Agenda",
            icon: "fa-solid fa-calendar-day",
            link: "/agenda"
        },
        {
            label: "Recherche",
            icon: "fa-solid fa-search",
            link: "/search"
        }
    ]

    const [currentPath, setCurrentPath] = useState(window.location.pathname);

    useEffect(() => {
        const handleRouteChange = () => {
            setCurrentPath(window.location.pathname);
        };

        window.addEventListener('popstate', handleRouteChange);

        return () => {
            window.removeEventListener('popstate', handleRouteChange);
        };
    }, []);

    return (
        <>
            <div className={`h-full bg-white rounded-lg overflow-hidden dark:bg-gray-900 lg:w-64 md:w-48 md:flex-col lg:flex text-gray-700 dark:text-gray-200 border-gray-800 ${hideAppMenu ? "absolute lg:relative z-10 lg:static right-0 left-0 -mt-3 md:w-full" : "hidden"}`}>
                <div className="h-full flex-col pt-5 flex">
                    <div className="h-full flex-col flex">
                       
                           {USER_CONNECTED != null &&
                                <nav className="bg-cover bg-top mb-3 md:hidden block">
                                    <div className="p-3 m-2 dark:bg-gray-800 bg-gray-100 rounded-2xl">
                                        <div className="items-center justify-between flex rounded-lg ">
                                            <div className="mr-3 w-fit rounded-full relative">
                                                <img src={BASE_URL + USER_CONNECTED.profilThumbImageUrl} onError={(e) => e.target.src = defaultImage} className="cursor-pointer object-cover btn- h-10 w-10 rounded-full" />
                                            </div>
                                            <div className="ml-0 mr-auto cursor-pointer">
                                                <p className="font-bold text-xs">{USER_CONNECTED.name}</p>
                                                <p className="text-xs"> Voir votre profil </p>
                                            </div>

                                            <div className="w-8 h-8 rounded-full dark:bg-gray-900 flex justify-center items-center">
                                             <i className="fa-solid fa-caret-down"></i>
                                            </div>
                                        </div>
                                    </div>
                                </nav>
                            }

                        <div className="lg:px-4 md:px-2 space-y-4 overflow-y-auto">
                            <nav className="bg-cover space-y-1 bg-top">
                                {
                                    menus.map((menu) => (
                                        <a href={BASE_URL + menu.link} className={`items-center lg:mx-0 md:mx-0 sm:mx-4 mx-4 rounded-lg px-4 py-2.5 text-sm
                          font-medium group  flex cursor-pointer transition-all duration-200
                          ${currentPath === menu.link ? "dark:bg-lime-600 bg-lime-600 text-white" : ""}`}>
                                            <span className="items-center justify-center flex">
                                                <span className="items-center justify-center flex">
                                                    <span className="mr-4 h-5 w-5 items-center justify-center flex flex-shrink-0">
                                                        <span className="items-center justify-center h-full w-full flex">
                                                            <i className={menu.icon}></i>
                                                        </span>
                                                    </span>
                                                </span>
                                            </span>
                                            <span>{menu.label}</span>
                                        </a>
                                    ))
                                }
                            </nav>
                        </div>
                        <div className="mt-auto pb-0">
                            <a href="#" class="mx-4 mt-1 items-center rounded-lg px-4 py-2.5
                          text-sm font-medium group  flex cursor-pointer transition-all duration-200
                          hover:bg-gray-800">
                                <span class="items-center justify-center flex">
                                    <span class="items-center justify-center flex">
                                        <span class="mr-4 items-center justify-center flex">
                                            <span class="items-center justify-center h-full w-full flex">
                                                <i class="fa-solid fa-right-from-bracket"></i>
                                            </span>
                                        </span>
                                    </span>
                                </span>
                                <span>Deconnecter</span>
                            </a>
                            {USER_CONNECTED != null &&
                                <nav className="bg-cover bg-top md:block hidden">
                                    <div className="mt-4 px-2 py-3 border-t border-lime-600">
                                        <div className="items-center justify-between flex rounded-lg ">
                                            <div className="mr-3 w-fit rounded-full relative">
                                                <img src={BASE_URL + USER_CONNECTED.profilThumbImageUrl} onError={(e) => e.target.src = defaultImage} className="cursor-pointer object-cover btn- h-10 w-10 rounded-full" />
                                            </div>
                                            <div className="ml-0 mr-auto cursor-pointer">
                                                <p className="font-bold text-xs">{USER_CONNECTED.name}</p>
                                                <p className="text-xs">{USER_CONNECTED.email}</p>
                                            </div>
                                        </div>
                                    </div>
                                </nav>
                            }
                        </div>
                    </div>
                </div>
            </div>

        </>
    )
}

export default AppMenu;