import PropTypes from 'prop-types';

function CardTile({ title, subtitle, trailing,  leading, children, backgroundColor, borderColor, textColor, onClick, hoverColor }) {
    return ( 
        <div onClick={onClick} className={`block w-auto rounded-lg ${hoverColor} ${backgroundColor ?? "bg-gray-100 dark:bg-gray-600"} shadow-[0_2px_15px_-3px_rgba(0,0,0,0.07),0_10px_20px_-2px_rgba(0,0,0,0.04)]`}>
        <div className={`border-b-2 flex justify-between ${borderColor ?? "border-gray-500"} px-2 py-2  ${textColor ?? "dark:text-gray-50"}`}>
          <div className="flex flex-row items-center justify-start">
            {leading}
           <div className="flex-col ml-4">
              <h5> {title} </h5>
              {subtitle && <p className="text-xs dark:text-gray-300"> {subtitle} </p>}
           </div>
          </div>
           {trailing}
        </div>
        <div className="p-2 space-y-3">
            {children}   
        </div>
      </div>
     );
}

CardTile.propTypes = {
  title: PropTypes.string,
  subtitle: PropTypes.string,
  trailing: PropTypes.elementType,
  leading: PropTypes.element,
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  backgroundColor: PropTypes.string,
  borderColor: PropTypes.string,
  textColor: PropTypes.string,
  onClick: PropTypes.func,
  hoverColor: PropTypes.string,
};

export default CardTile;