import { Drawer } from "@material-tailwind/react";
import MiniCardIcon from "./MiniCardIcon";
import PropTypes from 'prop-types';

function CustomDrawer({ isOpenDrawer, openAndCloseDrawer, openPageTitle, placement, children, iconActionPage, overflowType }) {

  return (
    <Drawer
      overlay={true}
      size={550}
      placement={placement}
      open={isOpenDrawer}
      onClose={openAndCloseDrawer}
      className={`rounded-bl-lg rounded-tl-lg px-4 py-2 bg-gray-200 dark:bg-gray-900 opacity-100 w-full h-full ${overflowType == undefined ? "overflow-auto" : overflowType}`}
    >
      <div className="flex items-center justify-between">
        <MiniCardIcon icon={"fa fa-close"} backgroundColor={"bg-lime-600 dark:bg-gray-600 text-white"} onClick={openAndCloseDrawer} />
        {
          openPageTitle && (
            <div className="inline-flex w-auto h-8 mr-0 px-1 text-sm space-x-1 items-center cursor-pointer justify-center bg-lime-600 text-white dark:text-gray-300 transition-colors duration-150 dark:bg-gray-600 rounded-lg focus:shadow-outline">
              <span> {openPageTitle} </span>
              {iconActionPage == undefined || iconActionPage == true ?
                <i class="fa-solid fa-arrow-up-right-from-square"></i> :
                null
              }
            </div>
          )
        }
      </div>

      {children}

    </Drawer>

  );
}

CustomDrawer.propTypes = {
  openPageTitle: PropTypes.string.isRequired,
  children: PropTypes.node.isRequired,
  placement: PropTypes.string
};

export default CustomDrawer;