import React from "react";
import {
  convertToFrenchDay,
  convertToFrenchMonth,
} from "../../application/helpers/dateTime-converter";
import PropTypes from 'prop-types';

const DateRenderer = ({ date, isAllDate }) => {
  const dayOfWeek = date.toLocaleDateString("en-US", { weekday: "short" });
  const month = date.toLocaleDateString("en-US", { month: "short" });
  const year = date.getFullYear();
  const dayOfMonth = date.getDate();
  const startTime = date.toLocaleTimeString("en-US", {
    hour: "numeric",
    minute: "numeric",
    hour12: true,
  });

  return (
    <div className="flex flex-row space-x-2 w-auto h-auto">
      <div className="dark:bg-gray-600 w-12 h-12 rounded-lg border border-gray-600">
        <div className="h-5 w-auto bg-gray-700 text-center rounded-tl-lg rounded-tr-lg">
          <span className="text-xs text-white dark:text-white"> {month.toUpperCase()}. </span>
        </div>

        <div className="w-auto h-auto items-center justify-center">
          <p className="text-center text-gray-800 dark:text-white text-lg"> {dayOfMonth} </p>
        </div>
      </div>

      {isAllDate ? (
        <div className="flex-col">
          <p className="text-gray-800 dark:text-white text-sm">
            {convertToFrenchDay(dayOfWeek)} {dayOfMonth}{" "}
            {convertToFrenchMonth(month)} {year}
          </p>
          <p className="text-gray-700 dark:text-gray-300 text-sm">{startTime}</p>
        </div>
      ) : null}
    </div>
  );
};

DateRenderer.propTypes = {
  date: PropTypes.instanceOf(Date).isRequired,
  isAllDate: PropTypes.bool.isRequired,
};

export default DateRenderer;
