import React from 'react'
import PropTypes from 'prop-types';

function Modal({ children, show, close, title, onSubmit, isLoading, style, width, onSubmitColor, onSubmitText, onSubmitShow, headerShow, headerColor, footerShow }) {
    return (
        <>
            {show && (
                <div className="fixed inset-0 flex bg-gray-800 bg-opacity-50 transition-opacity items-center justify-center z-50 backdrop-blur-sm">
                    <div className="absolute inset-0 bg-gray-900 opacity-60"></div>
                    <div className={`${width == undefined ? `w-5/6 md:w-2/5` : width} relative bg-white rounded-lg shadow dark:bg-gray-900 m-5`}>
                        {headerShow == undefined &&
                            <div className={`flex justify-between p-4 border-b rounded-t dark:border-gray-600 ${headerColor == undefined ? `` : headerColor}`}>
                                <h3 className="text-xl font-semibold text-gray-900 dark:text-gray-300">
                                    {title}
                                </h3>
                                <i onClick={close} className="fa-solid fa-xmark fa-xl mt-3 ml-2 cursor-pointer text-gray-900 dark:text-gray-300"></i>
                            </div>
                        }
                        <div className={`p-6 ${style}`}>
                            {children}
                        </div>
                        {footerShow == undefined &&
                            <div className={`${footerShow == `border-t` ? `` : width} flex justify-between p-4 dark:border-gray-600`}>
                                <button onClick={close} type="button" className="text-gray-500 bg-white hover:bg-gray-100 focus:ring-4 focus:outline-none focus:ring-gray-200 rounded-lg border border-gray-200 text-sm font-medium px-5 py-2.5 hover:text-gray-900 focus:z-10 dark:bg-gray-700 dark:text-gray-300 dark:border-gray-500 dark:hover:text-gray-200 dark:hover:bg-gray-600 dark:focus:ring-gray-600">Fermer</button>
                                {isLoading ? (
                                    <button
                                        disabled={true}
                                        type="button"
                                        className="text-gray-200 bg-green-600 hover:bg-green-800 focus:ring-4 focus:outline-none focus:ring-green-300 dark:focus:ring-green-800 font-medium rounded-lg text-sm inline-flex items-center px-5 py-2.5 text-center mr-2"
                                    >
                                        <div className="loader">
                                            <svg
                                                aria-hidden="true"
                                                className="w-8 h-5 mr-2 ml-2 text-gray-200 animate-spin dark:text-gray-300 fill-gray-600"
                                                viewBox="0 0 100 101"
                                                fill="none"
                                                xmlns="http://www.w3.org/2000/svg"
                                            >
                                                <path
                                                    d="M100 50.5908C100 78.2051 77.6142 100.591 50 100.591C22.3858 100.591 0 78.2051 0 50.5908C0 22.9766 22.3858 0.59082 50 0.59082C77.6142 0.59082 100 22.9766 100 50.5908ZM9.08144 50.5908C9.08144 73.1895 27.4013 91.5094 50 91.5094C72.5987 91.5094 90.9186 73.1895 90.9186 50.5908C90.9186 27.9921 72.5987 9.67226 50 9.67226C27.4013 9.67226 9.08144 27.9921 9.08144 50.5908Z"
                                                    fill="currentColor"
                                                />
                                                <path
                                                    d="M93.9676 39.0409C96.393 38.4038 97.8624 35.9116 97.0079 33.5539C95.2932 28.8227 92.871 24.3692 89.8167 20.348C85.8452 15.1192 80.8826 10.7238 75.2124 7.41289C69.5422 4.10194 63.2754 1.94025 56.7698 1.05124C51.7666 0.367541 46.6976 0.446843 41.7345 1.27873C39.2613 1.69328 37.813 4.19778 38.4501 6.62326C39.0873 9.04874 41.5694 10.4717 44.0505 10.1071C47.8511 9.54855 51.7191 9.52689 55.5402 10.0491C60.8642 10.7766 65.9928 12.5457 70.6331 15.2552C75.2735 17.9648 79.3347 21.5619 82.5849 25.841C84.9175 28.9121 86.7997 32.2913 88.1811 35.8758C89.083 38.2158 91.5421 39.6781 93.9676 39.0409Z"
                                                    fill="currentColor"
                                                />
                                            </svg>
                                        </div>
                                    </button>
                                ) : (
                                    (onSubmitShow === undefined || onSubmitShow === true) ?
                                        <button
                                            onClick={onSubmit}
                                            type="button"
                                            className={onSubmitColor === undefined
                                                ? "bg-green-600 hover:bg-green-800 focus:ring-green-300 dark:focus:ring-green-800 text-gray-200 focus:ring-4 focus:outline-none font-medium rounded-lg text-sm inline-flex items-center px-5 py-2.5 text-center mr-2"
                                                : onSubmitColor === "danger"
                                                    ? "bg-red-600 hover:bg-red-800 focus:ring-red-300 dark:focus:ring-red-800 text-gray-200 focus:ring-4 focus:outline-none font-medium rounded-lg text-sm inline-flex items-center px-5 py-2.5 text-center mr-2"
                                                    : null
                                            }

                                        >
                                            {onSubmitText === undefined ? "Envoyer" : onSubmitText}
                                        </button>
                                        : (
                                            null
                                        )
                                )}
                            </div>
                        }
                    </div>
                </div>
            )}
        </>
    )
}

Modal.propTypes = {
    children: PropTypes.node.isRequired,
    show: PropTypes.bool.isRequired,
    title: PropTypes.string.isRequired,
    isLoading: PropTypes.bool,
    style: PropTypes.string,
    width: PropTypes.string,
    onSubmitColor: PropTypes.string,
    onSubmitText: PropTypes.string,
    onSubmitShow: PropTypes.bool,
};

export default Modal