import { BASE_URL, USER_CONNECTED } from "../../application/constant/common";
import logo from "../../assets/images/logo-min.png";

import ThemeSwicther from './ThemeSwicther';
import { useState } from "preact/hooks";
import defaultImage from "../../../core/assets/images/defaultPerson.png";

const Navbar = ({ onSearchKeyUp, hideAppMenu }) => {
    const [menuHidden, setmenuHidden] = useState(false)
    const handleSearchKeyUp = (e) => {
        onSearchKeyUp ? onSearchKeyUp(e.target.value) : null
    };

    return (
        <>
            <div className="w-full bg-white dark:bg-gray-900 dark:text-gray-200 text-gray-900">
                <div className="mx-auto h-16 items-center justify-between px-4 flex">
                    <a href={BASE_URL + "/news"}>
                        <img src={logo} className="h-5 md:h-10 md:ml-2 "/>
                    </a>
                    <div className="cursor-pointer lg:invisible md:visible" onClick={() => hideAppMenu(setmenuHidden(!menuHidden))}>
                        <i className={`fa-solid ${menuHidden ? "fa-bars-staggered" : "fa-bars"} ml-3 mt-2`}></i>
                    </div>
                    <div className="ml-40 pl-3 mr-auto lg:block relative hidden max-w-xs invisible">
                        <span className="pl-5 absolute inset-y-0 left-0 flex items-center">
                            <i className="fa-solid fa-search text-gray-500 mt-1"></i>
                        </span>
                        <input
                            type="search"
                            className="border border-gray-700 focus:border-indigo-600
                         focus:ring-indigo-600 text-gray-300 w-full rounded-lg bg-gray-800 px-3 py-2 pb-2 pl-8 pt-2 sm:text-sm"
                            placeholder="Rechercher..."
                            onChange={handleSearchKeyUp}
                        />
                    </div>
                    <div className="ml-auto items-center justify-end md:space-x-6 flex space-x-3">
                        <ThemeSwicther />
                        <div className="relative">
                            <p className="rounded-full bg-gray-200 dark:bg-gray-800 pb-1 pl-1 pr-1 pt-1 text-gray-800 dark:text-gray-300 transition-all duration-200
                      hover:bg-gray-700 hover:text-gray-300 focus:outline-none">
                                <span className="items-center justify-center flex">
                                    <span className="items-center justify-center flex">
                                        <span className="h-6 w-6 items-center justify-center flex">
                                            <span className="items-center justify-center h-full w-full flex">
                                                <i className="fa-solid fa-bell"></i>
                                            </span>
                                        </span>
                                    </span>
                                </span>
                            </p>
                            {/* <p className="items-center rounded-full bg-indigo-600 px-1.5 py-0.5 text-xs font-semibold text-gray-200 absolute
                      -right-1 -top-px inline-flex">2</p> */}
                        </div>
                        <a href={USER_CONNECTED != null ? BASE_URL + "/profile" : "javascript:void(0)"} className="items-center justify-center relative cursor-pointer md:flex hidden">
                            <img src={USER_CONNECTED != null && BASE_URL + USER_CONNECTED.profilImageUrl} onError={(e) => e.target.src = defaultImage} className="object-cover btn- mr-2 h-9 w-9 rounded-full bg-gray-300 dark:bg-gray-700" />
                            <p className="text-sm font-semibold">{USER_CONNECTED != null && USER_CONNECTED.name}</p>
                        </a>

                    </div>
                </div>
            </div>
        </>
    )
}


export default Navbar;