import { useState } from "preact/hooks";
import { passwordRecovery } from "../../../agenda/infrastructure/constant/api-endpoints";
import logo from "../../assets/images/logo-min.png";
import { Button } from "@material-tailwind/react";

function ResetPasswordPage() {
  const [email, setEmail] = useState("");
  const [isSuccess, setIsSuccess] = useState(false);

  const isValidEmail = (email) => {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
  };

  const onChange = ({ target }) => {
    const newEmail = target.value;
    setEmail(newEmail);
  };

  const handlePasswordRecovery = async () => {
    await passwordRecovery(email, "password").then((res) => {
      if (res.data.result) {
        setIsSuccess(true);
      }
    });
  };

  const successWidgets = (
    <div className="sm:my-20">
      <div className="flex sm:flex-row flex-col justify-center items-center sm:m-auto space-y-6">
        <div className="relative sm:w-1/2 h-full bg-gray-700 rounded-3xl sm:mr-8 sm:px-4 sm:py-10 flex flex-col space-x-4 items-center">
          <p className="text-gray-100 font-medium text-center px-7 py-2 sm:text-2xl text-xs">
            {" "}
            UN NOUVEAU MOT DE PASSE VOUS A ÉTÉ ENVOYÉ SUR VOTRE BOITE MAIL{" "}
          </p>
          <i className="fa fa-envelope sm:text-9xl text-3xl text-gray-500"></i>
          <br />
          <br />
          <div className="absolute sm:-bottom-14 -bottom-5 left-1/2 transform -translate-x-1/2 w-16 h-16  sm:w-36 sm:h-36 rounded-full flex items-center justify-center bg-gray-600">
            <i className="fa fa-check text-lime-600 sm:text-8xl text-4xl"></i>
          </div>
        </div>

        <div className="sm:w-1/2 h-full bg-gray-700 rounded-3xl flex flex-col p-3 space-y-3.5">
          <div className="flex flex-row items-center space-x-5">
            <i className="fa fa-check-circle text-lime-600"></i>
            <div className="flex flex-col">
              <p className="text-gray-100 font-medium">
                {" "}
                VOUS Y TROUVEREZ VOTRE MOT DE PASSE TEMPORAIRE{" "}
              </p>
              <p className="text-gray-300 text-sm underline">
                {" "}
                AFIN DE VOUS CONNECTER{" "}
              </p>
              <div className="flex space-x-2">
                <i class="fa fa-lock text-gray-50 text-xs mt-1"></i>
                <span className="text-sm text-gray-50">
                  {" "}
                  Ensuite, vous serez libre de changer votre mot de passe sur
                  votre page de profil.{" "}
                </span>
              </div>
            </div>
          </div>

          <div className="flex flex-row items-center space-x-5">
            <i className="fa fa-info-circle text-lime-600"></i>
            <div className="flex flex-col">
              <p className="text-gray-100 font-medium"> COMMENT FAIRE ? </p>
              <div className="flex space-x-2">
                <i class="fa fa-link text-gray-50 text-xs mt-1"></i>
                <span className="text-sm text-gray-50">
                  {" "}
                  Allez sur votre page de profil{" "}
                </span>
              </div>
              <div className="flex space-x-2">
                <i class="fa fa-hand-pointer text-sm text-gray-50"></i>
                <span className="text-sm text-gray-50">
                  {" "}
                  Cliquez sur le bouton de paramêtres dans le menu sous votre
                  bannière.
                </span>
              </div>
            </div>
          </div>

          <div className="border-b border-gray-600"></div>

          <div className="flex space-x-2">
            <i class="fa fa-list text-sm text-gray-50"></i>
            <span className="text-sm text-gray-50">
              {" "}
              Ensuite cliquez sur l'onglet 'Changer mon mot de passe'.
            </span>
          </div>

          <div className="border-b border-gray-600"></div>

          <div className="flex space-x-2">
            <i class="fa fa-unlock text-sm text-gray-50"></i>
            <span className="text-sm text-gray-50">
              {" "}
              En quelques secondes, vous aurez enregistré votre nouveau mot de
              passe de connexion.
            </span>
          </div>

          <div className="border-b border-gray-600"></div>
        </div>
      </div>
    </div>
  );
    
  const resetWidget = (
    <div className="flex flex-col justify-center items-center mt-16">
      <img className="w-20 h-20" src={logo} />
      <span className="md:text-3xl dark:text-gray-300 text-gray-100 w-2/3 text-center mt-7">
        {" "}
        Indiquez l'adresse e-mail liée à votre compte afin de récupérer votre
        mot de passe.{" "}
      </span>

      <div className="mt-10 relative flex w-full max-w-[28rem]">
        <div className="relative w-full ">
          <input
            type="email"
            label="Email Address"
            value={email}
            onChange={onChange}
            className="block p-3 w-full text-sm text-gray-600 bg-white rounded-lg border-l-2 border border-gray-300 dark:bg-gray-800 dark:border-l-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 focus:outline-none dark:rounded-l-lg"
            placeholder="Email Address"
          />

          <div className="absolute top-0 right-0 h-full p-3 text-sm font-medium text-gray-200 bg-lime-700 rounded-r-lg focus:ring-4 focus:outline-none dark:bg-lime-600">
            <i className="fa fa-envelope"></i>
            <span className="sr-only"> Email Address </span>
          </div>
        </div>
      </div>

      <Button
        color={isValidEmail(email) ? "lime" : "gray"}
        disabled={!isValidEmail(email)}
        className="mt-8 rounded text-white cursor-pointer"
        onClick={handlePasswordRecovery}
      >
        Valider
      </Button>
    </div>
  );

  return (
    <>
     { isSuccess ? successWidgets : resetWidget }
    </>
  );
}

export default ResetPasswordPage;
