import { useEffect, useState } from 'preact/hooks';
import React from 'react';
import PropTypes from 'prop-types';

function Select({ label, type, ctrl, value, defaultValue, list }) {

    const [inputValue, setInputValue] = useState();

    useEffect(() => {
        setInputValue(defaultValue == undefined ? "" : defaultValue)
    }, [defaultValue])

    const handleChange = (e) => {
        setInputValue(e.target.value);
        value(e.target.value);
    };

    return (
        <div className="mb-4 mt-4">
            <label
                className={`block text-sm font-medium ${ctrl === false ? `text-gray-900 dark:text-gray-300` : `text-red-700 dark:text-red-500`
                    }`}
            >
                {label}
            </label>
            <select
                value={type}
                onChange={handleChange}
                id="typeEvents"
                className={`${ctrl === false
                    ? 'block w-full p-3 pl-2 mt-2 text-sm text-gray-900 dark:text-gray-300 border border-gray-300 dark:bg-gray-800 dark:border-gray-600 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 rounded-lg dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none'
                    : 'w-full p-3 pl-2 mt-2 bg-red-50 border border-red-500 text-red-900 placeholder-red-700 text-sm rounded-lg focus:ring-red-500 dark:bg-gray-700 focus:border-red-500 block dark:text-red-500 dark:placeholder-red-500 dark:border-red-500 outline-none'
                    }`}
            >
                <option value="" disabled>Choisir un pays</option>
                {list.map(({ name, code }) => {
                    return (
                        <option value={code}>{name}</option>
                    );
                })}
            </select>
        </div>
    );
}

Select.propTypes = {
    label: PropTypes.string.isRequired,
    type: PropTypes.string,
    ctrl: PropTypes.bool,
    value: PropTypes.func.isRequired,
    defaultValue: PropTypes.string,
    list: PropTypes.array
  };

export default Select;
