import React, { useState } from 'react';
import logo from "../../../../core/assets/images/logo-min.png";
import { BASE_URL } from '../../../application/constant/common';
import PropTypes from 'prop-types';

function UploadImage({ valueCallBack, editData }) {
    const [selectedImage, setSelectedImage] = useState(editData == undefined ? null : BASE_URL + editData);
    const handleImageChange = (e) => {
        const file = e.target.files[0];
        if (file) {
            const reader = new FileReader();
            reader.onload = () => {
                setSelectedImage(reader.result);
            };
            reader.readAsDataURL(file);
            valueCallBack({ "name": file.name, "size": file.size, "binary": file })
        }
    };

    return (
        <div className='mt-4'>
            <label className='block text-sm font-medium text-gray-900 dark:text-gray-300 mb-2'>Vos images ici</label>
            <div className="flex items-center space-x-6">
                <div className="shrink-0">
                    <img
                        id="preview_img"
                        className="h-16 w-16 object-cover rounded-lg"
                        src={selectedImage || logo}
                        alt="Current profile photo"
                    />
                </div>
                <label className="block">
                    <input
                        type="file"
                        accept="image/*"
                        className="block w-full text-sm text-slate-500
                                file:mr-4 file:py-5 file:px-4
                                file:rounded-lg file:border-0
                                file:text-sm file:font-semibold
                                file:bg-violet-50 
                                dark:file:bg-gray-700
                                file:text-gray-900
                                file:dark:text-gray-300
                                cursor-pointer
                                hover:file:bg-violet-100"
                        onChange={handleImageChange}
                        title={selectedImage == null ? "Aucun fichier choisi" : "Fichier sélectionné"}
                    />
                </label>
            </div>
        </div>
    );
}


UploadImage.propTypes = {
    valueCallBack: PropTypes.func.isRequired,
    editData: PropTypes.string,
};

export default UploadImage;
