import axios from "axios"
import { BASE_URL, ELEMENT_TYPE, USER_CONNECTED } from "../../../core/application/constant/common"
import { GET_NEWS, GET_COMMENTS, ADD_COMMENTS, ADD_NEWS, DELETE_NEWS, ADD_ACTION, DELETE_COMMENTS, UPDATE_COMMENTS, ADD_IMAGE_NEWS, DELETE_IMAGE_NEWS, ADD_FILE_NEWS, DELETE_FILE_NEWS, UPDATE_NEWS, SHARE_NEWS, SEARCH_TAGS } from "../constant/api-endpoints";

export const getNews = (dateLimit, searchName) => {
    const params2 = new URLSearchParams();
    params2.append('isLive', true);
    params2.append('type', ELEMENT_TYPE.citoyens);
    params2.append('id', USER_CONNECTED.id);
    params2.append('json', true);

    const params = new FormData()
    params.append("dateLimit", dateLimit !== undefined ? dateLimit : 0);
    params.append("search[name]", searchName !== undefined ? searchName : "");


    return axios.post(BASE_URL + GET_NEWS + "?" + params2.toString(), params).then(({ data }) => {
        const news = [];
        Object.keys(data.news).forEach(id => {
            const item = data.news[id];

            item.author.profilThumbImageUrl = BASE_URL + item.author.profilThumbImageUrl;

            if (item?.mediaImg?.images) {
                item.mediaImg.images = item.mediaImg.images.map(image => {
                    image.imagePath = BASE_URL + image.imagePath
                    return image;
                })
            }

            news.push({
                id,
                ...item
            })
        })

        return Promise.resolve(news)
    })
}

export const searchTags = (q) => {
    const params = {
        q: q
    }

    return axios.get(BASE_URL + SEARCH_TAGS, { params }).then(({ data }) => {
        return Promise.resolve(data)
    })
}

export const getComments = (paramsId) => {
    const params = {
        json: true
    }

    return axios.get(BASE_URL + GET_COMMENTS + paramsId, { params }).then(({ data }) => {
        const comments = [];
        Object.keys(data).forEach(id => {
            const item = data[id];
            item.author.profilThumbImageUrl = BASE_URL + item.author.profilThumbImageUrl;
            comments.push({
                id,
                ...item
            })
        })

        return Promise.resolve(comments)
    })
}

export const addComments = (text, contextId, parentCommentId) => {
    const params = new URLSearchParams();
    params.append('parentCommentId', parentCommentId);
    params.append('text', text);
    params.append('contextId', contextId);
    params.append('contextType', 'news');
    params.append('argval', "");
    params.append('path', "");

    return axios.post(BASE_URL + ADD_COMMENTS, params)
};

export const addNews = (news, scope, markdownActive, parentId, countImg, idImage, countFile, idFile, countTags, tags) => {

    const params = new URLSearchParams();
    params.append('text', news);
    params.append('scope', scope);
    params.append('markdownActive', markdownActive);
    params.append('parentId', parentId);
    params.append('parentType', "citoyens");
    params.append('type', "news");
    if (countImg > 0) {
        params.append('mediaImg[countImages]', countImg);
        for (let i = 0; i < countImg; i++) {
            params.append('mediaImg[images][]', idImage[i]);
        }
    }
    if (countFile > 0) {
        params.append('mediaFile[countFiles]', countFile);
        for (let i = 0; i < countFile; i++) {
            params.append('mediaFile[files][]', idFile[i]);
        }
    }
    if (countTags > 0) {
        for (let i = 0; i < countTags; i++) {
            params.append('tags[]', tags[i]);
        }
    }

    return axios.post(BASE_URL + ADD_NEWS, params)
}

export const deleteNews = (id) => {
    const params = {
        isLive: true,
    }
    return axios.delete(BASE_URL + DELETE_NEWS + id, params)
}

export const addaction = (id, reaction, collection) => {
    const params = new URLSearchParams();
    params.append('id', id);
    params.append('collection', collection);
    params.append('action', 'vote');
    params.append('details[status]', reaction);

    return axios.post(BASE_URL + ADD_ACTION, params)
}

export const addActionSignaler = (id, collection, reason, comment) => {
    const params = new URLSearchParams();
    params.append('id', id);
    params.append('collection', collection);
    params.append('action', 'reportAbuse');
    params.append('details[reason]', reason);
    params.append('details[comment]', comment);

    return axios.post(BASE_URL + ADD_ACTION, params)
}

export const deleteCommments = (id) => {
    return axios.delete(BASE_URL + DELETE_COMMENTS + id)
}

export const updateComment = (id, text) => {
    const params = new URLSearchParams();
    params.append('id', id);
    params.append('params[text]', text);

    return axios.post(BASE_URL + UPDATE_COMMENTS, params)
}

export const addImageInNews = (binaryData) => {
    const params = new FormData();
    params.append('newsImage', binaryData);

    return axios.post(BASE_URL + ADD_IMAGE_NEWS + USER_CONNECTED.id + '/input/newsImage/docType/image/contentKey/slider', params)
}

export const deleteImageInNews = (idImage) => {
    const params = new URLSearchParams();
    params.append('parentId', USER_CONNECTED.id);
    params.append('parentType', 'citoyens');
    params.append('path', 'communecter');
    params.append('ids[]:', idImage);

    return axios.post(BASE_URL + DELETE_IMAGE_NEWS + USER_CONNECTED.id, params)
}

export const addFileInNews = (binaryData) => {
    const params = new FormData();
    params.append('newsFile', binaryData);

    return axios.post(BASE_URL + ADD_FILE_NEWS + USER_CONNECTED.id + '/input/newsFile/docType/file', params)
}

export const deleteFileInNews = (idFile) => {
    const params = new URLSearchParams();
    params.append('parentId', USER_CONNECTED.id);
    params.append('parentType', 'citoyens');
    params.append('path', 'communecter');
    params.append('ids[]:', idFile);

    return axios.post(BASE_URL + DELETE_FILE_NEWS + USER_CONNECTED.id, params)
}

export const updateNews = (idNews, news, scope, markdownActive, parentId, countImg, idImage, countFile, idFile, countTags, tags) => {
    const params = new URLSearchParams();
    params.append('text', news);
    params.append('scope', scope);
    params.append('markdownActive', markdownActive);
    params.append('parentId', parentId);
    params.append('parentType', "citoyens");
    params.append('type', "news");
    if (countImg > 0) {
        params.append('mediaImg[countImages]', countImg);
        for (let i = 0; i < countImg; i++) {
            params.append('mediaImg[images][]', idImage[i]);
        }
    }
    if (countFile > 0) {
        params.append('mediaFile[countFiles]', countFile);
        for (let i = 0; i < countFile; i++) {
            params.append('mediaFile[files][]', idFile[i]);
        }
    }
    if (countTags > 0) {
        for (let i = 0; i < countTags; i++) {
            params.append('tags[]', tags[i]);
        }
    }
    params.append('idNews', idNews);


    return axios.post(BASE_URL + UPDATE_NEWS, params)
}

export const shareNews = (id, childType, connectType, comment, parentType) => {
    const params = new URLSearchParams();
    params.append('parentId', id);
    params.append('childId', USER_CONNECTED.id);
    params.append('childType', childType);
    params.append('connectType', connectType);
    params.append('comment', comment);
    params.append('parentType', parentType);

    return axios.post(BASE_URL + SHARE_NEWS, params)
};

