import React from 'react'
import Modal from '../../../core/presentation/component/Modal'
import { Carousel } from '@material-tailwind/react'
import { BASE_URL, USER_CONNECTED } from '../../../core/application/constant/common';
import Article from './article';
import CommentList from '../container/CommentList';
import StateContext from '../../../core/context/state-context';
import { useContext, useEffect } from 'preact/hooks';
import { getComments } from '../../infrastructure/api/news-api';

function DetailleNews({ show, close, element, addReactionAction }) {
    const { articleComments } = useContext(StateContext);

    useEffect(async () => {
        const commentsConst = await getComments(element.id);
        articleComments.signal.value = commentsConst;
    }, [])

    return (
        <Modal show={show} title={"title"} close={close} isLoading={false} width={"w-full"} headerShow={false} footerShow={false}>
            <div className='flex flex-col w-full overflow-hidden md:flex-row h-[30rem]'>
                <div className='w-full md:w-3/5'>
                    <div className='flex justify-between'>
                        <div className="relative">
                            <i onClick={close} style={{ fontSize: '25px' }} class="fa-solid fa-xmark text-lime-600 hover:text-gray-600 dark:text-gray-300 cursor-pointer hover:dark:text-lime-600"></i>
                        </div>
                        <div className='flex justify-center items-center mt-[3.5rem] mb-10'>
                            <Carousel
                                className="rounded-xl relative"
                                navigation={({ setActiveIndex, activeIndex, length }) => (
                                    <div className="absolute left-0 right-0 bottom-0.5 flex justify-center z-50 gap-2">
                                        {new Array(length).fill("").map((_, i) => (
                                            <span
                                                key={i}
                                                className={`block h-1 w-4 cursor-pointer rounded-2xl transition-all bg-gray-300 ${activeIndex === i ? "w-8 dark:bg-lime-600" : ""
                                                    }`}
                                                onClick={() => setActiveIndex(i)}
                                            />
                                        ))}
                                    </div>
                                )}
                                prevArrow={({ handlePrev }) => (
                                    <button
                                        onClick={handlePrev}
                                        className="absolute left-0 top-1/2 transform -translate-y-1/2 bg-transparent h-full z-50 dark:text-gray-300 hover:dark:text-gray-200"
                                    >
                                        <i style={{ fontSize: 22 }} class="fa-solid fa-chevron-left bg-lime-600 dark:bg-gray-600 px-4 py-3 rounded-full hover:bg-gray-600 dark:hover:bg-lime-600"></i>
                                    </button>
                                )}
                                nextArrow={({ handleNext }) => (
                                    <button
                                        onClick={handleNext}
                                        className="absolute right-0 top-1/2 transform -translate-y-1/2 bg-transparent h-full z-50 dark:text-gray-300 hover:dark:text-gray-200"
                                    >
                                        <i style={{ fontSize: 22 }} class="fa-solid fa-chevron-right bg-lime-600 dark:bg-gray-600 px-4 py-3 rounded-full hover:bg-gray-600 dark:hover:bg-lime-600"></i>
                                    </button>
                                )}
                            >
                                {element.mediaImg && element.mediaImg.images.map(({ imagePath }) => (
                                    <div className="flex justify-center">
                                        <img
                                            key={imagePath}
                                            src={imagePath}
                                            className="h-96 object-cover w-5/6 rounded-lg"
                                        />
                                    </div>
                                ))}
                            </Carousel>

                        </div>
                        <div className="flex flex-col space-y-4 pr-2 pt-2">
                            <i style={{ fontSize: '20px' }} class="fa-solid fa-magnifying-glass-plus text-lime-600 hover:text-gray-600 dark:text-gray-300 cursor-pointer hover:dark:text-lime-600"></i>
                            <i style={{ fontSize: '20px' }} class="fa-solid fa-magnifying-glass-minus text-lime-600 hover:text-gray-600 dark:text-gray-300 cursor-pointer hover:dark:text-lime-600"></i>
                            <i style={{ fontSize: '20px' }} class="fa-solid fa-up-right-and-down-left-from-center text-lime-600 hover:text-gray-600 dark:text-gray-300 cursor-pointer hover:dark:text-lime-600"></i>
                        </div>
                    </div>

                </div>
                <div className='w-full md:w-2/5 overflow-y-auto overflow-x-hidden'>
                    <Article
                        mode={"noImage"}
                        element={element}
                        parentId={USER_CONNECTED.id}
                        dataReaction={(e) => addReactionAction(e, element.id)}
                    />
                    <CommentList
                        articleComments={articleComments}
                        imageConnected={BASE_URL + USER_CONNECTED.profilImageUrl}
                        idNews={element.id}
                    />
                </div>
            </div>
        </Modal>
    )
}

export default DetailleNews