import moment from "../../../core/application/helpers/moment";
import DeleteConfirm from "../component/deleteConfirm";
import { useState, useMemo } from "preact/hooks";
import { BASE_URL, USER_CONNECTED } from "../../../core/application/constant/common"
import Signaler from "../component/signaler";
import { makeHtml } from "../../../core/application/helpers/markdown-converter";
import "../../../core/application/helpers/co-emoji-picker/co-emoji-picker";
import ActionNews from "./actionNews";
import { voteTypes } from "./voteTypes";
import FormNewsInput from "../container/FormNewsInput";
import { Tooltip } from 'react-tooltip';
import CustomDialog from "../../../core/presentation/component/CustomDialog";
import CardNewsDetail from "./articleGalerie/CardNewsDetail";

const Article = ({ element, toggleComments, parentId, deleteAction, dataReaction, mode, addReactionAction, articleComments }) => {
    const [isContextMenuOpen, setContextMenuOpen] = useState(false);
    const [deleteConfirm, setDeleteConfirmation] = useState(false);
    const [showNewsForm, setShowNewsForm] = useState(false);
    const [showSignaler, setShowSignaler] = useState(false);
    const [typeFormNewsInput, setTypeFormNewsInput] = useState('');
    const [isLoading, setIsLoading] = useState(false);
    const [titleModal, setTitleModal] = useState("");
    const [detailShow, setdetailShow] = useState(false);

    const totalVotes = element.voteCount ? Object.values(element.voteCount).reduce((acc, count) => acc + count, 0) : "";

    let commentCountVar;
    if (element.commentCount > 0) {
        commentCountVar = element.commentCount
    }
    else {
        commentCountVar = ""
    }

    const formatedContent = useMemo(() => {
        const formatedText = $.displayCoEmoji(element.text);
        return element.markdownActive ? makeHtml(formatedText) : formatedText
    }, [element.text, element.markdownActive])
    const toggleContextMenu = () => {
        setContextMenuOpen(!isContextMenuOpen);
    };

    const openDeleteConfirme = () => {
        setDeleteConfirmation(true);
        toggleContextMenu()
    };
    const closeDeleteConfirme = () => {
        setDeleteConfirmation(false);
    };

    const openModifModal = () => {
        setTypeFormNewsInput('edit')
        setTitleModal("Modifier votre publication")
        setShowNewsForm(true);

        toggleContextMenu()
    };

    const deleteBtn = () => {
        setIsLoading(true)
        deleteAction(element.id)
        setContextMenuOpen(false)
        setDeleteConfirmation(false);
        setIsLoading(false)
    };

    const modalShare = (data) => {
        setShowNewsForm(data)
        setTypeFormNewsInput('share')
        setTitleModal("Partager du contenue avec votre reseau")
    }
    const getDataReaction = (e) => {
        dataReaction(e)
    }

    const detailleNews = () => {
        setdetailShow(true)
    }
    return (
        <>
            <article className="w-full text-gray-900 dark:text-gray-300 flex bg-white p-5 rounded-lg dark:drop-shadow-md drop-shadow-sm dark:bg-gray-900">
                <div className="w-14">
                    <img src={element.author.profilThumbImageUrl} alt="" className="block w-12 h-12 object-cover rounded-full" />
                </div>
                <div className="pl-4 w-full">
                    <div className="flex justify-between -mt-1">
                        <h1 className="text-lg font-medium text-gray-900 dark:text-gray-50"><a href="#">{element.author.name}</a></h1>
                        <div className="w-50 h-6 ml-auto text-sm">
                            {moment.unix(element.date.sec).fromNow()}
                            <i onClick={toggleContextMenu} className="fas fa-ellipsis-h ml-3 cursor-pointer"></i>
                            {isContextMenuOpen && (
                                <div className="absolute right-1 mt-2 w-48 bg-white border border-lime-600 dark:border-gray-700 rounded-lg shadow-md dark:bg-gray-800">
                                    <ul>
                                        {element.author.id == USER_CONNECTED.id && (
                                            <>
                                                <li onClick={openDeleteConfirme} className="px-4 py-2 hover:bg-lime-600 dark:hover:bg-lime-600 hover:text-white cursor-pointer">
                                                    Supprimer
                                                </li>
                                                <li onClick={openModifModal} className="px-4 py-2 hover:bg-lime-600 dark:hover:bg-lime-600 hover:text-white cursor-pointer">
                                                    Modifier
                                                </li>
                                            </>
                                        )}

                                        <li onClick={() => setShowSignaler(true)} className="px-4 py-2 hover:bg-lime-600 dark:hover:bg-lime-600 hover:text-white cursor-pointer">
                                            Signaler un abus
                                        </li>
                                    </ul>
                                </div>
                            )}
                        </div>
                    </div>
                    <ul className="flex items-center">
                        {/* <li><a href="#">Meteolamer</a></li>
                        <li className="text-[8px] px-2 pt-1"><i class="fa-solid fa-circle"></i></li> */}
                        <li>{moment.unix(element.date.sec).format("ddd DD MMM YYYY - HH:mm")}</li>
                        {element.scope.type == 'public' ? (
                            <i class="ml-1 fa-solid fa-globe"></i>
                        ) : element.scope.type == 'restricted' ? (
                            <i class="ml-1 fa-solid fa-rss"></i>
                        ) : element.scope.type == 'private' ? (
                            <i class="ml-1 fa-solid fa-lock"></i>
                        ) : <>not defined</>}
                    </ul>
                    <div className="pt-4" dangerouslySetInnerHTML={{ __html: formatedContent }}></div>
                    {/* <div className="pt-4 text-lg text-gray-900 dark:text-gray-50 font-light">{text}</div> */}
                    <div className="mb-3">
                        {element.tags && element.tags.map((item) => (
                            <a href={BASE_URL + "/#live?tags=" + item}>
                                <span className="bg-blue-100 text-blue-800 text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-gray-50">
                                    #{item}
                                </span>
                            </a>
                        ))}
                    </div>
                    {mode == undefined && element.mediaImg !== undefined && (
                        <>
                            {element.mediaImg.images.length === 3 && element.mediaImg.images.length % 2 !== 0 && (
                                <>
                                    <div className="grid grid-cols-2 gap-5">
                                        {element.mediaImg.images.slice(0, -1).map(({ imagePath }, index) => (
                                            <div key={index} className="md:h-48 sm:h-32 w-full h-auto flex items-stretch rounded-lg overflow-hidden cursor-pointer" onClick={detailleNews}>
                                                <img
                                                    src={imagePath}
                                                    className="max-h-full w-full object-cover"
                                                />
                                            </div>
                                        ))}
                                    </div>
                                    <div className="md:h-48 sm:h-32 w-full h-auto flex items-stretch rounded-lg overflow-hidden mt-4 cursor-pointer" onClick={detailleNews}>
                                        <img
                                            src={element.mediaImg.images[element.mediaImg.images.length - 1].imagePath}
                                            className="max-h-full w-full object-cover"
                                            alt={`Image ${element.mediaImg.images.length}`}
                                        />
                                    </div>
                                </>
                            )}

                            {element.mediaImg.images.length > 4 && (
                                <>
                                    <div className="grid grid-cols-2 gap-5">
                                        {element.mediaImg.images.slice(0, 3).map(({ imagePath }, index) => (
                                            <div key={index} className="md:h-48 sm:h-32 w-full h-auto flex items-stretch rounded-lg overflow-hidden cursor-pointer" onClick={detailleNews}>
                                                <img
                                                    src={imagePath}
                                                    className="max-h-full w-full object-cover"
                                                />
                                            </div>
                                        ))}
                                        <div key="lastImage" className="md:h-48 sm:h-32 w-full h-auto relative rounded-lg overflow-hidden">
                                            <img
                                                src={element.mediaImg.images[3].imagePath}
                                                className="min-h-full w-full object-cover filter blur-sm"
                                                alt="Image"
                                            />
                                            <div className="absolute inset-0 flex items-center justify-center cursor-pointer" onClick={detailleNews}>
                                                <p className="text-lime-600 text-xl font-bold">+{element.mediaImg.images.length - 4}</p>
                                            </div>
                                        </div>
                                    </div>
                                </>
                            )}

                            {element.mediaImg.images.length > 1 && element.mediaImg.images.length <= 4 && element.mediaImg.images.length % 2 === 0 && (
                                <div className="grid grid-cols-2 gap-5">
                                    {element.mediaImg.images.map(({ imagePath }, index) => (
                                        <div key={index} className="md:h-48 sm:h-32 w-full flex items-stretch rounded-lg overflow-hidden cursor-pointer" onClick={detailleNews}>
                                            <img
                                                src={imagePath}
                                                className="max-h-full w-full object-cover"
                                            />
                                        </div>
                                    ))}
                                </div>
                            )}

                            {element.mediaImg.images.length === 1 && element.mediaImg.images.map(({ imagePath }, index) => (
                                <div key={index} className="w-full h-auto max-w-full flex items-stretch rounded-lg overflow-hidden cursor-pointer" onClick={detailleNews}>
                                    <img
                                        src={imagePath}
                                        className="h-48 w-full object-cover"
                                    />
                                </div>
                            ))}
                        </>
                    )}

                    {element.mediaFile != undefined && element.mediaFile.files.map(({ name, docPath }) => {
                        return (
                            <a href={BASE_URL + docPath} target="_blank" className=" cursor-pointer rounded-lg dark:bg-gray-800 dark:text-gray-400 p-1 mt-3 flex w-full">
                                <i class="fa-solid fa-file mt-1 mr-1"></i>
                                {
                                    name.length > 20 ?
                                        `${name.slice(0, 20)}..${name.substring(name.lastIndexOf('.') + 1)}` :
                                        name
                                }
                            </a>
                        )
                    })}
                    <ul className="mt-3 flex text-gray-700 text-xs justify-between dark:text-gray-400">
                        <li>
                            <div className="hover:text-gray-50 cursor-pointer">
                                {element.voteCount && voteTypes.map(({ type, color, icon }) => {
                                    const hasVote = element.voteCount.hasOwnProperty(type);
                                    return (
                                        hasVote && (
                                            <i
                                                key={type}
                                                className={`bg-${color} text-gray-50 fa-solid fa-${icon} p-1 rounded-full ml-1`}
                                            ></i>
                                        )
                                    );
                                })}
                                {" "}
                                {totalVotes}
                            </div>
                        </li>
                        <li>
                            {element.reportAbuseCount &&
                                <span data-tooltip-id="abuseTooltip" data-tooltip-content="Abuse">
                                    <i className="fa-solid fa-flag text-red-500"></i>
                                    <span className="ml-2">{element.reportAbuseCount}</span>
                                </span>
                            }
                            <Tooltip className="dark:bg-gray-700" id="abuseTooltip" />
                        </li>
                    </ul>
                    <ActionNews commentCountVar={element.commentCountVar} vote={element.vote} voteCount={element.voteCount} id={element.id} toggleComments={toggleComments} tags={element.tags} scope={element.scope.type} image={element.mediaImg} mediaFile={element.mediaFile} text={element.text} author={element.author} parentId={element.parentId} onDataPassShowNewsForm={modalShare} dataReaction={getDataReaction} />
                </div>
            </article>
            <DeleteConfirm isLoading={isLoading} deleteBtn={deleteBtn} deleteConfirm={deleteConfirm} close={closeDeleteConfirme} title={"Supprimer ?"} textConfirmBtn={"Oui, supprimer"} />
            <FormNewsInput title={titleModal} tagsModif={element.tags} scopeValue={element.scope.type} id={element.id} image={element.mediaImg} mediaFile={element.mediaFile} text={element.text} type={typeFormNewsInput} showNewsForm={showNewsForm} close={() => setShowNewsForm(false)} imageConnected={element.author.profilThumbImageUrl} parentId={parentId} author={element.author} markdownActiveProps={element.markdownActive} />
            <Signaler collection={"news"} type={"article"} closeContextMenuOpen={() => setContextMenuOpen(false)} id={element.id} showSignaler={showSignaler} close={() => setShowSignaler(false)} />
            <CustomDialog size={"xxl"} isOpenDialog={detailShow} setOpenAndCloseDialog={() => setdetailShow(false)}>
                <CardNewsDetail post={element} closePreview={() => setdetailShow(false)} />
            </CustomDialog>
        </>
    )
}

export default Article;