
import CircularIconButton from "./CirclularIconButton";
import { useState } from "react";
import CardNewsDetail from "./CardNewsDetail";
import FormNewsInput from "../../container/FormNewsInput";
import CustomDialog from "../../../../core/presentation/component/CustomDialog";

function CardNews({ post }) {
  const [isHovered, setIsHovered] = useState(false);
  const [showMenu, setShowMenu] = useState(false);
  const [isPreviewOpen, setIsPreviewOpen] = useState(false);
  const [showNewsForm, setShowNewsForm] = useState(false);
  const [typeFormNewsInput, setTypeFormNewsInput] = useState('');
  const [titleModal, setTitleModal] = useState("");
  const [isOpenDialog, setIsOpenDialog] = useState(false);

  const handleMouseEnterAndLeave = () => {
    setIsHovered(!isHovered);
    setShowMenu(false);
  };

  const handleShowMenu = () => {
    setShowMenu(!showMenu);
  };

  const openAndClosePreview = () => {
    setIsPreviewOpen(!isPreviewOpen);
  };

  const closePreview = () => {
    setIsPreviewOpen(false);
  };

  const modalShare = (data) => {
    setShowNewsForm(data)
    setTypeFormNewsInput('share')
    setTitleModal("Partager du contenue avec votre reseau")
  } 

  function findLink(text) {
    const urlRegex = /(https?:\/\/[^\s]+)/;
    const match = text.match(urlRegex);
    return match ? match[0] : null;
  }

  function openNewTab(url) {
    window.open(url, '_blank');
  }

  const handleOpenDialog = () => setIsOpenDialog((value) => !value);


  const handleDownloadImage = () => {
    const fileExtension = post.mediaImg.images[0].name.split(".").pop();
    const newExtension = fileExtension.toLowerCase() === "jpg" ? "jpg" : "png";
    const editedName = `${post.mediaImg.images[0].name.split(".")[0]}.${newExtension}`;

    const downloadLink = document.createElement("a");
    downloadLink.href = post.mediaImg.images[0].imagePath;
    downloadLink.download = editedName;
    downloadLink.click();
  };

  const imgClass = `w-full h-auto ${isHovered ? "filter" : "filter-none"} ${
    isHovered ? "blur" : "blur-none"
  }`;

  const displayClass = isHovered ? "block" : "none";
  const menuStyle = showMenu ? "block" : "none";


  return (
    <>

      <CustomDialog size={"xxl"} isOpenDialog={isOpenDialog} setOpenAndCloseDialog={handleOpenDialog}>
        <CardNewsDetail post={post} closePreview={handleOpenDialog} />
      </CustomDialog>      

      <FormNewsInput title={titleModal} tagsModif={post.tags} scopeValue={post.scope.type} id={post.id} image={post.mediaImg} mediaFile={post.mediaFile} text={post.text} type={typeFormNewsInput} showNewsForm={showNewsForm} close={() => setShowNewsForm(false)} imageConnected={post.author.profilThumbImageUrl} parentId={post.parentId} author={post.author} markdownActiveProps={post.markdownActive} />

      <div
        onMouseEnter={handleMouseEnterAndLeave}
        onMouseLeave={handleMouseEnterAndLeave}
        className="max-w-sm rounded-2xl overflow-hidden shadow-lg md:ml-0 ml-2"
      >
        <div className="relative">
          <img
            src={post.mediaImg.images[0].imagePath}
            alt="Your Image"
            className={imgClass}
            onClick={handleOpenDialog}
          />

          <div style={{ display: displayClass }}>
           
          {post.mediaImg.images.length > 1 && (
              <div className="absolute text-sm top-2 left-2 w-8 h-8 ml-1 bg-lime-600 text-gray-200 rounded-full flex items-center justify-center focus:outline-none">
               +{post.mediaImg.images.length - 1}
             </div>
          )}

            <div className="absolute top-2 right-2">
              <button className="rounded-3xl p-1.5 px-4 text-sm bg-lime-600 text-gray-200">
                save
              </button>
            </div>

            <div className="absolute p-2 bottom-0 right-2 flex">
              <CircularIconButton onClick={modalShare}  icon={"fa-solid fa-share"} />
              <CircularIconButton
                isSelected={showMenu}
                onClick={handleShowMenu}
                icon={"fa-solid fa-ellipsis"} 
              />
            </div>

            {
              findLink(post.text) !== null && (
              <div onClick={()=> openNewTab(findLink(post.text))} className="absolute w-1/2 bg-white text-black rounded-3xl bottom-2 p-1.5 left-0 ml-2 flex">
                <i class="fa-solid fa-link"></i>
                <a className="text-sm truncate">
                  {findLink(post.text)}
                </a>
                </div>
              )
            }

              <div
               style={{ display: menuStyle }} 
               className="relative flex-col text-center p-4 h-auto w-full min-h-56 bg-white rounded-2xl bottom-12">
                <div className="hover:bg-gray-200 h-auto w-full rounded-2xl text-center mb-2">
                  <a onClick={handleDownloadImage} className="text-center p-2">
                    Download image
                  </a>
                </div>
                <div className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
                  <a className="text-center p-2">Hide post</a>
                </div>
                <div className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
                  <a className="text-center p-2">Report post</a>
                </div>
              </div>
            </div>
          </div>
        </div>
        
    </>
  );
}

export default CardNews;
