import { useContext, useEffect, useMemo, useState } from "preact/hooks";
import CarouselSlide from "./CarouselSlide";
import CircularIconButton from "./CirclularIconButton";
import { BASE_URL, USER_CONNECTED } from "../../../../core/application/constant/common";
import CommentList from "../../container/CommentList";
import StateContext from "../../../../core/context/state-context";
import { addaction, getComments } from "../../../infrastructure/api/news-api";
import moment from "../../../../core/application/helpers/moment";
import ActionNews from "../actionNews";
import FormNewsInput from "../../container/FormNewsInput";
import DeleteConfirm from "../deleteConfirm";
import { makeHtml } from "../../../../core/application/helpers/markdown-converter";
import "../../../../core/application/helpers/co-emoji-picker/co-emoji-picker";


function CardNewsDetail({ post, closePreview }) {
  const { articleComments, articles } = useContext(StateContext);
  const [showMenu, setShowMenu] = useState(false);
  const [currentImage, setCurrentImage]= useState(post.mediaImg.images[0].imagePath);
  const [isFullScreen, setIsFullScreen] = useState(false);
  const [showNewsForm, setShowNewsForm] = useState(false);
  const [typeFormNewsInput, setTypeFormNewsInput] = useState('');
  const [titleModal, setTitleModal] = useState("");
  const [isContextMenuOpen, setContextMenuOpen] = useState(false);
  const [deleteConfirm, setDeleteConfirmation] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  const getCommentsByArticleId = async () => {
    try {
      const commentsConst = await getComments(post.id);
      articleComments.signal.value = commentsConst;
    } catch (error) {
      console.error("Error fetching events: ", error);
    }
   
  }

  const formatedContent = useMemo(() => {
    const formatedText = $.displayCoEmoji(post.text);
    return post.markdownActive ? makeHtml(formatedText) : formatedText
  }, [post.text, post.markdownActive])

  const addReactionAction = async (params, id) => {
    await addaction(id, params, 'news');
    await getCommentsByArticleId();
  };

  const deleteAction = async (params) => {
    await deleteNews(params);
    articles.signal.value = articles.signal.value.filter(article => article.id != params);
  };

  const deleteBtn = () => {
    setIsLoading(true)
    deleteAction(post.id)
    setContextMenuOpen(false)
    setDeleteConfirmation(false);
    setIsLoading(false)
  };

  const openModifModal = () => {
    setTypeFormNewsInput('edit')
    setTitleModal("Modifier votre publication")
    setShowNewsForm(true);
    // toggleContextMenu()
  };

  const closeDeleteConfirme = () => {
    setDeleteConfirmation(false);
  };

const openDeleteConfirme = () => {
  setDeleteConfirmation(true);
  toggleContextMenu()
};

  useEffect(() => {
    getCommentsByArticleId();
  });


  const isCurrentUser = USER_CONNECTED.id === post.author.id;
  let imageConnected = BASE_URL + USER_CONNECTED.profilThumbImageUrl;

  let commentCountVar;
  if (post.commentCount > 0) {
      commentCountVar = post.commentCount
  }
  else {
      commentCountVar = ""
  }

  const fullScreenClass = isFullScreen ? "md:w-full sm:w-full md:h-full" : "md:w-2/3 sm:w-full md:h-full sm:w-1/3";

  const handleShowMenu = () => {
    setShowMenu(!showMenu);
  };

  function setScreen() {
    setIsFullScreen(!isFullScreen);
  }

  function onMouseLeaveMenu() {
    setShowMenu(!showMenu);
  }

  function downloadCurrentImage() {
    const parts = currentImage.split('/');
    const fileName = parts[parts.length - 1];
  
    const link = document.createElement('a');
    link.href = currentImage;
    link.download = fileName;
    link.click();
  }

  const modalShare = (data) => {
    setShowNewsForm(data)
    setTypeFormNewsInput('share')
    setTitleModal("Partager du contenue avec votre reseau")
}
  
  
  return (
    <>

      <div className="fixed md:flex md:flex-row sm:flex-col inset-0 w-full h-full bg-white dark:bg-gray-900 bg-clip-border text-gray-700 shadow-md overflow-scroll md:overflow-hidden">

         <div className={`m-0 ${fullScreenClass} h-1/3 md:shrink-0 bg-clip-border text-gray-700`}>
            <CarouselSlide 
                images={post.mediaImg.images} 
                setCurrentImage={setCurrentImage} 
                closePreview={closePreview}
                setScreen={setScreen}
            />
        </div> 
      

        <div className={` ${isFullScreen ?? "hidden "} p-4 w-full overflow-x-hidden`}>
          <div className="flex justify-between p-1 rounded-lg drop-shadow-m">
            <div className="flex flex-row">
              <div className="w-14">
                <img
                  src={post.author.profilThumbImageUrl}
                  alt=""
                  className="w-12 h-12 object-cover rounded-full"
                />
              </div>

              <div className="pl-4 mb-4 w-full">
                <h1 className="text-sm font-medium text-gray-900 dark:text-gray-50">
                  <a href="#">{post.author.name}</a>
                </h1>
                <ul className="flex items-center text-gray-700 dark:text-gray-400 ml-auto text-sm">
                  <li>
                    {moment.unix(post.date.sec).format("ddd DD MMM YYYY - HH:mm")}
                    {post.scope.type == 'public' ? (
                            <i className="ml-1 fa-solid fa-globe"></i>
                        ) : post.scope.type == 'restricted' ? (
                            <i className="ml-1 fa-solid fa-rss"></i>
                        ) : post.scope.type == 'private' ? (
                            <i className="ml-1 fa-solid fa-lock"></i>
                        ) : <>not defined</>}
                  </li>
                </ul>
              </div>
            </div>


            <div className="ml-auto flex justify-center space-x-3">
               <span className="dark:text-gray-300 text-xs mt-1">  {moment.unix(post.date.sec).fromNow()} </span>
              <CircularIconButton  isSelected={showMenu} onClick={handleShowMenu} icon={"fa-solid fa-ellipsis"} />
            </div>
          </div>

          {post.tags && (
            <div className="flex flex-wrap mb-3">
              {post.tags.map((tag, index) => (
                <div
                  key={index}
                  className="bg-lime-600 text-white text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-lime-600 dark:text-gray-50"
                >
                  {" "}
                  #{tag}{" "}
                </div>
              ))}
            </div>
          )}

        <div className="flex-col p-1 space-y-4">
           
        <div className="pt-4 text-gray-300" dangerouslySetInnerHTML={{ __html: formatedContent }}></div>
    
          <ActionNews 
             commentCountVar={commentCountVar}
             vote={post.vote} 
             voteCount={post.voteCount} 
             id={post.id} 
             tags={post.tags} 
             scope={post.scope.type} 
             image={post.mediaImg} 
             mediaFile={post.mediaFile}
             text={post.text} 
             author={post.author} 
             parentId={USER_CONNECTED.id} 
             onDataPassShowNewsForm={modalShare}
             dataReaction={(e) => addReactionAction(e, post.id)}
          />

          <hr class="border-t-2 border-gray-300 dark:border-gray-800"/>

          {/* comment */}
        
           <CommentList
              articleComments={articleComments}
              imageConnected={imageConnected}
              idNews={post.id}
           />
         

        </div>

        </div>
        
        {/* show menu  */}
        <div
            style={{ display: `${showMenu ? "block" : "none"}` }}
            onMouseLeave={onMouseLeaveMenu}
            className="absolute flex-col p-6 w-auto h-auto md:top-5 top-1/3 right-16 rounded-lg bg-white shadow-md text-sm"
          >
            <div className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
              <span className="text-center p-2">Save Post</span>
            </div>
            <div className="hover:bg-gray-200 h-auto w-full rounded-2xl text-center mb-2">
              <span onClick={downloadCurrentImage} className="text-center p-2">Download</span>
            </div>
            <div className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
              <span className="text-center p-2">Signaler un abus</span>
            </div>
            
            {isCurrentUser && (
              <>
               <div class="border-t border-gray-300 my-2"></div>
               <div onClick={openDeleteConfirme} className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
                    <span className="text-center p-2">Supprimer</span>
                </div>
                <div onClick={openModifModal} className="hover:bg-gray-200 h-auto rounded-2xl text-center mb-2">
                    <span className="text-center p-2">Modifier</span>
                </div>
              </>
            )}

          </div>
      </div>

      <FormNewsInput 
        title={titleModal} 
        tagsModif={post.tags} 
        scopeValue={post.scope.type} 
        id={post.id} 
        image={post.mediaImg} 
        mediaFile={post.mediaFile} 
        text={post.text} 
        type={typeFormNewsInput} 
        showNewsForm={showNewsForm}
        close={() => setShowNewsForm(false)} 
        imageConnected={post.author.profilThumbImageUrl} 
        parentId={USER_CONNECTED.id} 
        author={post.author} 
        markdownActiveProps={post.markdownActive} 
      />

    <DeleteConfirm 
      isLoading={isLoading} 
      deleteBtn={deleteBtn} 
      deleteConfirm={deleteConfirm} 
      close={closeDeleteConfirme} 
      title={"Supprimer ?"} 
      textConfirmBtn={"Oui, supprimer"} 
     />
    
     </>

  );
}

export default CardNewsDetail;
