
import { useState } from "preact/hooks";

function CarouselSlide({ images, setCurrentImage, closePreview, setScreen }) {
  
  const [activeSlide, setActiveSlide] = useState(0);
  const [zoomLevel, setZoomLevel] = useState(1);

  const handlePrev = () => {
    const prevSlide = activeSlide - 1 >= 0 ? activeSlide - 1 : images.length - 1;
    setActiveSlide(prevSlide);
    setCurrentImage(images[prevSlide].imagePath);
  };

  const handleNext = () => {
    const nextSlide = activeSlide + 1 < images.length ? activeSlide + 1 : 0;
    setActiveSlide(nextSlide);
    setCurrentImage(images[nextSlide].imagePath);
  };

  const handleZoomIn = () => {
    setZoomLevel(zoomLevel + 0.1);
  };

  const handleZoomOut = () => {
    setZoomLevel(Math.max(1, zoomLevel - 0.1));
  };

  const imageStyles = {
    transform: `scale(${zoomLevel})`,
  };


  const listImg = images.map((img, index) => (
    <div
      key={index}
      className={`duration-700 ease-in-out ${index === activeSlide ? 'block' : 'hidden'}`}
      data-carousel-item={index === activeSlide ? 'active' : ''}
    >
     <img
        src={img.imagePath}
        style={imageStyles}
        className="absolute h-full md:px-14 md:object-contain w-full"
        alt="..."
      />
    </div>
  ));

  const showButton = images.length > 1 ? "block" : "none";


  return (
    <div
      id="indicators-carousel"
      className="relative h-full w-full bg-white dark:bg-gray-800"
      data-carousel="static"  
    >
      <div class="h-full w-full overflow-hidden">
         {listImg}
      </div>

      <div className="absolute top-5 left-5 text-gray-600 dark:text-gray-50 text-xl">
        <i onClick={closePreview} class="cursor-pointer fa-solid fa-xmark"></i>
      </div>

      <div className="absolute w-auto flex flex-row top-7 right-5 space-x-4 text-gray-600 dark:text-gray-50 text-xl">
        <i  onClick={handleZoomIn} className="fa-solid fa-magnifying-glass-plus"></i>
        <i  onClick={handleZoomOut} className="fa-solid fa-magnifying-glass-minus"></i>
        <i  onClick={setScreen} className="fa-solid fa-expand hidden md:flex"></i>
      </div>
    
      {/* <!-- Slider controls --> */}
      <div style={{display: showButton }}>
      <button
        onClick={handlePrev}
        type="button"
        class="absolute  top-1/2 -left-2 z-30 flex items-center justify-center px-4 cursor-pointer group focus:outline-none"
        data-carousel-prev
      >
        <span class="inline-flex items-center justify-center w-10 h-10 rounded-full dark:bg-white/50  group-focus:ring hover:dark:bg-white ">
          <i style={{fontSize: 22}} class="fa-solid fa-chevron-left "></i>
          <span class="sr-only">Previous</span>
        </span>
      </button>
      <button
        onClick={handleNext}
        type="button"
        class="absolute top-1/2 -right-2 z-30 flex items-center justify-center px-4 cursor-pointer group focus:outline-none"
        data-carousel-next
      >
      <span class="inline-flex items-center justify-center w-10 h-10 rounded-full dark:bg-white/50 hover:dark:bg-white">
          <i style={{fontSize: 22}} class="fa-solid fa-chevron-right"></i>
          <span class="sr-only">Next</span>
        </span>
      </button>
      </div>

      <div className="absolute bottom-4 left-1/2 transform -translate-x-1/2 flex space-x-2 items-center p-1 bg-gray-800 rounded-md">
      <i className="fa fa-image text-xl text-gray-300"></i>
        <span className="text-gray-300 font-medium text-sm">
          {activeSlide + 1}/{images.length}
        </span>
      </div>


    </div>
  );
}

export default CarouselSlide;
