import moment from "../../../core/application/helpers/moment";
import Reation from "../component/reaction";
import { useState, useMemo } from "preact/hooks";
import DeleteConfirm from "../component/deleteConfirm";
import Signaler from "../component/signaler";
import { voteTypes } from "./voteTypes";
import { USER_CONNECTED } from "../../../core/application/constant/common";
import ModifComment from "./form/comment/modifComment";

const Comment = ({ idNews, idComments, author, created, text, image, voteCount, reportAbuseCount, toggleReponse, replies, deleteAction, updateAction, addReactionAction }) => {
    const [reactionShow, setReactionShow] = useState(false);
    const totalVotes = voteCount ? Object.values(voteCount).reduce((acc, count) => acc + count, 0) : "";
    const totalReponse = Object.keys(replies).length > 0 ? Object.keys(replies).length : "";
    const [deleteConfirm, setDeleteConfirmation] = useState(false);
    const [showModifModal, setShowModifModal] = useState(false);
    const [showSignaler, setShowSignaler] = useState(false);
    const [isLoading, setIsLoading] = useState(false);

    const addReactionBtn = async (data) => {
        addReactionAction(idComments, data, idNews)
        setReactionShow(false)
    };

    const deleteBtn = () => {
        setIsLoading(true)
        deleteAction(idComments)
        setDeleteConfirmation(false)
        setIsLoading(false)
    };

    const updateCommentBtn = async (commentTextModif) => {
        setIsLoading(true)
        updateAction(idComments, commentTextModif)
        setShowModifModal(false);
        setIsLoading(false)
    };

    const formatedContent = useMemo(() => {
        const formatedText = $.displayCoEmoji(text);
        return formatedText
    }, [text])

    return (
        <>
            <div className="l-4 w-full flex p-5 drop-shadow-md -mt-5">
                <div className="w-20">
                    <img src={image} alt="" className="block w-12 h-12 object-cover rounded-full" />
                </div>
                <div className="w-full">
                    <div className="p-2 rounded-lg bg-white dark:bg-gray-700">
                        <div className="flex justify-between -mt-1">
                            <h1 className="text-lg font-medium text-gray-900 dark:text-gray-50 text-sm"><a href="#">{author.name}</a></h1>
                            <div className="w-50 h-6 text-gray-900 dark:text-gray-400 ml-auto text-sm">{moment.unix(created).fromNow()} </div>
                        </div>
                        <p className="text-sm text-lg text-gray-900 dark:text-gray-50 font-normal" dangerouslySetInnerHTML={{ __html: formatedContent }}>
                        </p>
                    </div>
                    <div onMouseLeave={() => setReactionShow(false)} className="ml-2 grid-cols-10 divide-x-2 divide-gray-300 dark:divide-gray-700">
                        <button onMouseEnter={() => setReactionShow(true)} className="dark:bg-gray-900 text-xs dark:text-gray-400 font-normal py-1 px-2">
                            <div className="-ml-3 -mb-2">
                                <Reation reactionShow={reactionShow} onDataCallback={addReactionBtn} />
                            </div>
                            J'aime
                            {voteCount && voteTypes.map(({ type, color, icon }) => {
                                const hasVote = voteCount.hasOwnProperty(type);
                                return (
                                    hasVote && (
                                        <i
                                            key={type}
                                            className={`dark:bg-${color} dark:text-gray-200 fa-solid fa-${icon} p-1 rounded-full ml-1`}
                                        ></i>
                                    )
                                );
                            })}
                            {" "}
                            {totalVotes}
                        </button>
                        <button onClick={() => toggleReponse(idComments)} className="dark:bg-gray-900 text-xs dark:text-gray-400 font-normal py-1 px-2">
                            {
                                totalReponse === 1 ? (
                                    <>1 réponse</>
                                ) : totalReponse > 1 ? (
                                    <>{totalReponse} réponses</>
                                ) : (
                                    <>Répondre</>
                                )
                            }
                        </button>
                        <button onClick={() => setShowSignaler(true)} className="dark:bg-gray-900 text-xs dark:text-gray-400 font-normal py-1 px-2">
                            <i class="fa-solid fa-flag"></i>
                            {reportAbuseCount &&
                                <span className="ml-2">{reportAbuseCount}</span>
                            }
                        </button>
                        {author.id == USER_CONNECTED.id && (
                            <>
                                <button onClick={() => setShowModifModal(true)} className="dark:bg-gray-900 text-xs dark:text-gray-400 font-normal py-1 px-2">
                                    <i class="fa-solid fa-pen"></i>
                                </button>
                                <button onClick={() => setDeleteConfirmation(true)} className="dark:bg-gray-900 text-xs dark:text-gray-400 font-normal py-1 px-2">
                                    <i class="fa-solid fa-trash"></i>
                                </button>
                            </>
                        )}
                    </div>
                </div>
            </div>
            <DeleteConfirm isLoading={isLoading} deleteBtn={deleteBtn} deleteConfirm={deleteConfirm} close={() => setDeleteConfirmation(false)} />
            <ModifComment isLoading={isLoading} updateCommentBtn={updateCommentBtn} text={text} showModifModal={showModifModal} close={() => setShowModifModal(false)} />
            <Signaler id={idComments} collection={"comments"} type={"comment"} showSignaler={showSignaler} close={() => setShowSignaler(false)} />
        </>
    )
}

export default Comment;