import { useState } from 'preact/hooks';
import React from 'react'
import { searchTags } from '../../../infrastructure/api/news-api';

function Tags({ type, tagsValueCallBack, tagsModif }) {
    const [tags, setTags] = useState(tagsModif ? tagsModif : []);
    const [tagInput, setTagInput] = useState('');
    const [suggestions, setSuggestions] = useState([]);
    const handleInputChange = async (e) => {
        setTagInput(e.target.value);
        if (e.target.value.length >= 3) {
            try {
                const response = await searchTags(e.target.value)
                const tagsArray = response.map(item => item.tag)
                setSuggestions(tagsArray)
            } catch (error) {
                console.log(error);
            }
        }
    };

    const handleTagKeyPress = (e) => {
        if (e.key === 'Enter') {
            handleTagAdd(tagInput);
        }
    };

    const handleTagAdd = (tag) => {
        if (tag && !tags.includes(tag)) {
            setTags([...tags, tag]);
            setTagInput('');
        }
    };

    const handleTagRemove = (tagToRemove) => {
        const updatedTags = tags.filter((tag) => tag !== tagToRemove);
        setTags(updatedTags);
    };
    tagsValueCallBack(tags)
    return (
        <div className="mt-4">
            <label className="block text-sm font-medium text-gray-900 dark:text-gray-300">Tags</label>
            <div className='relative'>
                {tags.map((tag, index) => (
                    <span key={index} className="bg-blue-100 text-blue-800 text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">
                        {type != "share" && (
                            <i onClick={() => handleTagRemove(tag)} className="cursor-pointer fa-solid fa-xmark mr-1 mt-5"></i>
                        )}{tag}
                    </span>
                ))}
                <input
                    value={tagInput}
                    onChange={handleInputChange}
                    onKeyPress={handleTagKeyPress}
                    placeholder="#Tags"
                    className="block w-full p-3 pl-2 mt-2 mb-3 text-sm text-gray-900 border border-gray-300 rounded-lg bg-gray-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-800 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-300 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none"
                />
                {suggestions.length > 0 && tagInput.length >= 3 && (
                    <div className="absolute w-56 z-50 -mt-5 p-2 bg-white border border-gray-200 rounded-lg shadow dark:bg-gray-800 dark:border-gray-700">
                        {suggestions
                            .filter((suggestion) => suggestion.startsWith(tagInput))
                            .map((suggestion, index) => (
                                <div
                                    key={index}
                                    onClick={() => handleTagAdd(suggestion)}
                                    className="text-gray-900 dark:text-gray-300 cursor-pointer"
                                >
                                    {suggestion}
                                </div>
                            ))}
                    </div>
                )}
            </div>
        </div>
    )
}

export default Tags