import { useEffect, useRef, useState } from 'preact/hooks';
import React from 'react'
import "../../../../core/application/helpers/co-emoji-picker/co-emoji-picker";
import "../../../../core/application/helpers/co-emoji-picker/co-emoji-picker.css";

function TextAreaNews({ text, type, newsValueCallBack, newsControl }) {
    const [news, setNews] = useState(text);
    const btnToggleEmoji = useRef();

    const setValueNews = (e) => {
        setNews(e.target.value)
        newsValueCallBack(e.target.value)
    };

    useEffect(() => {
        if (type == "share") {
            setNews('');
        }
        $(btnToggleEmoji.current).coEmojiPicker({
            onclick: function ({ value }) {
                newsValueCallBack(
                    prevValue => {
                        if (prevValue === undefined) {
                            return value;
                        } else {
                            return prevValue + ' ' + value;
                        }
                    }
                );
                setNews(prevValue => {
                    if (prevValue === undefined) {
                        return value;
                    } else {
                        return prevValue + ' ' + value;
                    }
                });


            }
        })
    }, [type])

    return (
        <>
            <div className="relative">
                <textarea
                    placeholder="Exprimer-vous"
                    value={news}
                    onInput={setValueNews}
                    rows={type === "share" ? "3" : "6"}
                    className={`block w-full p-3 pl-2 mt-4 text-sm text-gray-900 border rounded-lg outline-none 
            ${newsControl ? 'border-gray-300 bg-gray-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-800 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-300 dark:focus:ring-blue-500 dark:focus:border-blue-500'
                            : 'border-red-300 bg-red-50 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-800 dark:border-red-600 dark:placeholder-red-400 dark:text-red-300 dark:focus:ring-blue-500 dark:focus:border-blue-500'}`}
                ></textarea>
                <div className="absolute right-2 bottom-2" ref={btnToggleEmoji}>
                    <i className="cursor-pointer fa-xl fa-solid fa-face-smile mr-4 text-blue-400"></i>
                </div>
            </div>
            {!newsControl && (
                <p className="mt-2 text-sm text-red-600 dark:text-red-500">
                    Ce champ ne doit pas être vide.
                </p>
            )}

            {/* <li className="flex mt-2 mb-2 items-center px-2 text-blue">
                <div className="flex items-center">
                    <input id="link-checkbox"
                        checked={markdownActive}
                        type="checkbox"
                        className="w-4 h-4 text-blue-600 bg-gray-100 border-gray-300 rounded bg-gray-500 cursor-pointer"
                        onChange={({ target }) => setValueMarkDown(target.checked)}
                    />
                    <label for="link-checkbox" className="ml-2 text-sm font-medium dark:text-gray-400 cursor-pointer">Utiliser la syntaxe markdown</label>
                </div>
            </li> */}
        </>
    )
}

export default TextAreaNews