import { useEffect, useState } from 'preact/hooks';
import React from 'react'
import { addFileInNews, addImageInNews, deleteFileInNews, deleteImageInNews } from '../../../infrastructure/api/news-api';

function UploadFile({ type, idImageValueCallBack, idFileValueCallBack, image, mediaFile }) {
    const [fileNames, setFileNames] = useState([]);
    const [idImage, setIdImage] = useState([]);
    const [idFile, setIdFile] = useState([]);
    const [imagePreviews, setImagePreviews] = useState([]);

    useEffect(() => {
        if (image) {
            const newImagePreviews = [];
            const newIdImage = [];
            image.images.forEach((img) => {
                newImagePreviews.push(img.imagePath);
                newIdImage.push(img._id.$id);
            });
            setImagePreviews(newImagePreviews);
            setIdImage(newIdImage);
        }
        if (mediaFile) {
            const newFileNames = [];
            const newIdFile = [];
            mediaFile.files.forEach((file) => {
                newFileNames.push(file.name);
                newIdFile.push(file._id.$id);
            });
            setFileNames(newFileNames);
            setIdFile(newIdFile);
        }
    }, [image, mediaFile]);

    const handleImageUpload = async (event) => {
        const files = event.target.files;
        if (files.length > 0) {
            const newPreviews = [...imagePreviews];
            try {
                const response = await addImageInNews(event.target.files[0]);
                setIdImage((prevIds) => [...prevIds, response.data.id.$id]);
                for (const file of files) {
                    const reader = new FileReader();
                    reader.onload = async (e) => {
                        newPreviews.push(e.target.result);
                        setImagePreviews([...newPreviews]);
                    };
                    reader.readAsDataURL(file);
                }
            } catch (error) {
                console.error(error);
            }
        }
    }

    const handleFileUpload = async (event) => {
        const files = event.target.files;
        if (files.length > 0) {
            const newFileNames = [...fileNames];
            try {
                const response = await addFileInNews(event.target.files[0]);
                setIdFile((prevIds) => [...prevIds, response.data.id.$id]);
                for (const file of files) {
                    newFileNames.push(file.name);
                    setFileNames(newFileNames);
                }
            } catch (error) {
                console.error(error);
            }
        }
    }
    const handleRemoveImage = async (index) => {
        const imageIdToRemove = idImage[index];
        await deleteImageInNews(imageIdToRemove)
        setIdImage((prevIds) => prevIds.filter((id, idx) => idx !== index));
        const newPreviews = [...imagePreviews];
        newPreviews.splice(index, 1);
        setImagePreviews(newPreviews);
    };
    const handleRemoveFile = async (index) => {
        const fileIdToRemove = idFile[index];
        await deleteFileInNews(fileIdToRemove)
        setIdFile((prevIds) => prevIds.filter((id, idx) => idx !== index));
        const filePreviews = [...fileNames];
        filePreviews.splice(index, 1);
        setFileNames(filePreviews);

    };
    idImageValueCallBack(idImage)
    idFileValueCallBack(idFile)
    return (
        <>
            {fileNames.map((fileName, index) => (
                <div className="rounded-lg dark:bg-gray-800 dark:text-gray-400 p-1 mb-1 flex justify-between" key={index}>
                    <span><i className="fa-solid fa-paperclip"></i> {fileName}</span>
                    {type != "share" && (
                        <i onClick={() => handleRemoveFile(index)} className="cursor-pointer text-red-600 fa-solid fa-circle-xmark mt-1"></i>
                    )}
                </div>
            ))}
            <div className="relative flex w-full mt-2">
                <div className="flex  block w-full p-2 pl-2 text-sm text-gray-900 border border-gray-300 rounded-lg bg-gray-50 dark:bg-gray-800 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-300 dark:focus:ring-blue-500 dark:focus:border-blue-500 outline-none">
                    {imagePreviews.length === 0 ? (
                        <div className="p-3 text-gray-400 cursor-default">
                            Ajouter a votre publication
                        </div>
                    ) : (
                        imagePreviews.map((preview, index) => (
                            <>
                                <img
                                    key={index}
                                    src={preview}
                                    className="w-12 h-12 rounded-lg object-cover ml-1"
                                />
                                {type != "share" && (
                                    <i onClick={() => handleRemoveImage(index)} className="cursor-pointer text-red-600 fa-solid fa-circle-xmark -ml-3 mr-1"></i>
                                )}
                            </>
                        ))
                    )}
                </div>
                <div className="absolute inset-y-0 right-0 flex items-center">
                    <label htmlFor="imageInput">
                        <i className="cursor-pointer fa-2xl fa-solid fa-image mr-4 text-yellow-500"></i>
                    </label>
                    <input
                        type="file"
                        id="imageInput"
                        accept="image/*"
                        disabled={type == "share" ? true : false}
                        style={{ display: 'none' }}
                        onChange={handleImageUpload}
                    />
                    <label htmlFor="fileInput">
                        <i className="cursor-pointer fa-2xl fa-solid fa-file mr-4 text-blue-400"></i>
                    </label>
                    <input
                        type="file"
                        id="fileInput"
                        accept=".pdf,.docs,.csv"
                        disabled={type == "share" ? true : false}
                        style={{ display: 'none' }}
                        onChange={handleFileUpload}
                    />
                </div>
            </div>
        </>
    )
}

export default UploadFile