import { useState, useContext } from "preact/hooks";
import { addActionSignaler } from "../../infrastructure/api/news-api";
import StateContext from "../../../core/context/state-context";

export default function Signaler({ collection, showSignaler, close, id, closeContextMenuOpen, type }) {
    const { articles, articleComments } = useContext(StateContext);
    const [reason, setReason] = useState('Propos malveillants');
    const [comment, setComment] = useState('');
    const [isLoading, setIsLoading] = useState(false);

    const addActionReportAbuse = async () => {
        setIsLoading(true)
        try {
            const response = await addActionSignaler(id, collection, reason, comment)
            if (response.data.result === true) {
                if (collection == "news") {
                    closeContextMenuOpen()
                    articles.signal.value = articles.signal.value.map((article) => {
                        if (article.id === id) {
                            return { ...article, reportAbuseCount: article.reportAbuseCount ? parseFloat(article.reportAbuseCount) + 1 : 1 };
                        } else {
                            return article;
                        }
                    });
                } else if (collection == "comments" && type == "reponse") {
                    articleComments.signal.value = articleComments.signal.value.map((comment) => {
                        if (comment.replies.hasOwnProperty(id)) {
                            if (id === id) {
                                comment.replies[id].reportAbuseCount = comment.replies[id].reportAbuseCount ? parseFloat(comment.replies[id].reportAbuseCount) + 1 : 1;
                            }
                            return comment;
                        } else {
                            return comment;
                        }
                    });
                } else {
                    articleComments.signal.value = articleComments.signal.value.map((comment) => {
                        if (comment.id === id) {
                            return { ...comment, reportAbuseCount: comment.reportAbuseCount ? parseFloat(comment.reportAbuseCount) + 1 : 1 };
                        } else {
                            return comment;
                        }
                    });
                }
            }

        } catch (error) {
            console.log(error)
        }
        close()
        setReason('')
        setComment('')
        setIsLoading(false)
    }
    const closeAll = () => {
        close()
        if (collection == "news") {
            closeContextMenuOpen()
        }
    }
    return (
        <>
            {showSignaler &&
                <div className="fixed inset-0 flex items-center justify-center z-50 p-4 overflow-x-hidden overflow-y-auto" style="backdrop-filter: blur(1.5px);">
                    <div className="relative w-2/5">
                        <div className="relative bg-white rounded-lg shadow dark:bg-gray-800">
                            <div className="flex justify-between p-4 border-b rounded-t dark:border-gray-600">
                                <h3 className="text-xl font-semibold text-gray-900 dark:text-red-500">
                                    Signaler un abus
                                </h3>
                                <i onClick={closeAll} className="fa-solid fa-xmark fa-xl mt-3 ml-2 cursor-pointer text-gray-900 dark:text-gray-200"></i>
                            </div>
                            <div className="ml-2 text-lg p-2 border-b text-gray-900 dark:border-gray-600 dark:text-gray-300">
                                Pour quelle raison signaler-vous ce contenu ?
                            </div>
                            <div className="p-4 text-gray-900 dark:border-gray-600 dark:text-gray-300">
                                <div onClick={() => setReason("Propos malveillants")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Propos malveillants"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Propos malveillants</label>
                                </div>
                                <div onClick={() => setReason("Incitation et glorification des conduites agressives")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Incitation et glorification des conduites agressives"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Incitation et glorification des conduites agressives</label>
                                </div>
                                <div onClick={() => setReason("Affichage de contenu gore et trash")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Affichage de contenu gore et trash"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Affichage de contenu gore et trash</label>
                                </div>
                                <div onClick={() => setReason("Contenu pornographique")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Contenu pornographique"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Contenu pornographique</label>
                                </div>
                                <div onClick={() => setReason("Liens fallacieux ou frauduleux")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Liens fallacieux ou frauduleux"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Liens fallacieux ou frauduleux</label>
                                </div>
                                <div onClick={() => setReason("Violations des droits d’auteur")} className="flex items-center mb-2">
                                    <input
                                        checked={reason === "Violations des droits d’auteur"}
                                        type="radio" name="default-radio" className="w-4 h-4 text-blue-600 bg-gray-100 cursor-pointer border-gray-300 focus:ring-blue-500 dark:focus:ring-blue-600 dark:ring-offset-gray-800 focus:ring-2 dark:bg-gray-700 dark:border-gray-600" />
                                    <label className="ml-2 text-sm text-gray-900 dark:text-gray-300 cursor-pointer">Violations des droits d’auteur</label>
                                </div>
                                <div className="mt-5">
                                    <input
                                        onChange={(e) => setComment(e.target.value)}
                                        value={comment}
                                        type="text"
                                        className="bg-gray-50 border border-gray-300 text-gray-900 text-sm rounded-lg focus:ring-blue-500 focus:border-blue-500 block w-full p-2.5 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 dark:focus:ring-blue-500 dark:focus:border-blue-500" placeholder="Laisser votre commentaire" />
                                </div>
                                <div className="mt-5">
                                    Votre signalement sera envoyé aux administrateurs du réseau, qui le traiteront conformément aux conditions générales d’utilisations
                                </div>
                                <div className="mt-2 dark:text-red-500 font-semibold">
                                    <i className="fa-solid fa-info-circle mr-1"></i>
                                    Tout signalement est définitif, vous ne pourrez pas l’annuler
                                </div>
                            </div>
                            <div className="flex justify-between p-4 border-t rounded-b dark:border-gray-600">
                                {isLoading ? (
                                    <button
                                        disabled={true}
                                        type="button"
                                        className="text-gray-200 bg-red-600 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300 dark:focus:ring-red-800 font-medium rounded-lg text-sm inline-flex items-center px-5 py-2.5 text-center mr-2"
                                    >
                                        <div className="loader">
                                            <svg aria-hidden="true" className="w-56 h-5 text-gray-200 animate-spin dark:text-gray-300 fill-gray-600" viewBox="0 0 100 101" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M100 50.5908C100 78.2051 77.6142 100.591 50 100.591C22.3858 100.591 0 78.2051 0 50.5908C0 22.9766 22.3858 0.59082 50 0.59082C77.6142 0.59082 100 22.9766 100 50.5908ZM9.08144 50.5908C9.08144 73.1895 27.4013 91.5094 50 91.5094C72.5987 91.5094 90.9186 73.1895 90.9186 50.5908C90.9186 27.9921 72.5987 9.67226 50 9.67226C27.4013 9.67226 9.08144 27.9921 9.08144 50.5908Z" fill="currentColor" /><path d="M93.9676 39.0409C96.393 38.4038 97.8624 35.9116 97.0079 33.5539C95.2932 28.8227 92.871 24.3692 89.8167 20.348C85.8452 15.1192 80.8826 10.7238 75.2124 7.41289C69.5422 4.10194 63.2754 1.94025 56.7698 1.05124C51.7666 0.367541 46.6976 0.446843 41.7345 1.27873C39.2613 1.69328 37.813 4.19778 38.4501 6.62326C39.0873 9.04874 41.5694 10.4717 44.0505 10.1071C47.8511 9.54855 51.7191 9.52689 55.5402 10.0491C60.8642 10.7766 65.9928 12.5457 70.6331 15.2552C75.2735 17.9648 79.3347 21.5619 82.5849 25.841C84.9175 28.9121 86.7997 32.2913 88.1811 35.8758C89.083 38.2158 91.5421 39.6781 93.9676 39.0409Z" fill="currentFill" /></svg>
                                        </div>
                                    </button>
                                ) : (
                                    <button
                                        onClick={addActionReportAbuse}
                                        type="button"
                                        className="w-56 text-gray-200 bg-red-600 hover:bg-red-800 focus:ring-4 focus:outline-none focus:ring-red-300 dark:focus:ring-red-800 font-medium rounded-lg text-sm inline-flex items-center px-5 py-2.5 text-center mr-2 pl-8"
                                    >
                                        Envoyer le signalement
                                    </button>
                                )}
                                <button
                                    onClick={closeAll}
                                    type="button"
                                    className="text-gray-500 bg-white hover:bg-gray-100 focus:ring-4 focus:outline-none focus:ring-gray-200 rounded-lg border border-gray-200 text-sm font-medium px-5 py-2.5 hover:text-gray-900 focus:z-10 dark:bg-gray-700 dark:text-gray-300 dark:border-gray-500 dark:hover:text-gray-200 dark:hover:bg-gray-600 dark:focus:ring-gray-600"
                                >
                                    Fermer
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            }
        </>
    )
}