import { useState } from "preact/hooks";
import Comment from "../component/comment";
import FormComment from "../component/form/comment/formComment";
import ReponseList from "../container/ReponseList";
import { addComments, addaction, deleteCommments, getComments, updateComment } from "../../infrastructure/api/news-api";

export default function CommentList({ articleComments, idNews, imageConnected }) {
    // console.log(imageConnected);
    const [selectedReponse, setSelectedReponse] = useState(null);
    const [loading, setloading] = useState(false)
    
    const toggleReponse = async (id) => {
        setSelectedReponse((prevSelectedArticle) =>
            prevSelectedArticle === id ? null : id
        );
    }

    const deleteAction = async (params) => {
        await deleteCommments(params);
        articleComments.signal.value = articleComments.signal.value.filter(article => article.id != params)
    };

    const updateAction = async (params, e) => {
        await updateComment(params, e);
        articleComments.signal.value = articleComments.signal.value.map((comment) => {
            if (comment.id === params) {
                return { ...comment, text: e };
            } else {
                return comment;
            }
        });
    }
    const addReactionAction = async (idComments, data, idNews) => {
        await addaction(idComments, data, 'comments');
        const comment = await getComments(idNews);
        articleComments.signal.value = comment;
    }

    const addCommentAction = async (comment, idNews) => {
        setloading(true)
        await addComments(comment, idNews, "")
        setloading(false)
        const commentsConst = await getComments(idNews);
        articleComments.signal.value = commentsConst;
    }

    return (
        <>
            <div className="bg-white dark:bg-gray-900 -mt-5 rounded-b-lg">
                <FormComment image={imageConnected} idNews={idNews} addCommentAction={addCommentAction}  loading={loading}/>
                {
                    articleComments.signal.value.map(({ id, text, created, author, voteCount, reportAbuseCount, replies }) => (
                        <>
                            <Comment
                                replies={replies}
                                reportAbuseCount={reportAbuseCount}
                                idNews={idNews}
                                toggleReponse={() => toggleReponse(id)}
                                idComments={id} author={author}
                                text={text}
                                created={created}
                                image={author.profilThumbImageUrl}
                                voteCount={voteCount}
                                deleteAction={() => deleteAction(id)}
                                updateAction={updateAction}
                                addReactionAction={addReactionAction}
                            />
                            {selectedReponse === id && (
                                <ReponseList imageConnected={imageConnected} replies={replies} idNews={idNews} idComments={id} />
                            )}
                        </>
                    ))
                }
            </div>
        </>
    )
}