import { getNews, addNews, deleteImageInNews, deleteFileInNews, updateNews, shareNews } from "../../infrastructure/api/news-api";
import { useState, useContext, useEffect } from "preact/hooks";
import StateContext from "../../../core/context/state-context";
import Modal from "../../../core/presentation/component/Modal";
import Scope from "../component/form/Scope";
import TextAreaNews from "../component/form/TextAreaNews";
import Tags from "../component/form/Tags";
import UploadFile from "../component/form/UploadFile";

export default function FormNewsInput({ id, imageConnected, parentId, author, showNewsForm, close, type, text, image, mediaFile, scopeValue, tagsModif, title }) {
    const { articles } = useContext(StateContext);
    const [news, setNews] = useState(text);
    const [scope, setScope] = useState(scopeValue);
    const [markdownActive, setMarkdownActive] = useState(true);
    const [idImage, setIdImage] = useState([]);
    const [idFile, setIdFile] = useState([]);
    const [isLoading, setIsLoading] = useState(false);
    const [tags, setTags] = useState([]);
    const [newsControl, setNewsControl] = useState(true);
    useEffect(() => {
        setScope('public');
    }, []);

    const addBtnNews = async () => {
        setIsLoading(true);
        if (news == "" || news == undefined) {
            setIsLoading(false);
            setNewsControl(false)
        } else {
            await addNews(news, scope, markdownActive, parentId, idImage.length, idImage, idFile.length, idFile, tags.length, tags);
            const newsConst = await getNews();
            articles.signal.value = newsConst;
            setNews('')
            setIdImage([])
            setScope('restricted')
            setMarkdownActive(true)
            setIdFile([])
            setTags([])
            close()
            setIsLoading(false)
            setNewsControl(true)
        }
    };

    const updateBtnNews = async () => {
        setIsLoading(true);
        await updateNews(id, news, scope, markdownActive, parentId, idImage.length, idImage, idFile.length, idFile, tags.length, tags);
        const newsConst = await getNews();
        articles.signal.value = newsConst;
        close()
        setIsLoading(false);
    }

    const btnShareNews = async () => {
        setIsLoading(true);
        await shareNews(id, 'citoyens', 'share', news, 'news');
        close()
        setIsLoading(false);
    }

    const closeModal = async () => {
        close()
        if (type === undefined && idImage.length > 0) {
            for (const idImageOne of idImage) {
                await deleteImageInNews(idImageOne)
            }
        }
        if (type === undefined && idFile.length > 0) {
            for (const idFileOne of idFile) {
                await deleteFileInNews(idFileOne)
            }
        }
        close()
    };

    return (
        <>
            <Modal show={showNewsForm} close={closeModal} title={title} onSubmit={type == 'edit' ? updateBtnNews : type == 'share' ? btnShareNews : addBtnNews} isLoading={isLoading} style={""}>
                <Scope imageConnected={imageConnected} author={author} type={type} scopeValue={scopeValue} scopeValueCallBack={(e) => setScope(e)} />
                <TextAreaNews type={type} newsValueCallBack={(e) => setNews(e)} text={text} newsControl={newsControl}/>
                <Tags type={type} tagsValueCallBack={(e) => setTags(e)} tagsModif={tagsModif} />
                {type == "share" && (
                    <span className="dark:text-gray-400">{text}</span>
                )}
                <UploadFile type={type} idImageValueCallBack={(e) => setIdImage(e)} idFileValueCallBack={(e) => setIdFile(e)} image={image} mediaFile={mediaFile} />
            </Modal>
        </>
    )
}