import Article from "../component/article";
import { useContext, useEffect, useState } from "preact/hooks";
import { getNews, getComments, deleteNews, addaction } from "../../infrastructure/api/news-api";
import StateContext from "../../../core/context/state-context";
import CommentList from "../container/CommentList";
import FormNews from "../component/form/formNews";
import SwitchIconButton from "../component/articleGalerie/SwitchIconButton";
import { BASE_URL, USER_CONNECTED } from "../../../core/application/constant/common"
import ListGallery from "../component/articleGalerie/ListGallery";

const ListArticle = ({ articleProps }) => {
    console.log(articleProps);
    const categoryNews = [
        {
            label: 'Listes',
            icon: 'fa-solid fa-newspaper',
        },
        {
            label: 'Gallerie',
            icon: 'fa-solid fa-images'
        },
    ];

    const { articles, articleComments } = useContext(StateContext);
    const [selectedArticle, setSelectedArticle] = useState(null);
    const [switchNews, setSwitchNews] = useState(categoryNews[0]);
    const [scrollEnd, setScrollEnd] = useState(false);
    const [endNews, setEndNews] = useState(false);
    let imageConnected = BASE_URL + USER_CONNECTED.profilImageUrl;

    useEffect(async () => {
        const news = await getNews();
        // articleProps.length > 0 ? articles.signal.value = articleProps :  articles.signal.value = news;
        if (articleProps.length > 0) {
            articles.signal.value = articleProps
            setEndNews(false)
        } else {
            articles.signal.value = news
            setEndNews(true)
        }
    }, [articleProps])
    const toggleComments = async (id) => {
        setSelectedArticle((prevSelectedArticle) =>
            prevSelectedArticle === id ? null : id
        );
        try {
            const commentsConst = await getComments(id);
            articleComments.signal.value = commentsConst;
        } catch (error) {
            console.error(error);
        }
    }

    const scroll = async (event) => {
        if (!scrollEnd) {
            const div = event.target;
            let distanceFromBottom;

            if (!articles.signal.value) {
                distanceFromBottom = 20;
            } else {
                distanceFromBottom = div.scrollHeight - (div.scrollTop + div.clientHeight);
            }

            if (distanceFromBottom <= 20) {
                setScrollEnd(true);
                setEndNews(false);
                if (!articles.signal.value) {
                    const newsPush = await getNews();
                    articles.signal.value = newsPush;
                } else {
                    const lastTimeStamp = articles.signal.value.slice(-1)[0];
                    if (lastTimeStamp !== undefined && lastTimeStamp.updated["sec"]) {
                        const newsPush = await getNews(lastTimeStamp.updated["sec"]);
                        if (newsPush.length > 0) {
                            articles.signal.value = articles.signal.value.concat(newsPush);
                        } else if (newsPush.length === 0) {
                            setEndNews(true);
                        }
                    }
                }
                setEndNews(true);
                setScrollEnd(false);
            }
        }
    };

    const deleteAction = async (params) => {
        await deleteNews(params);
        articles.signal.value = articles.signal.value.filter(article => article.id != params);

    };
    const addReactionAction = async (params, id) => {
        await addaction(id, params, 'news');
        const news = await getNews();
        articles.signal.value = news;
    };

    const articleItems = articles.signal.value.map((element) => (
        <div className="mb-5">
            <Article
                element={element}
                parentId={USER_CONNECTED.id}
                toggleComments={() => toggleComments(element.id)}
                deleteAction={() => deleteAction(element.id)}
                dataReaction={(e) => addReactionAction(e, element.id)}
                addReactionAction={(e) => addReactionAction(e, element.id)}
            />
            {selectedArticle === element.id && (
                <CommentList articleComments={articleComments} imageConnected={imageConnected} idNews={element.id} />
            )}
        </div>
    ));

    const categoryNewsItems = categoryNews.map((item, index) => (
        <SwitchIconButton
            key={index}
            icon={item.icon}
            label={item.label}
            isSelected={item.label === switchNews.label}
            onClick={() => setSwitchNews(item)}
        />
    ));

    const contentListNews = categoryNews[0].label === switchNews.label ? articleItems : <ListGallery />

    return (
        <>
            <div onScroll={scroll} className="h-full overflow-auto overflow-x-hidden -mb-5">
                <FormNews imageConnected={imageConnected} parentId={USER_CONNECTED.id} author={USER_CONNECTED} />

                <div class="flex items-center space-x-4 mb-2">
                    {categoryNewsItems}
                </div>

                {contentListNews}

                {endNews ? (
                    <div className="bg-white p-5 text-center rounded-lg drop-shadow-md dark:bg-gray-900 dark:text-gray-400 font-bold">
                        <i className="fa-solid fa-ban"></i> Fin du fil d'actus
                    </div>
                ) : (
                    <div className="bg-white p-5 text-center rounded-lg drop-shadow-md dark:bg-gray-900 dark:text-gray-400 font-bold flex justify-center items-center">
                        <div className="loader">
                            <svg aria-hidden="true" className="w-8 h-5 mr-2 ml-2 text-gray-200 animate-spin dark:text-gray-300 fill-gray-600" viewBox="0 0 100 101" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M100 50.5908C100 78.2051 77.6142 100.591 50 100.591C22.3858 100.591 0 78.2051 0 50.5908C0 22.9766 22.3858 0.59082 50 0.59082C77.6142 0.59082 100 22.9766 100 50.5908ZM9.08144 50.5908C9.08144 73.1895 27.4013 91.5094 50 91.5094C72.5987 91.5094 90.9186 73.1895 90.9186 50.5908C90.9186 27.9921 72.5987 9.67226 50 9.67226C27.4013 9.67226 9.08144 27.9921 9.08144 50.5908Z" fill="currentColor" />
                                <path d="M93.9676 39.0409C96.393 38.4038 97.8624 35.9116 97.0079 33.5539C95.2932 28.8227 92.8710 24.3692 89.8167 20.3480C85.8452 15.1192 80.8826 10.7238 75.2124 7.4129C69.5422 4.1019 63.2754 1.9402 56.7698 1.0512C51.7666 0.3675 46.6976 0.4468 41.7345 1.2787C39.2613 1.6933 37.8130 4.1978 38.4501 6.6233C39.0873 9.0487 41.5694 10.4717 44.0505 10.1071C47.8511 9.5486 51.7191 9.5269 55.5402 10.0491C60.8642 10.7766 65.9928 12.5457 70.6331 15.2552C75.2735 17.9648 79.3347 21.5619 82.5849 25.8410C84.9175 28.9121 86.7997 32.2913 88.1811 35.8758C89.0830 38.2158 91.5421 39.6781 93.9676 39.0409Z" fill="currentFill" />
                            </svg>
                        </div>
                    </div>
                )}

            </div>
        </>
    )
}

export default ListArticle;