import React from 'react'
import changePassordImg from '../../../core/assets/images/changePassowrd.png'
import deleteAccountImg from '../../../core/assets/images/deleteAccount.png'
import Card from '../component/Card'
import Modal from '../../../core/presentation/component/Modal'
import { useState } from 'preact/hooks'
import InputSimple from '../../../core/presentation/component/input/InputSimple'
import { Toaster, toast } from 'react-hot-toast';
import { changepassword, deleteAccount } from '../../infrastructure/constant/api-endpoints'
import { USER_CONNECTED } from '../../../core/application/constant/common'
import Textarea from '../../../core/presentation/component/input/Textarea'

function Settings() {
    const [showChangePasswordModal, setshowChangePasswordModal] = useState(false)
    const [showDeleteAccountModal, setshowDeleteAccountModal] = useState(false)
    const [pwd, setpwd] = useState("")
    const [repwd, setrepwd] = useState("")
    const [newpwd, setnewpwd] = useState("")
    const [reason, setreason] = useState("")
    const [reasonctrl, setreasonctrl] = useState(false)
    const [pwdctrl, setpwdctrl] = useState(false)
    const [repwdctrl, setrepwdctrl] = useState(false)
    const [newpwdctrl, setnewpwdctrl] = useState(false)
    const [loadingChangePwd, setloadingChangePwd] = useState(false)
    const [loadingDeleteAccount, setloadingDeleteAccount] = useState(false)

    const toastOptions = {
        style: {
            borderRadius: '10px',
            background: '#333',
            color: '#fff',
        },
    };

    const changePassowrd = async () => {
        let result = '';
        if (pwd == '') {
            setpwdctrl(true)
        } else {
            setpwdctrl(false)
            result += '1';
        }
        if (repwd == '') {
            setrepwdctrl(true)
        } else {
            setrepwdctrl(false)
            result += '2';
        }
        if (newpwd == '') {
            setnewpwdctrl(true)
        } else {
            setnewpwdctrl(false)
            result += '3';
        }
        if (result == "123") {
            if (newpwd != repwd) {
                setnewpwdctrl(true)
                setrepwdctrl(true)
                toast.error("Mots de passe pas identique", toastOptions);
            } else {
                const response = await changepassword("changePassword", USER_CONNECTED.id, pwd, newpwd, repwd, undefined, "");
                setloadingChangePwd(true)
                if (response.data.result === true) {
                    setpwd("")
                    setrepwd("")
                    setnewpwd("")
                    setpwdctrl(false)
                    setrepwdctrl(false)
                    setnewpwdctrl(false)
                    setshowChangePasswordModal(false)
                    toast.success(<div dangerouslySetInnerHTML={{ __html: response.data.msg }} />, toastOptions);
                    setloadingChangePwd(false)
                }
                else {
                    toast.error(<div dangerouslySetInnerHTML={{ __html: response.data.msg }} />, toastOptions);
                    setloadingChangePwd(false)
                }
            }

        }
    }

    const deleteAccountFunction = async () => {
        let result = '';
        if (reason == '') {
            setreasonctrl(true)
        } else {
            setreasonctrl(false)
            result += '1';
        }
        if (result == "1") {
            const response = await deleteAccount(reason);
            setloadingDeleteAccount(true)
            if (response.data.result === true) {
                setreason("")
                setshowDeleteAccountModal(false)
                toast.success(<div dangerouslySetInnerHTML={{ __html: response.data.msg }} />, toastOptions);
                setloadingDeleteAccount(false)
            }
            else {
                toast.error(<div dangerouslySetInnerHTML={{ __html: response.data.msg }} />, toastOptions);
                setloadingDeleteAccount(false)
            }
        }
    }
    return (
        <>
            <div className='w-full'>
                <div class="grid grid-cols-2 gap-3 px-2 pt-1">
                    <Card label={"Changer votre mots de passe"} image={changePassordImg} action={() => setshowChangePasswordModal(true)} />
                    <Card label={"Supprimer mon compte"} image={deleteAccountImg} action={() => setshowDeleteAccountModal(true)} />
                </div>
            </div>
            <Modal
                show={showChangePasswordModal}
                close={() => setshowChangePasswordModal(false)}
                title={"Changer votre mot de passe"}
                onSubmit={changePassowrd}
                isLoading={loadingChangePwd}
            >
                <InputSimple value={(e) => setpwd(e)} label={'Ancien mot de passe*'} type={'password'} ctrl={pwdctrl} msgErreur={'Verifier votre champs'} />
                <InputSimple value={(e) => setrepwd(e)} label={'Nouveau mot de passe*'} type={'password'} ctrl={repwdctrl} msgErreur={'Verifier votre champs'} />
                <InputSimple value={(e) => setnewpwd(e)} label={'Répéter votre nouveau mot de passe*'} type={'password'} ctrl={newpwdctrl} msgErreur={'Verifier votre champs'} />
            </Modal>
            <Modal
                show={showDeleteAccountModal}
                close={() => setshowDeleteAccountModal(false)}
                title={"SUPPRIMER"}
                onSubmit={deleteAccountFunction}
                onSubmitColor={"danger"}
                onSubmitText={"je confirme la suppression"}
            >
                <div className='mb-6 dark:text-gray-300 text-gray-900 font-semibold'>
                    Si vous supprimer votre comptes, toutes vos informations personnelles et vos messages seront supprimer
                </div>
                <div>
                    <Textarea
                        label={"Ajouter ci dessous pourquoi vous souhaitez supprimer cet élément :"}
                        placeholder={"Laisser une raison"}
                        value={(e) => setreason(e)}
                        ctrl={reasonctrl}
                        isLoading={loadingDeleteAccount}
                    />
                </div>
            </Modal>
            <Toaster
                position="bottom-right"
                reverseOrder={false}
            />
        </>
    )
}

export default Settings