import React from 'react'
import { BASE_URL, USER_CONNECTED } from '../../../core/application/constant/common'
import defaultImage from "../../../core/assets/images/defaultImage.png";

function Card({ element, openShareModal, action, jointAction, leaveAction, openRightDetailleFunction }) {
    let backgroundColor;
    let icon;

    console.log(element);
    if (element.type === 'NGO') {
        backgroundColor = 'bg-lime-600';
        icon = 'fa-solid fa-users text-gray-200';
    } else if (element.type === 'LocalBusiness') {
        backgroundColor = 'bg-cyan-400';
        icon = 'fa-solid fa-industry';
    } else if (element.type === 'Group') {
        backgroundColor = 'bg-cyan-400';
        icon = 'fa-regular fa-circle';
    } else if (element.type === 'GovernmentOrganization') {
        backgroundColor = 'bg-red-600 text-gray-200';
        icon = 'fa-solid fa-university';
    } else if (element.type === 'Cooperative') {
        backgroundColor = 'bg-cyan-600';
        icon = 'fa-solid fa-industry';
    } else if (element.collection === 'projects') {
        backgroundColor = 'bg-violet-600';
        icon = 'fa-solid fa-lightbulb text-gray-200';
    } else if (element.collection === 'citoyens') {
        backgroundColor = 'bg-yellow-500';
        icon = 'fa-solid fa-users text-gray-200';
    } else if (element.collection === 'poi') {
        backgroundColor = 'bg-green-500';
        icon = 'fa-solid fa-newspaper text-gray-200';
    } else {
        backgroundColor = 'bg-gray-500';
        icon = 'fa-solid fa-question';
    }

    const share = () => {
        openShareModal(true, element)
    }

    const renderContributors = () => {
        if (element.links && element.links.contributors) {
            const contributorCount = Object.keys(element.links.contributors).length;

            if (contributorCount === 1) {
                return "1 contributeur";
            } else if (contributorCount > 1) {
                return `${contributorCount} contributeurs`;
            }
        }
        return null;
    };

    const renderFollowers = () => {
        if (element.links && element.links.followers) {
            const followerCount = Object.keys(element.links.followers).length;

            if (followerCount === 1) {
                return "1 abonné";
            } else if (followerCount > 1) {
                return `${followerCount} abonnés`;
            }
        }
        return null;
    };

    const BtnShare = action != false ? (
        <p className="absolute top-0 text-sm right-0 bg-lime-600 text-gray-200 font-semibold py-1 px-3 rounded-bl-lg cursor-pointer" onClick={share}>
            Partager
        </p>
    ) : null;

    const isFollower = element.links && element.links.followers && element.links.followers[USER_CONNECTED.id] !== undefined;
    const isContributor = element.links && element.links.contributors && element.links.contributors[USER_CONNECTED.id] !== undefined;
    let buttonText = "";
    let actionOnClick = () => { };

    if (isFollower) {
        buttonText = "Abonné";
        actionOnClick = leaveAction;
    } else if (isContributor) {
        buttonText = "Contributrice";
        actionOnClick = null;
    } else {
        buttonText = "S'abonner";
        actionOnClick = jointAction;
    }

    const BtnParticipe = action != false ? (
        <p className="absolute top-0 text-sm left-0 bg-lime-600 text-gray-200 font-semibold py-1 px-3 rounded-br-lg cursor-pointer">
            <button disabled={isContributor} onClick={() => actionOnClick(element.id, element.collection)}>
                {buttonText}
            </button>
        </p>
    ) : null;

    const detailleFunction = () => {
        openRightDetailleFunction(element.id, element.collection)
    }

    return (
        <div class=" bg-gray-900 shadow-xl rounded-lg overflow-hidden transform hover:scale-105 transition duration-500">
            <div class="relative">
                <img class="h-56 w-full object-cover rounded-tl-lg" src={BASE_URL + element.profilMediumImageUrl} onError={(e) => e.target.src = defaultImage} />
                <p className={`absolute top-0 left-0 ${backgroundColor} text-gray-800 font-semibold py-1 px-3 rounded-br-lg rounded-tl-lg`}><i className={icon}></i></p>
                <div class="text-gray-100 font-bold truncate text-center">
                    <h1 class="truncate absolute bottom-0 left-0 w-full bg-black bg-opacity-80 text-gray-200 font-semibold py-1 px-3 rounded-br-lg rounded-bl-lg backdrop-blur-sm">
                        {element.name}
                    </h1>
                </div>
                <div class="absolute inset-0 bg-black rounded-lg bg-opacity-50 flex items-center justify-center opacity-0 hover:opacity-100 transition duration-500 backdrop-blur-sm">
                    <div class="text-center">
                        <div class="text-gray-100 font-bold truncate">
                            <h1 class="cursor-pointer truncate absolute bottom-0 left-0 w-full bg-lime-600 text-gray-200 font-semibold py-1 px-3 rounded-br-lg rounded-bl-lg" onClick={detailleFunction}>
                                {element.name}
                            </h1>
                        </div>
                        <div class="text-gray-100 text-sm p-2 px-4 max-h-36 overflow-auto">
                            {renderContributors() && (
                                <span className="bg-blue-100 mb-1 left-0 text-blue-800 text-xs font-medium me-2 px-1 py-0.5 rounded dark:bg-lime-600 dark:text-gray-100">
                                    <i className='fa-solid fa-users mr-0.5'></i>
                                    {renderContributors()}
                                </span>
                            )}
                            <br />
                            {renderFollowers() && (
                                <span className="bg-blue-100 mb-1 left-0 text-blue-800 text-xs font-medium me-2 px-1 py-0.5 rounded dark:bg-lime-600 dark:text-gray-100">
                                    <i className='fa-solid fa-link mr-0.5'></i>
                                    {renderFollowers()}
                                </span>
                            )}
                            {element.collection === "poi" ? (
                                <>
                                    {BtnShare}
                                </>
                            ) : element.collection === "citoyens" ? (
                                <>
                                    {BtnParticipe}
                                </>
                            ) : (
                                <>
                                    {BtnParticipe}{BtnShare}
                                </>
                            )}
                            {element.shortDescription != undefined ? (
                                <p class="line-clamp-2 mb-2">{element.shortDescription}</p>
                            ) : " "}
                            <div class="flex justify-center flex-wrap">
                                {element.tags && element.tags.map((element, index) => (
                                    <span key={index} class="bg-blue-100 mb-1 text-blue-800 text-xs font-medium me-2 px-2.5 py-0.5 rounded dark:bg-lime-600 dark:text-gray-100">
                                        #{element}
                                    </span>
                                ))}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>




    )
}

export default Card