import { Carousel, IconButton } from '@material-tailwind/react'
import React from 'react'
import { TagsType } from '../../../core/list/TagsType'
import { useEffect, useState } from 'preact/hooks'

function CarousselTags({ tagsSearchValue, tagsSearchDefaultValue }) {
    const [tags, settags] = useState([])

    useEffect(() => {
        settags(tagsSearchDefaultValue)
    }, [tagsSearchDefaultValue])

    const handleClick = (value) => {
        console.log('loremmmmmmmmmm');
        if (value.some(tag => tags.includes(tag))) {
            const updatedTags = tags.filter(tag => !value.includes(tag));
            settags(updatedTags);
            tagsSearchValue(updatedTags);
        } else {
            settags(tags.concat(value));
            tagsSearchValue(tags.concat(value));
        }
    }

    return (
        <Carousel
            className="rounded-xl w-full h-full md:h-[110px] overflow-hidden"
            navigation={({ setActiveIndex, activeIndex, length }) => (
                <div className="absolute bottom-1 left-2/4 z-30 flex -translate-x-2/4 gap-2">
                    {new Array(length).fill("").map((_, i) => (
                        <span
                            key={i}
                            className={`hover:bg-lime-600 z-50 block h-1 cursor-pointer rounded-2xl transition-all content-[''] ${activeIndex === i ? "w-8 h-2 bg-lime-600" : "w-4 h-2 bg-white/50"
                                }`}
                            onClick={() => setActiveIndex(i)}
                        />
                    ))}
                </div>
            )}
            prevArrow={({ handlePrev }) => (
                <IconButton
                    onClick={handlePrev}
                    className="!absolute top-1/2 -left-3 -mt-1 -translate-y-2/4 bg-transparent h-full"
                >
                    <i style={{ fontSize: 22 }} class="fa-solid fa-chevron-left text-lime-600 dark:text-gray-200"></i>
                </IconButton>
            )}
            nextArrow={({ handleNext }) => (
                <IconButton
                    onClick={handleNext}
                    className="!absolute top-1/2 right-0 -translate-y-2/4 bg-transparent h-full"
                >
                    <i style={{ fontSize: 22 }} class="fa-solid fa-chevron-right text-lime-600 dark:text-gray-200"></i>
                </IconButton>
            )}
        >
            <div class="mx-10 md:grid md:grid-cols-6 lg:grid-cols-6 gap-4 space-y-4 md:space-y-0 overflow-hidden">
                {TagsType.slice(0, 6).map(({ value, image, label }) => (
                    <div
                        className={`bg-gray-900 h-28 shadow-xl rounded-bl-lg rounded-lg overflow-hidden transform cursor-pointer ${value.some((tag) => tags.includes(tag)) ? 'border-2 border-lime-600' : ''
                            }`}
                    >
                        <div className="relative" onClick={() => handleClick(value)}>
                            <img
                                src={image}
                                className="h-28 w-full object-cover rounded-lg rounded-br-lg bg-gray-300 dark:bg-gray-700 transform hover:scale-105 transition duration-1000"
                            />
                            <div className="text-gray-100 font-bold text-center">
                                <h1 className="absolute dark:text-gray-200 text-xs bottom-0 w-full text-center backdrop-blur-sm bg-gray-800 bg-opacity-75 rounded-bl-lg rounded-br-lg">
                                    <div className='py-1'>
                                        {label}
                                    </div>
                                </h1>
                            </div>
                        </div>
                    </div>
                ))}
            </div>

            <div class="mx-10 md:grid md:grid-cols-6 lg:grid-cols-6 gap-4 space-y-4 md:space-y-0 overflow-hidden">
                {TagsType.slice(6).map(({ value, image, label }) => (
                    <div
                        className={`bg-gray-900 h-28 shadow-xl rounded-bl-lg rounded-lg overflow-hidden transform cursor-pointer ${value.some((tag) => tags.includes(tag)) ? 'border-2 border-lime-600' : ''
                            }`}
                    >
                        <div className="relative" onClick={() => handleClick(value)}>
                            <img
                                src={image}
                                className="h-28 w-full object-cover rounded-lg rounded-br-lg bg-gray-300 dark:bg-gray-700 transform hover:scale-105 transition duration-1000"
                            />
                            <div className="text-gray-100 font-bold text-center">
                                <h1 className="absolute dark:text-gray-200 text-xs bottom-0 w-full text-center backdrop-blur-sm bg-gray-800 bg-opacity-75 rounded-bl-lg rounded-br-lg">
                                    <div className='py-1'>
                                        {label}
                                    </div>
                                </h1>
                            </div>
                        </div>
                    </div>
                ))}
            </div>
        </Carousel>
    )
}

export default CarousselTags