import moment from 'moment'
import React from 'react'

function DateTimeOpen({ type, startDate, endDate, openingHours }) {
    return (
        <li className="mb-4 ms-6">
            <span className="absolute flex items-center justify-center w-6 h-6 bg-blue-100 rounded-full -start-3 ring-8 ring-white dark:ring-gray-800 bg-lime-600 text-gray-100">
                <i className="fa-solid fa-clock"></i>
            </span>
            <h3 className="flex items-center mb-1 text-base font-semibold dark:text-gray-200">{type == "projects" ? "QUAND" : "HEURE D'OUVERTURE"}</h3>
            {startDate != undefined && endDate != undefined ?
                <ol class="relative border-s border-lime-600">
                    <li class="mb-2 ms-4">
                        <div class="absolute w-3 h-3 bg-gray-200 rounded-full mt-1.5 -start-1.5 border border-white border-lime-600 bg-lime-700"></div>
                        <time class=" text-sm font-normal leading-none text-gray-700 dark:text-gray-500">Du</time>
                        <h3 class="text-lg font-semibold text-gray-900 dark:text-white">{moment(startDate).format('LL')}</h3>
                    </li>
                    <li class="ms-4">
                        <div class="absolute w-3 h-3 bg-gray-200 rounded-full mt-1.5 -start-1.5 border border-white border-lime-600 bg-lime-700"></div>
                        <time class="mb-1 text-sm font-normal leading-none text-gray-700 dark:text-gray-500">Au</time>
                        <h3 class="text-lg font-semibold text-gray-900 dark:text-white">{moment(endDate).format('LL')}</h3>
                    </li>
                </ol> : openingHours != undefined ?
                    <>
                        <ol class="relative border-s border-gray-200 dark:border-gray-700">
                            {openingHours.map((item, index) => (
                                <li key={index} class="mb-2 ms-4">
                                    <div class="absolute w-3 h-3 bg-gray-200 rounded-full mt-1.5 -start-1.5 border border-white border-lime-600 bg-lime-700"></div>
                                    <time class=" text-sm font-normal leading-none text-gray-700 dark:text-gray-500">{item.dayOfWeek}</time>
                                    {item.hours && item.hours.length > 0 && (
                                        <h3 className="text-lg leading-none font-normal text-gray-900 dark:text-white">
                                            {item.hours[0].opens} - {item.hours[0].closes}
                                        </h3>
                                    )}
                                </li>
                            ))}
                        </ol>
                    </>
                    :
                    null
            }
        </li>
    )
}

export default DateTimeOpen