import React from 'react'
import { useEffect, useState } from 'preact/hooks';
import SearchLocality from './SearchLocality';
import SearchViaType from './SearchViaType';
import Favoris from '../container/Favoris';

function SearchForm({ name, count, typeValue, typeDefaultValue, setlocality, setlocalityDefault, tagsSearch, setParsedParamsTypeFavoris, setParsedParamsTagsFavoris, localityFavoris  }) {
    const [inputValue, setInputValue] = useState('');

    useEffect(() => {
        const timer = setTimeout(() => {
            name(inputValue);
        }, 1000);
        return () => clearTimeout(timer);
    }, [inputValue, name]);

    const handleInputChange = (e) => {
        setInputValue(e.target.value);
    };

    const extractSearchParams = (url) => {
        url = url.replace(/^#search\?/, '');
        url = url.replace(/&amp;/g, '&');

        const params = new URLSearchParams(url);

        const result = {
            types: params.getAll('types').map(decodeURIComponent),
            tags: params.getAll('tags').map(decodeURIComponent)
        };

        // Supprimer les valeurs undefined ou null
        Object.keys(result).forEach(key => result[key] == null && delete result[key]);
        const splitTypes = result.types.flatMap(type => type.split(','));
        const splitTags = result.tags.flatMap(type => type.split(','));
        setParsedParamsTypeFavoris(splitTypes)
        setParsedParamsTagsFavoris(splitTags)
    }


    return (
        <div className='flex justify-between'>
            <div className="flex flex-col md:flex-row items-center md:justify-end -pt-3 p-3 rounded-lg mx-20">
                <div className="w-full relative flex-grow mb-4 md:mb-0 md:mr-4">
                    <input
                        value={inputValue}
                        onChange={handleInputChange}
                        type="text"
                        className="block p-1.5 z-20 text-sm text-gray-900 bg-gray-50 rounded-lg border-s-gray-50 border-s-2 border border-gray-300 focus:ring-lime-500 focus:border-lime-500 dark:bg-gray-700 dark:border-s-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 dark:focus:border-lime-500 w-full outline-none"
                        placeholder="Que recherchez-vous ?"
                    />
                    <button type="submit" className="absolute top-0 right-0 p-1.5 text-sm font-medium text-gray-200 bg-lime-700 rounded-e-lg border border-lime-700 hover:bg-lime-800 focus:ring-1 focus:outline-none focus:ring-lime-300 dark:bg-lime-600 dark:hover:bg-lime-700 dark:focus:ring-lime-800">
                        <i className="fa-solid fa-search mx-2"></i>
                    </button>
                </div>
                <SearchLocality setlocality={setlocality} setlocalityDefault={setlocalityDefault} />
                <SearchViaType
                    count={count}
                    typeValue={typeValue}
                    typeDefaultValue={typeDefaultValue}
                />
            </div>
            <Favoris
                typeSearch={typeDefaultValue}
                tagsSearch={tagsSearch}
                locality={setlocalityDefault}
                onArrayMerge={extractSearchParams}
                localityFavoris={localityFavoris}
            />
        </div>
    )
}

export default SearchForm;
