import { useEffect, useState } from 'preact/hooks';
import React from 'react'
import { globalAutocompleteCities } from '../../infrastructure/api/search-api';

function SearchLocality({ setlocality, setlocalityDefault }) {
    console.log(setlocalityDefault);
    const [inputValue, setInputValue] = useState('');
    const [isOpen, setIsOpen] = useState(false);
    const [results, setresults] = useState([]);
    const [localityArray, setlocalityArray] = useState([]);

    const handleKeyPress = async (event) => {
        if (event.key === 'Enter' && inputValue.length >= 3) {
            const results = await globalAutocompleteCities(inputValue)
            setresults(results);
            setIsOpen(true)
        }
    };

    const handlePressLocality = (id, name, type) => {
        setlocalityArray([...localityArray, { id: id.$id, name, type:type}])
        setlocality([...localityArray, { id: id.$id, name, type:type }])
        setInputValue("")
    }

    useEffect(() => {
        setlocalityArray(setlocalityDefault)
    }, [setlocalityDefault])

    return (
        <div className="relative flex-grow w-full" onMouseLeave={() => setIsOpen(false)}>
            <input
                value={inputValue}
                onChange={(e) => setInputValue(e.target.value)}
                onKeyPress={handleKeyPress}
                type="text"
                className="block p-1.5 z-20 text-sm text-gray-900 bg-gray-50 rounded-lg border-s-gray-50 border-s-2 border border-gray-300 focus:ring-lime-500 focus:border-lime-500 dark:bg-gray-700 dark:border-s-gray-700  dark:border-gray-600 dark:placeholder-gray-400 dark:text-gray-200 dark:focus:border-lime-500 w-full outline-none"
                placeholder="Ou ?"
            />
            <button type="submit" className="absolute top-0 right-0 p-1.5 text-sm font-medium text-gray-200 bg-lime-700 rounded-e-lg border border-lime-700 hover:bg-lime-800 focus:ring-1 focus:outline-none focus:ring-lime-300 dark:bg-lime-600 dark:hover:bg-lime-700 dark:focus:ring-lime-800">
                <i className="fa-solid fa-location-dot mx-2"></i>
            </button>
            {isOpen && (
                <div
                    className="-mr-1 h-50 z-50 origin-top-right absolute right-0 w-full rounded-md shadow-lg overflow-y-auto bg-white dark:bg-gray-900 dark:border-s-gray-700 dark:border-gray-600 ring-1 ring-black ring-opacity-5"
                    role="menu"
                    aria-orientation="vertical"
                    aria-labelledby="menu-button"
                    tabIndex="-1"
                >
                    <div className="pb-1" role="none">
                        {results.map(({ _id, type, name, country, postalCode, level1Name }) => (
                            <div key={_id} className="cursor-pointer block px-2 py-1 dark:text-gray-200 hover:bg-lime-600 hover:text-gray-900" onClick={() => handlePressLocality(_id, name, type)}>
                                <div className='truncate'><i className={type === "city" ? 'fa-solid fa-university' : 'fa-solid fa-bullseye'}></i> {name}</div>
                            </div>
                        ))}

                    </div>
                </div>
            )}
        </div>
    )
}

export default SearchLocality