import { useEffect, useState } from 'preact/hooks';
import React from 'react'
import { TagsThematique } from '../../../core/list/TagsThematique';

function SearchViaType({ count, typeValue, typeDefaultValue }) {
    const [isOpen, setIsOpen] = useState(false);
    const [type, setType] = useState([])

    const toggleDropdown = () => {
        setIsOpen(!isOpen);
    };

    useEffect(() => {
        typeValue(typeDefaultValue.length > 0 ? typeDefaultValue.concat(type.slice(-1)) : type.slice(-1))
    }, [type])

    const handleClick = (value) => {
        if (typeDefaultValue.includes(value)) {
            const updatedDefaults = typeDefaultValue.filter(element => element !== value);
            typeValue(updatedDefaults);
        } else {
            setType([...type, value]);
        }
    }

    return (
        <div className="relative w-full md:pr-4 sm:pr-0" onMouseLeave={toggleDropdown} onMouseEnter={toggleDropdown}>
            <button
                type="button"
                className="w-full text-sm mt-4 p-1.5 md:mt-0 md:ml-4 text-gray-200 bg-lime-700 hover:bg-lime-800 focus:ring-1 focus:ring-lime-300 font-medium rounded-lg px-5 py-1.5 dark:bg-lime-600 dark:hover:bg-lime-700 focus:outline-none dark:focus:ring-lime-800 flex flex-col items-center md:flex-row md:items-center"
            >
                <span className="flex-grow flex items-center justify-center">
                    Types
                    <i className="fa-solid fa-caret-down ml-1 mt-0"></i>
                </span>
            </button>
            {isOpen && (
                <div
                    className="-mr-1 h-50 z-40 origin-top-right absolute right-0 w-full rounded-md shadow-lg overflow-y-auto bg-white dark:bg-gray-900 dark:border-s-gray-700 dark:border-gray-600 ring-1 ring-black ring-opacity-5"
                    role="menu"
                    aria-orientation="vertical"
                    aria-labelledby="menu-button"
                    tabIndex="-1"
                >
                    <div className="pb-1" role="none">
                        {TagsThematique.map(({ value, label, icon }, index) => (
                            <div
                                key={index}
                                onClick={() => handleClick(value)}
                                className={`flex justify-between cursor-pointer block px-2 py-1 dark:text-gray-200 ${typeDefaultValue.includes(value)
                                    ? 'bg-lime-600 rounded-lg text-gray-900'
                                    : 'hover:bg-lime-600 hover:rounded-lg hover:text-gray-900'
                                    }`}
                            >
                                <div>
                                    <i className={icon}></i> {label}
                                </div>
                                {count[value]}
                            </div>
                        ))}
                    </div>
                </div>
            )}
        </div>
    )
}

export default SearchViaType