import { useContext, useEffect, useState } from "preact/hooks";
import Card from "../component/Card"
import StateContext from "../../../core/context/state-context";
import { disconnect, follow, getOneElement, globalautocomplete } from "../../infrastructure/api/search-api";
import ShareInSearch from "../component/ShareInSearch";
import CarousselTags from "../component/CarousselTags";
import SearchForm from "../component/SearchForm";
import { share } from "../../../agenda/infrastructure/constant/api-endpoints";
import DeleteConfirm from "../../../news/presentation/component/deleteConfirm";
import { USER_CONNECTED } from "../../../core/application/constant/common";
import DetailleRight from "../component/DetailleRight";
import ListMap from "./ListMap";
import CustomDrawer from "../../../core/presentation/component/CustomDrawer";

function ListeSearch() {

    const { articles, articleCount } = useContext(StateContext);
    const [scrollEnd, setScrollEnd] = useState(false);
    const [endNews, setEndNews] = useState(false);
    const [currentIndexMin, setCurrentIndexMin] = useState(6);
    const [currentIndexMax, setCurrentIndexMax] = useState(12);
    const [shareModal, setShareModal] = useState(false);
    const [name, setName] = useState("");
    const [dataInShare, setDataInShare] = useState()
    const [typeSearch, setTypeSearch] = useState([])
    const [tagsSearch, setTagsSearch] = useState([])
    const [locality, setlocality] = useState([])
    const [marginTopClass, setMarginTopClass] = useState("-mt-[0px]");
    const [commentInShare, setCommentInShare] = useState("")
    const [showConfirmLeave, setshowConfirmLeave] = useState(false)
    const [loadingLeave, setloadingLeave] = useState(false)
    const [idLeave, setidLeave] = useState(null)
    const [collectionLeave, setcollectionLeave] = useState(null)
    const [dataToGet, setDataToGet] = useState({})
    const [isOpenCustomDrawer, openAndCloseCustomDrawer] = useState(false);
    const [mapShow, setMapShow] = useState(false);

    const openDetailsFunction = async (id, collection) => {
        openAndCloseCustomDrawer(!isOpenCustomDrawer)
        if (isOpenCustomDrawer == false) {
            const result = await getOneElement(collection, id)
            setDataToGet(result.data)
        }
    };

    useEffect(async () => {
        const fetchData = async () => {
            articles.signal.value = []
            setEndNews(false);
            const result = await globalautocomplete(0, 6, name, typeSearch, tagsSearch, locality);

            const results = Object.keys(result.results).map(id => ({
                id,
                ...result.results[id]
            }));

            articles.signal.value = results;
            articleCount.signal.value = result.count;
            setEndNews(true);
        };

        fetchData();
    }, [name, typeSearch, tagsSearch, locality])

    const sumResutNoFilter = Object.values(articleCount.signal.value).reduce((accumulator, currentValue) => accumulator + currentValue, 0);

    const filteredKeys = Object.keys(articleCount.signal.value)
        .filter(key => typeSearch.includes(key));

    const sumResultFilterTyp = filteredKeys.reduce((accumulator, currentValue) => {
        return accumulator + articleCount.signal.value[currentValue];
    }, 0);

    const sumResut = typeSearch.length > 0 ? sumResultFilterTyp : sumResutNoFilter

    const scroll = async (event) => {
        const div = event.target;

        if (div.scrollTop === 0) {
            setMarginTopClass("-mt-[0px]");
        } else {
            setMarginTopClass("-mt-[135px]");
        }
        if (!scrollEnd) {
            const div = event.target;
            let distanceFromBottom;
            if (!articles.signal.value) {
                distanceFromBottom = 20;
            } else {
                distanceFromBottom = div.scrollHeight - (div.scrollTop + div.clientHeight);
            }
            if (distanceFromBottom <= 20) {
                setScrollEnd(true);
                setEndNews(false);
                const resultPush = await globalautocomplete(currentIndexMin, currentIndexMax, name, typeSearch, tagsSearch, locality);
                const results = Object.keys(resultPush.results).map(id => ({
                    id,
                    ...resultPush.results[id]
                }));

                if (results.length > 0) {
                    articles.signal.value = [...articles.signal.value, ...results];
                    setCurrentIndexMin(prev => prev + 6);
                    setCurrentIndexMax(prev => prev + 6);
                    setEndNews(false);
                } else {
                    setEndNews(true);
                    scrollEnd(true)
                }
                setScrollEnd(false);
            }
        }
    };

    const removeTypeSearch = (item) => {
        const updatedTypeSearch = typeSearch.filter(element => element !== item);
        setTypeSearch(updatedTypeSearch);
    }

    const removeTagsSearch = (item) => {
        const updatedTagsSearch = tagsSearch.filter(element => element !== item);
        setTagsSearch(updatedTagsSearch);
    }

    const removeLocalitySearch = (id) => {
        const updatedLocalitySearch = locality.filter(element => element.id !== id);
        setlocality(updatedLocalitySearch);
    }

    // const shareInSearch = async (dataShare) => {
    //     const shareConst = await share(dataShare.id, commentInShare, dataShare.collection == "projects" ? "projects" : "organizations")
    //     if (shareConst.data.result == true) {
    //         setShareModal(false)
    //     } else {
    //         alert('error')
    //     }
    // }

    const confirmLeave = (id, collection) => {
        setidLeave(id)
        setcollectionLeave(collection)
        setshowConfirmLeave(true)
    }

    const leaveAction = async () => {
        setloadingLeave(true)
        await disconnect('citoyens', collectionLeave, idLeave, 'followers')
        articles.signal.value = articles.signal.value.map(article => {
            if (article.id === idLeave) {
                if (article.links && article.links.followers && article.links.followers[USER_CONNECTED.id]) {
                    delete article.links.followers[USER_CONNECTED.id];
                }
                return {
                    ...article,
                    links: article.links
                };
            }
            return article;
        });

        setloadingLeave(false)
        setshowConfirmLeave(false)
    }

    const jointAction = async (id, collection) => {
        await follow('citoyens', collection, id)
        articles.signal.value = articles.signal.value.map(article => {
            if (article.id === id) {
                const updatedLinks = article.links || {};
                updatedLinks.followers = updatedLinks.followers || {};
                updatedLinks.followers[USER_CONNECTED.id] = {};

                return {
                    ...article,
                    links: updatedLinks
                };
            }
            return article;
        });
    }

    const hideShowCarte = () => {
        setMapShow(!mapShow)
        mapShow == false ? setMarginTopClass("-mt-[135px]") : setMarginTopClass("-mt-[0px]")
    }
    const modalShareShow = (e, element) => {
        setShareModal(e)
        setDataInShare(element)
    }

    return (
        <>
            <div className="h-full w-full lg:overflow-hidden md:overflow-hidden overflow-auto -mb-5">
                <SearchForm
                    name={(e) => setName(e)}
                    count={articleCount.signal.value}
                    typeValue={setTypeSearch}
                    setParsedParamsTypeFavoris={setTypeSearch}
                    typeDefaultValue={typeSearch}
                    setlocality={setlocality}
                    localityFavoris={setlocality}
                    setlocalityDefault={locality}
                    setParsedParamsTagsFavoris={setTagsSearch}
                    tagsSearch={tagsSearch}
                />
                <div className="w-full overflow-y-auto lg:overflow-x-hidden p-2 rounded-lg shadow">
                    <div className={`${marginTopClass} transition-margin duration-500 ease-in-out`}>
                        <h1 className="mb-4 -mt-2 text-xl font-bold leading-none tracking-tight text-gray-700 dark:text-gray-200">Thematiques</h1>
                        <CarousselTags
                            tagsSearchValue={setTagsSearch}
                            tagsSearchDefaultValue={tagsSearch}
                        />
                    </div>
                    <div className="w-full mt-6 mb-2">
                        <div className="flex justify-between">
                            <h1 className="text-xl font-bold leading-none tracking-tight text-gray-700 dark:text-gray-200">{sumResut} {sumResut === 1 ? 'Résultat' : 'Résultats'}</h1>
                            <button
                                onClick={hideShowCarte}
                                className="bg-lime-600 hover:bg-lime-700 -mt-1 text-white font-bold py-1 px-4 rounded"
                            >
                                {mapShow ? <>
                                    <i class="fa-regular fa-rectangle-list"></i> Liste
                                </> :
                                    <>
                                        <i className="fa-solid fa-location-dot"></i> Carte
                                    </>}
                            </button>
                        </div>
                        <div className="ml-5 overflow-x-auto hide-scrollbar flex max-w-[50rem]">
                            {typeSearch.map((item) => (
                                <span class="whitespace-nowrap bg-blue-100 text-blue-800 text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">
                                    <i onClick={() => removeTypeSearch(item)} class="fa-solid fa-circle-xmark mr-1 cursor-pointer"></i>
                                    {item}
                                </span>
                            ))}
                            {tagsSearch.map((item) => (
                                <span class="whitespace-nowrap bg-blue-100 text-blue-800 text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">
                                    <i onClick={() => removeTagsSearch(item)} class="fa-solid fa-circle-xmark mr-1 cursor-pointer"></i>
                                    {item}
                                </span>
                            ))}
                            {locality.map(({ id, name }) => (
                                <span class="whitespace-nowrap bg-blue-100 text-blue-800 text-xs font-medium mr-2 px-2.5 py-0.5 rounded dark:bg-blue-900 dark:text-blue-300">
                                    <i onClick={() => removeLocalitySearch(id)} class="fa-solid fa-circle-xmark mr-1 cursor-pointer"></i>
                                    {name}
                                </span>
                            ))}
                        </div>
                    </div>
                    {mapShow == false ?
                        <div className="w-full h-[calc(100vh-220px)] overflow-y-auto overflow-x-hidden" onScroll={scroll}>
                            <div class="md:grid md:grid-cols-2 lg:grid-cols-4 gap-5 space-y-4 md:space-y-0 px-2 pt-2">
                                {articles.signal.value.length > 0 && articles.signal.value.map((element) => (
                                    <Card
                                        element={element}
                                        openShareModal={modalShareShow}
                                        leaveAction={confirmLeave}
                                        jointAction={jointAction}
                                        openRightDetailleFunction={openDetailsFunction}
                                    />
                                ))}
                                {endNews ? (
                                    <></>
                                ) : (
                                    <>
                                        {
                                            Array.from({ length: 4 }, (_, i) => (
                                                <div key={i} role="status" className="w-full animate-pulse">
                                                    <div className="bg-gray-900 shadow-xl rounded-lg overflow-hidden transform hover:scale-105 transition duration-500 cursor-pointer">
                                                        <div className="relative">
                                                            <div className="h-56 w-full object-cover rounded-tl-lg bg-gray-300 rounded dark:bg-gray-700"></div>
                                                            <p className={`absolute top-0 left-0 text-gray-800 bg-gray-500 h-8 w-8 font-semibold py-1 px-3 rounded-br-lg rounded-tl-lg`}></p>
                                                            <div className="text-gray-100 font-bold text-center">
                                                                <h1 className="flex justify-center absolute bottom-0 left-0 w-full bg-black bg-opacity-80 text-gray-200 font-semibold py-1 px-3 rounded-br-lg rounded-bl-lg backdrop-blur-sm">
                                                                    <div className="h-2.5 bg-gray-200 rounded-full dark:bg-gray-700 w-48 my-2"></div>
                                                                </h1>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            ))
                                        }
                                    </>
                                )}
                            </div>
                        </div> :
                        <ListMap />
                    }
                </div>
            </div>
            <ShareInSearch
                title={"Partager cette contenu avec votre reseau"}
                show={shareModal}
                close={() => setShareModal(false)}
                comment={setCommentInShare}
            // dataInShare={dataInShare}
            // shareInSearch={() => shareInSearch(dataShare)}
            />
            <DeleteConfirm
                isLoading={loadingLeave}
                deleteBtn={leaveAction}
                deleteConfirm={showConfirmLeave}
                close={() => setshowConfirmLeave(false)}
                title={"Ne plus Suivre ?"}
                textConfirmBtn={"Oui"}
            />
            <CustomDrawer
                isOpenDrawer={isOpenCustomDrawer}
                openAndCloseDrawer={openDetailsFunction}
                openPageTitle={"Vos Favoris de recherche"}
                placement={'right'}
                iconActionPage={false}
                overflowType={"overflow-hidden"}
            >
                <DetailleRight element={dataToGet} />

            </CustomDrawer>


        </>
    )
}

export default ListeSearch